#[repr(i32)]pub enum PacketEncAlgo {
FtaesEcb = 0,
None = -1,
AesEcb = 1,
AesCbc = 2,
}Expand description
包加密算法
Variants
Implementations
Sourceimpl PacketEncAlgo
impl PacketEncAlgo
Sourceimpl PacketEncAlgo
impl PacketEncAlgo
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.