#[repr(i32)]pub enum ProgramStatusType {
Show 13 variants
None = 0,
Loaded = 1,
Loging = 2,
NeedPicVerifyCode = 3,
NeedPhoneVerifyCode = 4,
LoginFailed = 5,
ForceUpdate = 6,
NessaryDataPreparing = 7,
NessaryDataMissing = 8,
UnAgreeDisclaimer = 9,
Ready = 10,
ForceLogout = 11,
DisclaimerPullFailed = 12,
}Variants
None = 0
Loaded = 1
已完成类似加载配置,启动服务器等操作,服务器启动之前的状态无需返回
Loging = 2
登录中
NeedPicVerifyCode = 3
需要图形验证码
NeedPhoneVerifyCode = 4
需要手机验证码
LoginFailed = 5
登录失败,详细原因在描述返回
ForceUpdate = 6
客户端版本过低
NessaryDataPreparing = 7
正在拉取类似免责声明等一些必要信息
NessaryDataMissing = 8
缺少必要信息
UnAgreeDisclaimer = 9
未同意免责声明
Ready = 10
可以接收业务协议收发,正常可用状态
ForceLogout = 11
OpenD登录后被强制退出登录,会导致连接全部断开,需要重连后才能得到以下该状态(并且需要在ui模式下)
被强制退出登录,例如修改了登录密码,中途打开设备锁等,详细原因在描述返回
DisclaimerPullFailed = 12
拉取免责声明标志失败
Implementations
Sourceimpl ProgramStatusType
impl ProgramStatusType
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.