#[repr(i32)]pub enum ProtoFmt {
Protobuf = 0,
Json = 1,
}Expand description
协议格式,请求协议在请求头中指定,推送协议在Init时指定
Variants
Implementations
Sourceimpl ProtoFmt
impl ProtoFmt
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.