#[repr(i32)]pub enum RetType {
Succeed = 0,
Failed = -1,
TimeOut = -100,
DisConnect = -200,
Unknown = -400,
Invalid = -500,
}Expand description
返回结果
Variants
Succeed = 0
成功
Failed = -1
失败
TimeOut = -100
超时
DisConnect = -200
连接断开
Unknown = -400
未知结果
Invalid = -500
包内容非法
Implementations
Sourceimpl RetType
impl RetType
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.