#[repr(i32)]pub enum UserAttribution {
Unknown = 0,
Nn = 1,
Mm = 2,
Sg = 3,
Au = 4,
Jp = 5,
Hk = 6,
}Expand description
用户注册归属地
Variants
Implementations
Sourceimpl UserAttribution
impl UserAttribution
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.