#[repr(i32)]pub enum QotPushStage {
Unkonw = 0,
Sr2ss = 1,
Ss2cr = 2,
Cr2cs = 3,
Ss2cs = 4,
Sr2cs = 5,
}Expand description
某段时间的统计数据 SR表示服务器收到数据,目前只有港股支持SR字段,SS表示服务器发出数据 CR表示OpenD收到数据,CS表示OpenD发出数据
Variants
Unkonw = 0
未知
Sr2ss = 1
统计服务端处理耗时
Ss2cr = 2
统计网络耗时
Cr2cs = 3
统计OpenD处理耗时
Ss2cs = 4
统计服务器发出到OpenD发出的处理耗时
Sr2cs = 5
统计服务器收到数据到OpenD发出的处理耗时
Implementations
Sourceimpl QotPushStage
impl QotPushStage
Sourceimpl QotPushStage
impl QotPushStage
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.