#[repr(i32)]pub enum UserInfoField {
Basic = 1,
Api = 2,
QotRight = 4,
Disclaimer = 8,
Update = 16,
WebKey = 2_048,
}Variants
Basic = 1
昵称,用户头像,牛牛号
Api = 2
API权限信息
QotRight = 4
市场的行情权限
Disclaimer = 8
免责
Update = 16
升级类型
WebKey = 2_048
Implementations
Sourceimpl UserInfoField
impl UserInfoField
Sourceimpl UserInfoField
impl UserInfoField
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.