#[repr(i32)]pub enum GtwEventType {
Show 16 variants
None = 0,
LocalCfgLoadFailed = 1,
ApiSvrRunFailed = 2,
ForceUpdate = 3,
LoginFailed = 4,
UnAgreeDisclaimer = 5,
NetCfgMissing = 6,
KickedOut = 7,
LoginPwdChanged = 8,
BanLogin = 9,
NeedPicVerifyCode = 10,
NeedPhoneVerifyCode = 11,
AppDataNotExist = 12,
NessaryDataMissing = 13,
TradePwdChanged = 14,
EnableDeviceLock = 15,
}Variants
None = 0
正常无错
LocalCfgLoadFailed = 1
加载本地配置失败
ApiSvrRunFailed = 2
服务器启动失败
ForceUpdate = 3
客户端版本过低
LoginFailed = 4
登录失败
UnAgreeDisclaimer = 5
未同意免责声明
NetCfgMissing = 6
缺少必要网络配置信息;例如控制订阅额度 //已优化,不会再出现该情况
KickedOut = 7
牛牛帐号在别处登录
LoginPwdChanged = 8
登录密码被修改
BanLogin = 9
用户被禁止登录
NeedPicVerifyCode = 10
需要图形验证码
NeedPhoneVerifyCode = 11
需要手机验证码
AppDataNotExist = 12
程序自带数据不存在
NessaryDataMissing = 13
缺少必要数据
TradePwdChanged = 14
交易密码被修改
EnableDeviceLock = 15
启用设备锁
Implementations
Sourceimpl GtwEventType
impl GtwEventType
Sourceimpl GtwEventType
impl GtwEventType
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.