#[repr(i32)]pub enum NotifyType {
None = 0,
GtwEvent = 1,
ProgramStatus = 2,
ConnStatus = 3,
QotRight = 4,
ApiLevel = 5,
ApiQuota = 6,
UsedQuota = 7,
}Variants
None = 0
无
GtwEvent = 1
OpenD运行事件通知
ProgramStatus = 2
程序状态
ConnStatus = 3
连接状态
QotRight = 4
行情权限
ApiLevel = 5
用户等级,已在2.10版本之后废弃
ApiQuota = 6
API额度
UsedQuota = 7
已使用额度
Implementations
Sourceimpl NotifyType
impl NotifyType
Sourceimpl NotifyType
impl NotifyType
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.