#[repr(i32)]pub enum BuySellType {
Unknown = 0,
NetBuy = 1,
NetSell = 2,
}Expand description
券商净买卖方向
Variants
Implementations
Sourceimpl BuySellType
impl BuySellType
Sourceimpl BuySellType
impl BuySellType
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.