#[repr(i32)]pub enum EarningsPubTimeType {
Unknown = 0,
PreMarket = 1,
AfterMarket = 2,
DuringMarket = 3,
}Expand description
财报发布时间类型
Variants
Implementations
Sourceimpl EarningsPubTimeType
impl EarningsPubTimeType
Sourcepub fn from_i32(value: i32) -> Option<EarningsPubTimeType>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<EarningsPubTimeType>
Use the TryFrom<i32> implementation instead
Converts an i32 to a EarningsPubTimeType, or None if value is not a valid variant.
Sourceimpl EarningsPubTimeType
impl EarningsPubTimeType
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.