#[repr(i32)]pub enum EcKlineSource {
None = 0,
OrderBookYes = 1,
}Expand description
事件合约K线来源(区分合约成交价K线与子合约摆盘K线)
Variants
Implementations
Sourceimpl EcKlineSource
impl EcKlineSource
Sourceimpl EcKlineSource
impl EcKlineSource
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.