#[repr(i32)]pub enum EcMilestoneType {
Unknown = 0,
FootballGame = 1,
BasketballGame = 2,
SoccerTournamentMultiLeg = 3,
BaseballTournament = 4,
BaseballGame = 5,
}Expand description
里程碑类型
Variants
Unknown = 0
未知/暂未支持
FootballGame = 1
橄榄球比赛
BasketballGame = 2
篮球比赛
SoccerTournamentMultiLeg = 3
足球锦标赛(多回合)
BaseballTournament = 4
棒球锦标赛
BaseballGame = 5
棒球比赛
Implementations
Sourceimpl EcMilestoneType
impl EcMilestoneType
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.