#[repr(i32)]pub enum EcStatus {
Show 17 variants
Initialized = 0,
Inactive = 1,
Active = 2,
Closed = 3,
Halted = 4,
Settled = 5,
Canceled = 6,
DeterminationPending = 7,
Determined = 8,
Finalized = 9,
EventAbnormal = 100,
EventInitialized = 101,
EventActive = 102,
EventClosed = 103,
EventSettled = 104,
EventCanceled = 105,
EventFinalized = 106,
}Expand description
事件合约生命周期状态(适用于 Series / Event / Contract)
Variants
Initialized = 0
–– 合约级状态 (Contract) ––
初始化(默认值/未知)
Inactive = 1
未激活
Active = 2
活跃(可交易)
Closed = 3
已关闭
Halted = 4
暂停交易
Settled = 5
已结算
Canceled = 6
已取消
DeterminationPending = 7
等待确认结果
Determined = 8
已确认结果
Finalized = 9
已完成
EventAbnormal = 100
–– 事件级状态 (Event) ––
事件异常
EventInitialized = 101
事件初始化
EventActive = 102
事件活跃
EventClosed = 103
事件已关闭
EventSettled = 104
事件已结算
EventCanceled = 105
事件已取消
EventFinalized = 106
事件已完成
Implementations
Sourceimpl EcStatus
impl EcStatus
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.