#[repr(i32)]pub enum ExchType {
Show 19 variants
Unknown = 0,
HkMainBoard = 1,
HkGemBoard = 2,
HkHkex = 3,
UsNyse = 4,
UsNasdaq = 5,
UsPink = 6,
UsAmex = 7,
UsOption = 8,
UsNymex = 9,
UsComex = 10,
UsCbot = 11,
UsCme = 12,
UsCboe = 13,
CnSh = 14,
CnSz = 15,
CnStib = 16,
SgSgx = 17,
JpOse = 18,
}Expand description
所属交易所
Variants
Unknown = 0
未知
HkMainBoard = 1
港交所·主板
HkGemBoard = 2
港交所·创业板
HkHkex = 3
港交所
UsNyse = 4
纽交所
UsNasdaq = 5
纳斯达克
UsPink = 6
OTC 市场
UsAmex = 7
美交所
UsOption = 8
美国(仅美股期权适用)
UsNymex = 9
NYMEX
UsComex = 10
COMEX
UsCbot = 11
CBOT
UsCme = 12
CME
UsCboe = 13
CBOE
CnSh = 14
上交所
CnSz = 15
深交所
CnStib = 16
科创板
SgSgx = 17
新交所
JpOse = 18
大阪交易所
Implementations
Sourceimpl ExchType
impl ExchType
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.