#[repr(i32)]pub enum F10Type {
Unknown = 0,
Q1 = 1,
Q2 = 2,
Q3 = 3,
Q4 = 4,
Q6 = 5,
Q9 = 6,
Annual = 7,
Quarterly = 9,
QuarterlyAnnual = 10,
MulQuarterly = 11,
}Expand description
财报类型
Variants
Unknown = 0
Q1 = 1
单季报,Q1
Q2 = 2
单季报,Q2
Q3 = 3
单季报,Q3
Q4 = 4
单季报,Q4
Q6 = 5
累计季报,Q6(Q1+Q2)
Q9 = 6
累计季报,Q9(Q1+Q2+Q3)
Annual = 7
年报
Quarterly = 9
单季报组合(Q1, Q2, Q3, Q4)
QuarterlyAnnual = 10
单季报 + 年报
MulQuarterly = 11
累计季报(Q1, Q6, Q9, Annual)
Implementations
Sourceimpl F10Type
impl F10Type
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.