HolderDetailType

Enum HolderDetailType 

#[repr(i32)]
pub enum HolderDetailType {
Show 22 variants Default = 0, All = 1_000, Unclassified = 1, TraditionalInvestmentManager = 2, HedgeFundManager = 3, VcOrPe = 4, CorporatePensionPlanSponsor = 5, FoundationFundSponsor = 6, InsuranceCompany = 7, BankOrInvestmentBank = 8, FamilyOfficesOrTrust = 9, SovereignWealthFund = 10, Reit = 11, StructuredFinancePoolManager = 12, UnionPensionPlanSponsor = 13, GovernmentPensionPlanSponsor = 14, EndowmentFundSponsor = 15, IndividualInsiders = 100, IssueSponsoredAdr = 200, CorporationsPublic = 300, CorporationsPrivate = 400, StateOwnedShares = 500,
}
股东持仓明细机构类型

Variants



Default = 0

默认不过滤,按服务端默认逻辑返回



All = 1_000

全部



Unclassified = 1

其他机构



TraditionalInvestmentManager = 2

传统投资经理



HedgeFundManager = 3

对冲基金



VcOrPe = 4

风险资本/私募股权投资



CorporatePensionPlanSponsor = 5

企业年金



FoundationFundSponsor = 6

基金会基金



InsuranceCompany = 7

保险公司



BankOrInvestmentBank = 8

银行/投资银行



FamilyOfficesOrTrust = 9

家族办公室/信托



SovereignWealthFund = 10

主权财富基金



Reit = 11

REIT



StructuredFinancePoolManager = 12

结构化融资经理



UnionPensionPlanSponsor = 13

联合养老金



GovernmentPensionPlanSponsor = 14

政府养老金



EndowmentFundSponsor = 15

捐赠基金



IndividualInsiders = 100

个人



IssueSponsoredAdr = 200

ADS



CorporationsPublic = 300

上市公司



CorporationsPrivate = 400

未公开上市公司



StateOwnedShares = 500

国有股

Implementations

Source

impl HolderDetailType

pub fn is_valid(value: i32) -> bool

Returns true if value is a variant of HolderDetailType.

pub fn from_i32(value: i32) -> Option<HolderDetailType>

👎Deprecated:

Use the TryFrom<i32> implementation instead

Converts an i32 to a HolderDetailType, or None if value is not a valid variant.

Source

impl HolderDetailType

pub fn as_str_name(&self) -> &'static str

String value of the enum field names used in the ProtoBuf definition.

The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.

pub fn from_str_name(value: &str) -> Option<Self>

Creates an enum from field names used in the ProtoBuf definition.