#[repr(i32)]pub enum IndicatorLineType {
Unknown = 0,
Solid = 1,
Dashed = 2,
Dot = 3,
Cross = 4,
Circle = 5,
Histogram = 6,
HistogramLine = 7,
Step = 8,
StepDiamonds = 9,
}Expand description
指标线型
Variants
Unknown = 0
未知/未指定
Solid = 1
实线
Dashed = 2
虚线
Dot = 3
点线
Cross = 4
交叉线
Circle = 5
圆点连线
Histogram = 6
柱状图
HistogramLine = 7
柱线混合
Step = 8
阶梯线
StepDiamonds = 9
阶梯+菱形
Implementations
Sourceimpl IndicatorLineType
impl IndicatorLineType
Sourcepub const fn is_valid(value: i32) -> bool
pub const fn is_valid(value: i32) -> bool
Returns true if value is a variant of IndicatorLineType.
Sourcepub fn from_i32(value: i32) -> Option<IndicatorLineType>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<IndicatorLineType>
Use the TryFrom<i32> implementation instead
Converts an i32 to a IndicatorLineType, or None if value is not a valid variant.
Sourceimpl IndicatorLineType
impl IndicatorLineType
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.