#[repr(i32)]pub enum IndicatorParamValueType {
Unknown = 0,
Int = 1,
Float = 2,
String = 3,
Color = 4,
Shape = 5,
Line = 6,
Bool = 7,
}Expand description
指标参数值类型枚举
Variants
Unknown = 0
未知
Int = 1
整数
Float = 2
浮点
String = 3
字符串
Color = 4
颜色
Shape = 5
形状
Line = 6
线型
Bool = 7
布尔
Implementations
Sourceimpl IndicatorParamValueType
impl IndicatorParamValueType
Sourcepub const fn is_valid(value: i32) -> bool
pub const fn is_valid(value: i32) -> bool
Returns true if value is a variant of IndicatorParamValueType.
Sourcepub fn from_i32(value: i32) -> Option<IndicatorParamValueType>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<IndicatorParamValueType>
Use the TryFrom<i32> implementation instead
Converts an i32 to a IndicatorParamValueType, or None if value is not a valid variant.
Sourceimpl IndicatorParamValueType
impl IndicatorParamValueType
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.