#[repr(i32)]pub enum IndicatorSearchMode {
Partial = 0,
Exact = 1,
}Expand description
指标搜索模式
Variants
Implementations
Sourceimpl IndicatorSearchMode
impl IndicatorSearchMode
Sourcepub const fn is_valid(value: i32) -> bool
pub const fn is_valid(value: i32) -> bool
Returns true if value is a variant of IndicatorSearchMode.
Sourcepub fn from_i32(value: i32) -> Option<IndicatorSearchMode>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<IndicatorSearchMode>
Use the TryFrom<i32> implementation instead
Converts an i32 to a IndicatorSearchMode, or None if value is not a valid variant.
Sourceimpl IndicatorSearchMode
impl IndicatorSearchMode
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.