#[repr(i32)]pub enum IndicatorShape {
Show 13 variants
Unknown = 0,
Xcross = 1,
Cross = 2,
Circle = 3,
TriangleUp = 4,
TriangleDown = 5,
Flag = 6,
ArrowUp = 7,
ArrowDown = 8,
Square = 9,
Diamond = 10,
LabelUp = 11,
LabelDown = 12,
}Expand description
指标形状
Variants
Unknown = 0
未知
Xcross = 1
X 形十字
Cross = 2
十字
Circle = 3
圆形
TriangleUp = 4
上三角
TriangleDown = 5
下三角
Flag = 6
旗帜
ArrowUp = 7
上箭头
ArrowDown = 8
下箭头
Square = 9
方块
Diamond = 10
菱形
LabelUp = 11
上标签
LabelDown = 12
下标签
Implementations
Sourceimpl IndicatorShape
impl IndicatorShape
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.