#[repr(i32)]pub enum KlFields {
None = 0,
High = 1,
Open = 2,
Low = 4,
Close = 8,
LastClose = 16,
Volume = 32,
Turnover = 64,
TurnoverRate = 128,
Pe = 256,
ChangeRate = 512,
}Variants
None = 0
High = 1
最高价
Open = 2
开盘价
Low = 4
最低价
Close = 8
收盘价
LastClose = 16
昨收价
Volume = 32
成交量
Turnover = 64
成交额
TurnoverRate = 128
换手率
Pe = 256
市盈率
ChangeRate = 512
涨跌幅
Implementations
Sourceimpl KlFields
impl KlFields
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.