#[repr(i32)]pub enum KlType {
Unknown = 0,
KlType1min = 1,
Day = 2,
Week = 3,
Month = 4,
Year = 5,
KlType5min = 6,
KlType15min = 7,
KlType30min = 8,
KlType60min = 9,
KlType3min = 10,
Quarter = 11,
}Expand description
枚举值兼容旧协议定义
Variants
Unknown = 0
未知
KlType1min = 1
1分K
Day = 2
日K
Week = 3
周K
Month = 4
月K
Year = 5
年K
KlType5min = 6
5分K
KlType15min = 7
15分K
KlType30min = 8
30分K
KlType60min = 9
60分K
KlType3min = 10
3分K
Quarter = 11
季K
Implementations
Sourceimpl KlType
impl KlType
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.