#[repr(i32)]pub enum OptionSettlementMode {
Unknown = 0,
Am = 1,
Pm = 2,
}Expand description
期权结算方式
Variants
Implementations
Sourceimpl OptionSettlementMode
impl OptionSettlementMode
Sourcepub fn is_valid(value: i32) -> bool
pub fn is_valid(value: i32) -> bool
Returns true if value is a variant of OptionSettlementMode.
Sourcepub fn from_i32(value: i32) -> Option<OptionSettlementMode>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<OptionSettlementMode>
Converts an i32 to a OptionSettlementMode, or None if value is not a valid variant.
Sourceimpl OptionSettlementMode
impl OptionSettlementMode
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.