#[repr(i32)]pub enum OptionStrategyType {
Show 14 variants
Unknown = 0,
SingleOption = 1,
Covered = 2,
Spread = 4,
Straddle = 6,
Strangle = 7,
Collar = 8,
Butterfly = 9,
Condor = 11,
IronButterfly = 13,
IronCondor = 14,
CalendarSpread = 15,
DiagonalSpread = 16,
Customize = 100,
}Variants
Unknown = 0
未知
SingleOption = 1
单个期权
Covered = 2
股票担保
Spread = 4
垂直策略
Straddle = 6
跨式策略
Strangle = 7
宽跨式策略
Collar = 8
领式策略
Butterfly = 9
蝶式策略
Condor = 11
鹰式策略
IronButterfly = 13
铁蝶式策略
IronCondor = 14
铁鹰式策略
CalendarSpread = 15
日历策略
DiagonalSpread = 16
对角策略
Customize = 100
自定义策略
Implementations
Sourceimpl OptionStrategyType
impl OptionStrategyType
Sourcepub fn from_i32(value: i32) -> Option<OptionStrategyType>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<OptionStrategyType>
Use the TryFrom<i32> implementation instead
Converts an i32 to a OptionStrategyType, or None if value is not a valid variant.
Sourceimpl OptionStrategyType
impl OptionStrategyType
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.