#[repr(i32)]pub enum OptionVolatilityTimePeriodType {
Unknown = 0,
Week = 1,
Month = 2,
Quarter = 3,
HalfYear = 4,
Year = 5,
}Expand description
期权波动率查询时间周期
Variants
Implementations
Sourceimpl OptionVolatilityTimePeriodType
impl OptionVolatilityTimePeriodType
Sourcepub fn is_valid(value: i32) -> bool
pub fn is_valid(value: i32) -> bool
Returns true if value is a variant of OptionVolatilityTimePeriodType.
Sourcepub fn from_i32(value: i32) -> Option<OptionVolatilityTimePeriodType>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<OptionVolatilityTimePeriodType>
Use the TryFrom<i32> implementation instead
Converts an i32 to a OptionVolatilityTimePeriodType, or None if value is not a valid variant.
Sourceimpl OptionVolatilityTimePeriodType
impl OptionVolatilityTimePeriodType
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.