#[repr(i32)]pub enum PeriodType {
Unknown = 0,
Intraday = 1,
Day = 2,
Week = 3,
Month = 4,
}Expand description
周期类型
Variants
Implementations
Sourceimpl PeriodType
impl PeriodType
Sourceimpl PeriodType
impl PeriodType
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.