#[repr(i32)]pub enum PlateSetType {
All = 0,
Industry = 1,
Region = 2,
Concept = 3,
Other = 4,
}Variants
All = 0
所有板块
Industry = 1
行业板块
Region = 2
地域板块,港美股市场的地域分类数据暂为空
Concept = 3
概念板块
Other = 4
其他板块, 仅用于3207(获取股票所属板块)协议返回,不可作为其他协议的请求参数
Implementations
Sourceimpl PlateSetType
impl PlateSetType
Sourceimpl PlateSetType
impl PlateSetType
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.