#[repr(i32)]pub enum PriceReminderFreq {
Unknown = 0,
Always = 1,
OnceADay = 2,
OnlyOnce = 3,
}Expand description
提醒频率
Variants
Implementations
Sourceimpl PriceReminderFreq
impl PriceReminderFreq
Sourcepub const fn is_valid(value: i32) -> bool
pub const fn is_valid(value: i32) -> bool
Returns true if value is a variant of PriceReminderFreq.
Sourcepub fn from_i32(value: i32) -> Option<PriceReminderFreq>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<PriceReminderFreq>
Use the TryFrom<i32> implementation instead
Converts an i32 to a PriceReminderFreq, or None if value is not a valid variant.
Sourceimpl PriceReminderFreq
impl PriceReminderFreq
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.