#[repr(i32)]pub enum PriceReminderType {
Show 16 variants
Unknown = 0,
PriceUp = 1,
PriceDown = 2,
ChangeRateUp = 3,
ChangeRateDown = 4,
PriceReminderType5minChangeRateUp = 5,
PriceReminderType5minChangeRateDown = 6,
VolumeUp = 7,
TurnoverUp = 8,
TurnoverRateUp = 9,
BidPriceUp = 10,
AskPriceDown = 11,
BidVolUp = 12,
AskVolUp = 13,
PriceReminderType3minChangeRateUp = 14,
PriceReminderType3minChangeRateDown = 15,
}Expand description
提醒类型
Variants
Unknown = 0
未知
PriceUp = 1
价格涨到
PriceDown = 2
价格跌到
ChangeRateUp = 3
日涨幅超(该字段为百分比字段,设置时填 20 表示 20%)
ChangeRateDown = 4
日跌幅超(该字段为百分比字段,设置时填 20 表示 20%)
PriceReminderType5minChangeRateUp = 5
5 分钟涨幅超(该字段为百分比字段,设置时填 20 表示 20%)
PriceReminderType5minChangeRateDown = 6
5 分钟跌幅超(该字段为百分比字段,设置时填 20 表示 20%)
VolumeUp = 7
成交量超过
TurnoverUp = 8
成交额超过
TurnoverRateUp = 9
换手率超过(该字段为百分比字段,设置时填 20 表示 20%)
BidPriceUp = 10
买一价高于
AskPriceDown = 11
卖一价低于
BidVolUp = 12
买一量高于
AskVolUp = 13
卖一量高于
PriceReminderType3minChangeRateUp = 14
3 分钟涨幅超(该字段为百分比字段,设置时填 20 表示 20%)
PriceReminderType3minChangeRateDown = 15
3 分钟跌幅超(该字段为百分比字段,设置时填 20 表示 20%)
Implementations
Sourceimpl PriceReminderType
impl PriceReminderType
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.