#[repr(i32)]pub enum PriceType {
Unknow = 0,
Outside = 1,
WithIn = 2,
}Expand description
窝轮价外/内,界内证表示界内界外
Variants
Implementations
Sourceimpl PriceType
impl PriceType
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.