#[repr(i32)]pub enum PushDataType {
Unknow = 0,
Realtime = 1,
ByDisConn = 2,
Cache = 3,
}Expand description
推送数据的分类,目前只有逐笔在使用
Variants
Implementations
Sourceimpl PushDataType
impl PushDataType
Sourceimpl PushDataType
impl PushDataType
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.