#[repr(i32)]pub enum QotMarket {
Unknown = 0,
HkSecurity = 1,
HkFuture = 2,
UsSecurity = 11,
CnshSecurity = 21,
CnszSecurity = 22,
SgSecurity = 31,
JpSecurity = 41,
AuSecurity = 51,
MySecurity = 61,
CaSecurity = 71,
FxSecurity = 81,
}Variants
Unknown = 0
未知市场
HkSecurity = 1
香港市场
HkFuture = 2
港期货(已废弃,使用QotMarket_HK_Security即可)
UsSecurity = 11
美国市场
CnshSecurity = 21
沪股市场
CnszSecurity = 22
深股市场
SgSecurity = 31
新加坡市场
JpSecurity = 41
日本市场
AuSecurity = 51
澳大利亚市场
MySecurity = 61
马来西亚市场
CaSecurity = 71
加拿大市场
FxSecurity = 81
外汇市场
Implementations
Sourceimpl QotMarket
impl QotMarket
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.