#[repr(i32)]pub enum QotMarketState {
Show 37 variants
None = 0,
Auction = 1,
WaitingOpen = 2,
Morning = 3,
Rest = 4,
Afternoon = 5,
Closed = 6,
PreMarketBegin = 8,
PreMarketEnd = 9,
AfterHoursBegin = 10,
AfterHoursEnd = 11,
FutuSwitchDate = 12,
NightOpen = 13,
NightEnd = 14,
FutureDayOpen = 15,
FutureDayBreak = 16,
FutureDayClose = 17,
FutureDayWaitForOpen = 18,
HkCas = 19,
FutureNightWait = 20,
FutureAfternoon = 21,
FutureSwitchDate = 22,
FutureOpen = 23,
FutureBreak = 24,
FutureBreakOver = 25,
FutureClose = 26,
StibAfterHoursWait = 27,
StibAfterHoursBegin = 28,
StibAfterHoursEnd = 29,
CloseAuction = 30,
AfternoonEnd = 31,
Night = 32,
OvernightBegin = 33,
OvernightEnd = 34,
TradeAtLast = 35,
TradeAuction = 36,
Overnight = 37,
}Variants
None = 0
无交易
Auction = 1
竞价
WaitingOpen = 2
早盘前等待开盘
Morning = 3
早盘
Rest = 4
午间休市
Afternoon = 5
午盘
Closed = 6
收盘
PreMarketBegin = 8
盘前
PreMarketEnd = 9
盘前结束
AfterHoursBegin = 10
盘后
AfterHoursEnd = 11
盘后结束
FutuSwitchDate = 12
NightOpen = 13
夜市开盘
NightEnd = 14
夜市收盘
FutureDayOpen = 15
期货日市开盘
FutureDayBreak = 16
期货日市休市
FutureDayClose = 17
期货日市收盘
FutureDayWaitForOpen = 18
期货日市等待开盘
HkCas = 19
盘后竞价,港股市场增加CAS机制对应的市场状态
FutureNightWait = 20
夜市等待开盘(已废弃)
FutureAfternoon = 21
期货下午开盘(已废弃)
FutureSwitchDate = 22
美国期货新增加状态
期货切交易日(已废弃)
FutureOpen = 23
期货开盘
FutureBreak = 24
期货中盘休息
FutureBreakOver = 25
期货休息后开盘
FutureClose = 26
期货收盘
StibAfterHoursWait = 27
科创板新增状态
科创板的盘后撮合时段(已废弃)
StibAfterHoursBegin = 28
科创板的盘后交易开始(已废弃)
StibAfterHoursEnd = 29
科创板的盘后交易结束(已废弃)
CloseAuction = 30
收市竞价
AfternoonEnd = 31
已收盘
Night = 32
交易中
OvernightBegin = 33
夜盘开始
OvernightEnd = 34
夜盘结束
TradeAtLast = 35
收盘前成交(在交易时间表内)
TradeAuction = 36
收盘前的竞价 (在交易时间表内)
Overnight = 37
美股夜盘交易时段
Implementations
Sourceimpl QotMarketState
impl QotMarketState
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.