#[repr(i32)]pub enum ResearchRatingDimensionType {
Unknown = 0,
Institution = 1,
Analyst = 2,
}Expand description
研报评级汇总-评级维度
Variants
Implementations
Sourceimpl ResearchRatingDimensionType
impl ResearchRatingDimensionType
Sourcepub fn is_valid(value: i32) -> bool
pub fn is_valid(value: i32) -> bool
Returns true if value is a variant of ResearchRatingDimensionType.
Sourcepub fn from_i32(value: i32) -> Option<ResearchRatingDimensionType>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<ResearchRatingDimensionType>
Use the TryFrom<i32> implementation instead
Converts an i32 to a ResearchRatingDimensionType, or None if value is not a valid variant.
Sourceimpl ResearchRatingDimensionType
impl ResearchRatingDimensionType
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.