#[repr(i32)]pub enum ResearchRatingType {
Unknown = 0,
Sell = 1,
Underperform = 2,
Hold = 3,
Buy = 4,
StrongBuy = 5,
}Expand description
分析师评级
Variants
Unknown = 0
未知
Sell = 1
Sell(卖出)
Underperform = 2
Underperform(跑输大盘)
Hold = 3
Hold(持有)
Buy = 4
Buy(买入)
StrongBuy = 5
Strong Buy(强力推荐)
Implementations
Sourceimpl ResearchRatingType
impl ResearchRatingType
Sourcepub fn from_i32(value: i32) -> Option<ResearchRatingType>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<ResearchRatingType>
Use the TryFrom<i32> implementation instead
Converts an i32 to a ResearchRatingType, or None if value is not a valid variant.
Sourceimpl ResearchRatingType
impl ResearchRatingType
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.