#[repr(i32)]pub enum RevenueBreakdownType {
Unknown = 0,
Product = 1,
Industry = 2,
Region = 4,
Business = 8,
}Expand description
主营构成维度类型
Variants
Implementations
Sourceimpl RevenueBreakdownType
impl RevenueBreakdownType
Sourcepub fn is_valid(value: i32) -> bool
pub fn is_valid(value: i32) -> bool
Returns true if value is a variant of RevenueBreakdownType.
Sourcepub fn from_i32(value: i32) -> Option<RevenueBreakdownType>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<RevenueBreakdownType>
Use the TryFrom<i32> implementation instead
Converts an i32 to a RevenueBreakdownType, or None if value is not a valid variant.
Sourceimpl RevenueBreakdownType
impl RevenueBreakdownType
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.