SortField

Enum SortField 

#[repr(i32)]
pub enum SortField {
Show 51 variants Unknow = 0, Code = 1, CurPrice = 2, PriceChangeVal = 3, ChangeRate = 4, Status = 5, BidPrice = 6, AskPrice = 7, BidVol = 8, AskVol = 9, Volume = 10, Turnover = 11, Amplitude = 30, Score = 12, Premium = 13, EffectiveLeverage = 14, Delta = 15, ImpliedVolatility = 16, Type = 17, StrikePrice = 18, BreakEvenPoint = 19, MaturityTime = 20, ListTime = 21, LastTradeTime = 22, Leverage = 23, InOutMoney = 24, RecoveryPrice = 25, ChangePrice = 26, Change = 27, StreetRate = 28, StreetVol = 29, WarrantName = 31, Issuer = 32, LotSize = 33, IssueSize = 34, UpperStrikePrice = 45, LowerStrikePrice = 46, InLinePriceStatus = 47, PreCurPrice = 35, AfterCurPrice = 36, PrePriceChangeVal = 37, AfterPriceChangeVal = 38, PreChangeRate = 39, AfterChangeRate = 40, PreAmplitude = 41, AfterAmplitude = 42, PreTurnover = 43, AfterTurnover = 44, LastSettlePrice = 48, Position = 49, PositionChange = 50,
}
窝轮排序

Variants



Unknow = 0



Code = 1

代码



CurPrice = 2

最新价



PriceChangeVal = 3

涨跌额



ChangeRate = 4

涨跌幅%



Status = 5

状态



BidPrice = 6

买入价



AskPrice = 7

卖出价



BidVol = 8

买量



AskVol = 9

卖量



Volume = 10

成交量



Turnover = 11

成交额



Amplitude = 30

振幅%



Score = 12

以下排序字段只支持用于Qot_GetWarrant协议

综合评分



Premium = 13

溢价%



EffectiveLeverage = 14

有效杠杆



Delta = 15

对冲值,仅认购认沽支持该字段



ImpliedVolatility = 16

引伸波幅,仅认购认沽支持该字段



Type = 17

类型



StrikePrice = 18

行权价



BreakEvenPoint = 19

打和点



MaturityTime = 20

到期日



ListTime = 21

上市日期



LastTradeTime = 22

最后交易日



Leverage = 23

杠杆比率



InOutMoney = 24

价内/价外%



RecoveryPrice = 25

收回价,仅牛熊证支持该字段



ChangePrice = 26

换股价



Change = 27

换股比率



StreetRate = 28

街货比%



StreetVol = 29

街货量



WarrantName = 31

窝轮名称



Issuer = 32

发行人



LotSize = 33

每手



IssueSize = 34

发行量



UpperStrikePrice = 45

上限价,仅用于界内证



LowerStrikePrice = 46

下限价,仅用于界内证



InLinePriceStatus = 47

界内界外,仅用于界内证



PreCurPrice = 35

以下排序字段只支持用于Qot_GetPlateSecurity协议,并仅支持美股

盘前最新价



AfterCurPrice = 36

盘后最新价



PrePriceChangeVal = 37

盘前涨跌额



AfterPriceChangeVal = 38

盘后涨跌额



PreChangeRate = 39

盘前涨跌幅%



AfterChangeRate = 40

盘后涨跌幅%



PreAmplitude = 41

盘前振幅%



AfterAmplitude = 42

盘后振幅%



PreTurnover = 43

盘前成交额



AfterTurnover = 44

盘后成交额



LastSettlePrice = 48

以下排序字段只支持用于Qot_GetPlateSecurity协议,并仅支持期货

昨结



Position = 49

持仓量



PositionChange = 50

日增仓

Implementations

Source

impl SortField

pub fn is_valid(value: i32) -> bool

Returns true if value is a variant of SortField.

pub fn from_i32(value: i32) -> Option<SortField>

👎Deprecated: Use the TryFrom<i32> implementation instead

Converts an i32 to a SortField, or None if value is not a valid variant.

Source

impl SortField

pub fn as_str_name(&self) -> &'static str

String value of the enum field names used in the ProtoBuf definition.

The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.

pub fn from_str_name(value: &str) -> Option<Self>

Creates an enum from field names used in the ProtoBuf definition.