#[repr(i32)]pub enum ValuationIntervalType {
Unknown = 0,
Month3 = 1,
Month6 = 2,
Year1 = 3,
Year3 = 4,
Since2019 = 5,
Year5 = 6,
Year10 = 7,
Year2 = 8,
Year20 = 9,
Year30 = 10,
}Expand description
估值历史区间类型
Variants
Unknown = 0
未知
Month3 = 1
3个月
Month6 = 2
6个月
Year1 = 3
1年
Year3 = 4
3年
Since2019 = 5
从2019年起
Year5 = 6
5年
Year10 = 7
10年
Year2 = 8
2年
Year20 = 9
20年
Year30 = 10
30年
Implementations
Sourceimpl ValuationIntervalType
impl ValuationIntervalType
Sourcepub fn is_valid(value: i32) -> bool
pub fn is_valid(value: i32) -> bool
Returns true if value is a variant of ValuationIntervalType.
Sourcepub fn from_i32(value: i32) -> Option<ValuationIntervalType>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<ValuationIntervalType>
Use the TryFrom<i32> implementation instead
Converts an i32 to a ValuationIntervalType, or None if value is not a valid variant.
Sourceimpl ValuationIntervalType
impl ValuationIntervalType
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.