#[repr(i32)]pub enum ValuationType {
Unknown = 0,
Pe = 1,
Pb = 2,
Ps = 3,
}Expand description
估值类型
Variants
Implementations
Sourceimpl ValuationType
impl ValuationType
Sourceimpl ValuationType
impl ValuationType
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.