pub struct PreAfterMarketData {
pub price: Option<f64>,
pub high_price: Option<f64>,
pub low_price: Option<f64>,
pub volume: Option<i64>,
pub turnover: Option<f64>,
pub change_val: Option<f64>,
pub change_rate: Option<f64>,
pub amplitude: Option<f64>,
}Expand description
美股支持盘前盘后数据 科创板仅支持盘后数据:成交量,成交额
Fields
price: Option<f64>盘前或盘后 - 价格
high_price: Option<f64>盘前或盘后 - 最高价
low_price: Option<f64>盘前或盘后 - 最低价
volume: Option<i64>盘前或盘后 - 成交量
turnover: Option<f64>盘前或盘后 - 成交额
change_val: Option<f64>盘前或盘后 - 涨跌额
change_rate: Option<f64>盘前或盘后 - 涨跌幅(该字段为百分比字段,默认不展示%,如20实际对应20%)
amplitude: Option<f64>盘前或盘后 - 振幅(该字段为百分比字段,默认不展示%,如20实际对应20%)
Implementations
Sourceimpl PreAfterMarketData
impl PreAfterMarketData
Sourcepub fn high_price(&self) -> f64
pub fn high_price(&self) -> f64
Returns the value of high_price, or the default value if high_price is unset.
Sourcepub fn low_price(&self) -> f64
pub fn low_price(&self) -> f64
Returns the value of low_price, or the default value if low_price is unset.
Sourcepub fn volume(&self) -> i64
pub fn volume(&self) -> i64
Returns the value of volume, or the default value if volume is unset.
Sourcepub fn turnover(&self) -> f64
pub fn turnover(&self) -> f64
Returns the value of turnover, or the default value if turnover is unset.
Sourcepub fn change_val(&self) -> f64
pub fn change_val(&self) -> f64
Returns the value of change_val, or the default value if change_val is unset.
Sourcepub fn change_rate(&self) -> f64
pub fn change_rate(&self) -> f64
Returns the value of change_rate, or the default value if change_rate is unset.