Rehab

Struct Rehab 

pub struct Rehab {
Show 25 fields pub time: String, pub company_act_flag: i64, pub fwd_factor_a: f64, pub fwd_factor_b: f64, pub bwd_factor_a: f64, pub bwd_factor_b: f64, pub split_base: Option<i32>, pub split_ert: Option<i32>, pub join_base: Option<i32>, pub join_ert: Option<i32>, pub bonus_base: Option<i32>, pub bonus_ert: Option<i32>, pub transfer_base: Option<i32>, pub transfer_ert: Option<i32>, pub allot_base: Option<i32>, pub allot_ert: Option<i32>, pub allot_price: Option<f64>, pub add_base: Option<i32>, pub add_ert: Option<i32>, pub add_price: Option<f64>, pub dividend: Option<f64>, pub sp_dividend: Option<f64>, pub spin_off_base: Option<f64>, pub spin_off_ert: Option<f64>, pub timestamp: Option<f64>,
}

Fields

time: String

时间字符串

company_act_flag: i64

公司行动(CompanyAct)组合标志位,指定某些字段值是否有效

fwd_factor_a: f64

前复权因子A

fwd_factor_b: f64

前复权因子B

bwd_factor_a: f64

后复权因子A

bwd_factor_b: f64

后复权因子B

split_base: Option<i32>

拆股(例如,1拆5,Base为1,Ert为5)

split_ert: Option<i32>join_base: Option<i32>

合股(例如,50合1,Base为50,Ert为1)

join_ert: Option<i32>bonus_base: Option<i32>

送股(例如,10送3, Base为10,Ert为3)

bonus_ert: Option<i32>transfer_base: Option<i32>

转赠股(例如,10转3, Base为10,Ert为3)

transfer_ert: Option<i32>allot_base: Option<i32>

配股(例如,10送2, 配股价为6.3元, Base为10, Ert为2, Price为6.3)

allot_ert: Option<i32>allot_price: Option<f64>add_base: Option<i32>

增发股(例如,10送2, 增发股价为6.3元, Base为10, Ert为2, Price为6.3)

add_ert: Option<i32>add_price: Option<f64>dividend: Option<f64>

现金分红(例如,每10股派现0.5元,则该字段值为0.05)

sp_dividend: Option<f64>

特别股息(例如,每10股派特别股息0.5元,则该字段值为0.05)

spin_off_base: Option<f64>

分立

spin_off_ert: Option<f64>
timestamp: Option<f64>

时间戳

Implementations

Source

impl Rehab

pub fn split_base(&self) -> i32

Returns the value of split_base, or the default value if split_base is unset.

pub fn split_ert(&self) -> i32

Returns the value of split_ert, or the default value if split_ert is unset.

pub fn join_base(&self) -> i32

Returns the value of join_base, or the default value if join_base is unset.

pub fn join_ert(&self) -> i32

Returns the value of join_ert, or the default value if join_ert is unset.

pub fn bonus_base(&self) -> i32

Returns the value of bonus_base, or the default value if bonus_base is unset.

pub fn bonus_ert(&self) -> i32

Returns the value of bonus_ert, or the default value if bonus_ert is unset.

pub fn transfer_base(&self) -> i32

Returns the value of transfer_base, or the default value if transfer_base is unset.

pub fn transfer_ert(&self) -> i32

Returns the value of transfer_ert, or the default value if transfer_ert is unset.

pub fn allot_base(&self) -> i32

Returns the value of allot_base, or the default value if allot_base is unset.

pub fn allot_ert(&self) -> i32

Returns the value of allot_ert, or the default value if allot_ert is unset.

pub fn allot_price(&self) -> f64

Returns the value of allot_price, or the default value if allot_price is unset.

pub fn add_base(&self) -> i32

Returns the value of add_base, or the default value if add_base is unset.

pub fn add_ert(&self) -> i32

Returns the value of add_ert, or the default value if add_ert is unset.

pub fn add_price(&self) -> f64

Returns the value of add_price, or the default value if add_price is unset.

pub fn dividend(&self) -> f64

Returns the value of dividend, or the default value if dividend is unset.

pub fn sp_dividend(&self) -> f64

Returns the value of sp_dividend, or the default value if sp_dividend is unset.

pub fn timestamp(&self) -> f64

Returns the value of timestamp, or the default value if timestamp is unset.

pub fn spin_off_base(&self) -> f64

Returns the value of spin_off_base, or the default value if spin_off_base is unset.

pub fn spin_off_ert(&self) -> f64

Returns the value of spin_off_ert, or the default value if spin_off_ert is unset.