pub struct ArkFundHoldingItem {
pub security: Option<Security>,
pub name: Option<String>,
pub shares: Option<i64>,
pub shares_change: Option<i64>,
pub market_value: Option<f64>,
pub weight: Option<f64>,
pub weight_change: Option<f64>,
}Expand description
ARK基金持仓数据项
Fields
security: Option<Security>股票(stock_id有效时)
name: Option<String>名称
持仓数量
持仓数量变动
market_value: Option<f64>持仓市值(美元)
weight: Option<f64>持仓占比(%)
weight_change: Option<f64>持仓占比变动(%)
Implementations
Sourceimpl ArkFundHoldingItem
impl ArkFundHoldingItem
Returns the value of shares, or the default value if shares is unset.
Returns the value of shares_change, or the default value if shares_change is unset.
Sourcepub fn market_value(&self) -> f64
pub fn market_value(&self) -> f64
Returns the value of market_value, or the default value if market_value is unset.
Sourcepub fn weight(&self) -> f64
pub fn weight(&self) -> f64
Returns the value of weight, or the default value if weight is unset.
Sourcepub fn weight_change(&self) -> f64
pub fn weight_change(&self) -> f64
Returns the value of weight_change, or the default value if weight_change is unset.