#[repr(i32)]pub enum BondFieldId {
Show 18 variants
BondBuyPrice = 1,
BondSellPrice = 2,
BondMidPrice = 3,
BondStartPrice = 4,
BondBuyYtm = 5,
BondSellYtm = 6,
BondMidYtm = 7,
BondCoupon = 8,
BondExpiryDate = 9,
BondIssuer = 10,
BondRiskCountry = 11,
BondName = 12,
BondIsin = 13,
BondCurrency = 14,
BondType = 15,
BondRiskLevel = 16,
BondHighRiskTips = 17,
BondRemainYear = 18,
}Variants
BondBuyPrice = 1
BondSellPrice = 2
BondMidPrice = 3
BondStartPrice = 4
BondBuyYtm = 5
BondSellYtm = 6
BondMidYtm = 7
BondCoupon = 8
BondExpiryDate = 9
BondIssuer = 10
BondRiskCountry = 11
BondName = 12
BondIsin = 13
BondCurrency = 14
BondType = 15
BondRiskLevel = 16
BondHighRiskTips = 17
BondRemainYear = 18
Implementations
Sourceimpl BondFieldId
impl BondFieldId
Sourceimpl BondFieldId
impl BondFieldId
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.