pub struct CompanyLabItem {
pub name: Option<String>,
pub value: Option<String>,
pub field_type: Option<i32>,
}Expand description
公司详情标签项
Fields
name: Option<String>标签名
value: Option<String>标签对应信息
field_type: Option<i32>标签类型(详见 Qot_Common.CompanyProfileFieldType 定义)
Implementations
Sourceimpl CompanyLabItem
impl CompanyLabItem
Sourcepub fn value(&self) -> &str
pub fn value(&self) -> &str
Returns the value of value, or the default value if value is unset.
Sourcepub fn field_type(&self) -> CompanyProfileFieldType
pub fn field_type(&self) -> CompanyProfileFieldType
Returns the enum value of field_type, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_field_type(&mut self, value: CompanyProfileFieldType)
pub fn set_field_type(&mut self, value: CompanyProfileFieldType)
Sets field_type to the provided enum value.