ABuyBackItem

Struct ABuyBackItem 

pub struct ABuyBackItem {
Show 27 fields pub change_reg_date: Option<u64>, pub change_reg_date_str: Option<String>, pub change_date: Option<u64>, pub change_date_str: Option<String>, pub event_proce_desc: Option<String>, pub advance_date: Option<u64>, pub advance_date_str: Option<String>, pub meet_pass_date: Option<u64>, pub meet_pass_date_str: Option<String>, pub start_date: Option<u64>, pub start_date_str: Option<String>, pub end_date: Option<u64>, pub end_date_str: Option<String>, pub pay_date: Option<u64>, pub pay_date_str: Option<String>, pub seller: Option<String>, pub buy_back_mode: Option<String>, pub share_type: Option<String>, pub buy_back_sum: Option<i64>, pub buy_back_money: Option<f64>, pub percentage: Option<f64>, pub value_floor: Option<f64>, pub value_ceiling: Option<f64>, pub price_floor: Option<f64>, pub price_ceiling: Option<f64>, pub volume_floor: Option<f64>, pub volume_ceiling: Option<f64>,
}
A股回购单条记录

Fields

change_reg_date: Option<u64>

工商变更登记日时间戳(秒)

change_reg_date_str: Option<String>

工商变更登记日字符串,格式 YYYY-MM-DD,对应市场时区

change_date: Option<u64>

股份变动日时间戳(秒)

change_date_str: Option<String>

股份变动日字符串,格式 YYYY-MM-DD,对应市场时区

event_proce_desc: Option<String>

事件进程描述

advance_date: Option<u64>

预案公告日时间戳(秒)

advance_date_str: Option<String>

预案公告日字符串,格式 YYYY-MM-DD,对应市场时区

meet_pass_date: Option<u64>

股东大会通过日时间戳(秒)

meet_pass_date_str: Option<String>

股东大会通过日字符串,格式 YYYY-MM-DD,对应市场时区

start_date: Option<u64>

回购开始日时间戳(秒)

start_date_str: Option<String>

回购开始日字符串,格式 YYYY-MM-DD,对应市场时区

end_date: Option<u64>

回购截止日时间戳(秒)

end_date_str: Option<String>

回购截止日字符串,格式 YYYY-MM-DD,对应市场时区

pay_date: Option<u64>

支付日时间戳(秒)

pay_date_str: Option<String>

支付日字符串,格式 YYYY-MM-DD,对应市场时区

seller: Option<String>

出售方(股份被回购方)

buy_back_mode: Option<String>

回购方式

share_type: Option<String>

股份类别

buy_back_sum: Option<i64>

回购股数(股)

buy_back_money: Option<f64>

回购金额

percentage: Option<f64>

占已发行股份百分比,百分号前的值,如 12.34 表示 12.34%

value_floor: Option<f64>

拟回购资金总额下限

value_ceiling: Option<f64>

拟回购资金总额上限

price_floor: Option<f64>

回购价格下限

price_ceiling: Option<f64>

回购价格上限

volume_floor: Option<f64>

拟回购股数下限

volume_ceiling: Option<f64>

拟回购股数上限

Implementations

Source

impl ABuyBackItem

pub fn change_reg_date(&self) -> u64

Returns the value of change_reg_date, or the default value if change_reg_date is unset.

pub fn change_reg_date_str(&self) -> &str

Returns the value of change_reg_date_str, or the default value if change_reg_date_str is unset.

pub fn change_date(&self) -> u64

Returns the value of change_date, or the default value if change_date is unset.

pub fn change_date_str(&self) -> &str

Returns the value of change_date_str, or the default value if change_date_str is unset.

pub fn event_proce_desc(&self) -> &str

Returns the value of event_proce_desc, or the default value if event_proce_desc is unset.

pub fn advance_date(&self) -> u64

Returns the value of advance_date, or the default value if advance_date is unset.

pub fn advance_date_str(&self) -> &str

Returns the value of advance_date_str, or the default value if advance_date_str is unset.

pub fn meet_pass_date(&self) -> u64

Returns the value of meet_pass_date, or the default value if meet_pass_date is unset.

pub fn meet_pass_date_str(&self) -> &str

Returns the value of meet_pass_date_str, or the default value if meet_pass_date_str is unset.

pub fn start_date(&self) -> u64

Returns the value of start_date, or the default value if start_date is unset.

pub fn start_date_str(&self) -> &str

Returns the value of start_date_str, or the default value if start_date_str is unset.

pub fn end_date(&self) -> u64

Returns the value of end_date, or the default value if end_date is unset.

pub fn end_date_str(&self) -> &str

Returns the value of end_date_str, or the default value if end_date_str is unset.

pub fn pay_date(&self) -> u64

Returns the value of pay_date, or the default value if pay_date is unset.

pub fn pay_date_str(&self) -> &str

Returns the value of pay_date_str, or the default value if pay_date_str is unset.

pub fn seller(&self) -> &str

Returns the value of seller, or the default value if seller is unset.

pub fn buy_back_mode(&self) -> &str

Returns the value of buy_back_mode, or the default value if buy_back_mode is unset.

pub fn share_type(&self) -> &str

Returns the value of share_type, or the default value if share_type is unset.

pub fn buy_back_sum(&self) -> i64

Returns the value of buy_back_sum, or the default value if buy_back_sum is unset.

pub fn buy_back_money(&self) -> f64

Returns the value of buy_back_money, or the default value if buy_back_money is unset.

pub fn percentage(&self) -> f64

Returns the value of percentage, or the default value if percentage is unset.

pub fn value_floor(&self) -> f64

Returns the value of value_floor, or the default value if value_floor is unset.

pub fn value_ceiling(&self) -> f64

Returns the value of value_ceiling, or the default value if value_ceiling is unset.

pub fn price_floor(&self) -> f64

Returns the value of price_floor, or the default value if price_floor is unset.

pub fn price_ceiling(&self) -> f64

Returns the value of price_ceiling, or the default value if price_ceiling is unset.

pub fn volume_floor(&self) -> f64

Returns the value of volume_floor, or the default value if volume_floor is unset.

pub fn volume_ceiling(&self) -> f64

Returns the value of volume_ceiling, or the default value if volume_ceiling is unset.