pub struct HkDailyShortVolumeItem {
pub timestamp: Option<i64>,
pub timestamp_str: Option<String>,
pub shares_traded: Option<u64>,
pub turnover: Option<f64>,
pub short_sell_shares_traded: Option<u64>,
pub short_sell_turnover: Option<f64>,
pub open_price: Option<f64>,
pub close_price: Option<f64>,
pub last_close_price: Option<f64>,
pub daily_trade_avg_ratio: Option<f64>,
}Expand description
港股每日卖空单条记录
Fields
timestamp: Option<i64>数据所在交易日时间戳(秒,当日零点)
timestamp_str: Option<String>数据所在交易日字符串,格式 YYYY-MM-DD,对应市场时区
成交量(股)
turnover: Option<f64>成交额
做空成交量(股)
short_sell_turnover: Option<f64>做空成交额
open_price: Option<f64>开盘价
close_price: Option<f64>收盘价
last_close_price: Option<f64>上次收盘价
daily_trade_avg_ratio: Option<f64>日均成交比例,百分号前的值,如 12.34 表示 12.34%;timestamp 往前 20 交易日的日均
Implementations
Sourceimpl HkDailyShortVolumeItem
impl HkDailyShortVolumeItem
Sourcepub fn timestamp(&self) -> i64
pub fn timestamp(&self) -> i64
Returns the value of timestamp, or the default value if timestamp is unset.
Sourcepub fn timestamp_str(&self) -> &str
pub fn timestamp_str(&self) -> &str
Returns the value of timestamp_str, or the default value if timestamp_str is unset.
Returns the value of shares_traded, or the default value if shares_traded is unset.
Sourcepub fn turnover(&self) -> f64
pub fn turnover(&self) -> f64
Returns the value of turnover, or the default value if turnover is unset.
Returns the value of short_sell_shares_traded, or the default value if short_sell_shares_traded is unset.
Sourcepub fn short_sell_turnover(&self) -> f64
pub fn short_sell_turnover(&self) -> f64
Returns the value of short_sell_turnover, or the default value if short_sell_turnover is unset.
Sourcepub fn open_price(&self) -> f64
pub fn open_price(&self) -> f64
Returns the value of open_price, or the default value if open_price is unset.
Sourcepub fn close_price(&self) -> f64
pub fn close_price(&self) -> f64
Returns the value of close_price, or the default value if close_price is unset.
Sourcepub fn last_close_price(&self) -> f64
pub fn last_close_price(&self) -> f64
Returns the value of last_close_price, or the default value if last_close_price is unset.
Sourcepub fn daily_trade_avg_ratio(&self) -> f64
pub fn daily_trade_avg_ratio(&self) -> f64
Returns the value of daily_trade_avg_ratio, or the default value if daily_trade_avg_ratio is unset.