#[repr(i32)]pub enum SortField {
Unknown = 0,
DividendYieldTtm = 1,
AvgDividendYield5Y = 2,
DistributionFrequency = 3,
DividendGrowYear = 4,
DividendsTtm = 5,
PayoutRatioLfy = 6,
Price = 7,
MarketCap = 8,
ChangeRate = 9,
ChangeAmount = 10,
}Expand description
排序字段 (固定降序)
Variants
Unknown = 0
默认: HighYield→股息率TTM, DividendGrowth→连续增长年数
DividendYieldTtm = 1
股息率TTM
AvgDividendYield5Y = 2
5年平均股息率
DistributionFrequency = 3
派息频率
DividendGrowYear = 4
股息连续增长年数
DividendsTtm = 5
股息TTM
PayoutRatioLfy = 6
股息支付率LFY
Price = 7
价格
MarketCap = 8
市值
ChangeRate = 9
今日涨跌幅
ChangeAmount = 10
今日涨跌额
Implementations
Sourceimpl SortField
impl SortField
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.