DividendRankItem

Struct DividendRankItem 

pub struct DividendRankItem {
Show 14 fields pub security: Security, pub name: Option<String>, pub industry: Option<String>, pub cur_price: Option<f64>, pub change_rate: Option<f64>, pub change_amount: Option<f64>, pub market_cap: Option<f64>, pub dividend_yield_ttm: Option<f64>, pub avg_dividend_yield5_y: Option<f64>, pub distribution_frequency: Option<i32>, pub dividend_grow_year: Option<i32>, pub dividends_ttm: Option<f64>, pub payout_ratio_lfy: Option<f64>, pub next_payable_date: Option<String>,
}
股息排行数据项

Fields

security: Security

股票

name: Option<String>

名称

industry: Option<String>

行业

cur_price: Option<f64>

行情

最新价

change_rate: Option<f64>

今日涨跌幅 (%)

change_amount: Option<f64>

今日涨跌额

market_cap: Option<f64>

市值

dividend_yield_ttm: Option<f64>

股息

股息率TTM (%)

avg_dividend_yield5_y: Option<f64>

5年平均股息率 (%)

distribution_frequency: Option<i32>

派息频率 (1:年派, 2:半年派, 3:季派, 4:月派),不支持HK市场

dividend_grow_year: Option<i32>

股息连续增长年数

dividends_ttm: Option<f64>

股息TTM (金额)

payout_ratio_lfy: Option<f64>

股息支付率LFY (%)

next_payable_date: Option<String>

下次派息日 (“YYYY-MM-DD”)

Implementations

Source

impl DividendRankItem

pub fn name(&self) -> &str

Returns the value of name, or the default value if name is unset.

pub fn industry(&self) -> &str

Returns the value of industry, or the default value if industry is unset.

pub fn cur_price(&self) -> f64

Returns the value of cur_price, or the default value if cur_price is unset.

pub fn change_rate(&self) -> f64

Returns the value of change_rate, or the default value if change_rate is unset.

pub fn change_amount(&self) -> f64

Returns the value of change_amount, or the default value if change_amount is unset.

pub fn market_cap(&self) -> f64

Returns the value of market_cap, or the default value if market_cap is unset.

pub fn dividend_yield_ttm(&self) -> f64

Returns the value of dividend_yield_ttm, or the default value if dividend_yield_ttm is unset.

pub fn avg_dividend_yield5_y(&self) -> f64

Returns the value of avg_dividend_yield5_y, or the default value if avg_dividend_yield5_y is unset.

pub fn distribution_frequency(&self) -> i32

Returns the value of distribution_frequency, or the default value if distribution_frequency is unset.

pub fn dividend_grow_year(&self) -> i32

Returns the value of dividend_grow_year, or the default value if dividend_grow_year is unset.

pub fn dividends_ttm(&self) -> f64

Returns the value of dividends_ttm, or the default value if dividends_ttm is unset.

pub fn payout_ratio_lfy(&self) -> f64

Returns the value of payout_ratio_lfy, or the default value if payout_ratio_lfy is unset.

pub fn next_payable_date(&self) -> &str

Returns the value of next_payable_date, or the default value if next_payable_date is unset.