#[repr(i32)]pub enum BeatTerm {
Latest = 0,
LatestQuarter = 1,
LatestHalf = 2,
LatestAnnual = 3,
All = 4,
}Expand description
财报周期
Variants
Latest = 0
最近一期 (默认)
LatestQuarter = 1
最近一期季报
LatestHalf = 2
最近一期半年报
LatestAnnual = 3
最近一期年报
All = 4
全部(时间一样季报优先,时间不同最近一期)
Implementations
Sourceimpl BeatTerm
impl BeatTerm
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.