#[repr(i32)]pub enum SortField {
Unknown = 0,
BeatRatio = 1,
EarningDayChg = 2,
ReleasedDate = 3,
Actual = 4,
Estimate = 5,
Yoy = 6,
YoyGrowth = 7,
PeTtm = 8,
DividendsTtm = 9,
Price = 10,
ChangeRate = 11,
}Expand description
排序字段 (固定降序)
Variants
Unknown = 0
默认按市值排序
BeatRatio = 1
超预期比率
EarningDayChg = 2
财报后首日涨幅
ReleasedDate = 3
发布时间
Actual = 4
实际值
Estimate = 5
预测值
Yoy = 6
去年同期
YoyGrowth = 7
同比增长率
PeTtm = 8
市盈率TTM
DividendsTtm = 9
股息率TTM
Price = 10
价格
ChangeRate = 11
今日涨跌幅
Implementations
Sourceimpl SortField
impl SortField
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.