#[repr(i32)]pub enum EarningsCalendarEstimateType {
Unknown = 0,
Eps = 1,
Revenue = 2,
Ebit = 3,
}Expand description
财报指标类型
Variants
Implementations
Sourceimpl EarningsCalendarEstimateType
impl EarningsCalendarEstimateType
Sourcepub fn is_valid(value: i32) -> bool
pub fn is_valid(value: i32) -> bool
Returns true if value is a variant of EarningsCalendarEstimateType.
Sourcepub fn from_i32(value: i32) -> Option<EarningsCalendarEstimateType>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<EarningsCalendarEstimateType>
Use the TryFrom<i32> implementation instead
Converts an i32 to a EarningsCalendarEstimateType, or None if value is not a valid variant.
Sourceimpl EarningsCalendarEstimateType
impl EarningsCalendarEstimateType
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.