EarningsCalendarItem

Struct EarningsCalendarItem 

pub struct EarningsCalendarItem {
Show 13 fields pub security: Security, pub name: Option<String>, pub earnings_date: Option<String>, pub earnings_timestamp: Option<f64>, pub pub_type: Option<i32>, pub period_text: Option<String>, pub estimate_list: Vec<EstimateData>, pub option_volume: Option<i64>, pub iv: Option<f64>, pub iv_rank: Option<f64>, pub iv_percentile: Option<f64>, pub market_cap: Option<f64>, pub price: Option<f64>,
}
财报日历项

Fields

security: Security

股票

name: Option<String>

股票名称

earnings_date: Option<String>

财报日期(“yyyy-MM-dd”)

earnings_timestamp: Option<f64>

财报发布时间戳(秒)

pub_type: Option<i32>

EarningsCalendarPubType

period_text: Option<String>

财年周期(如“2025Q1“)

estimate_list: Vec<EstimateData>

预测数据列表

option_volume: Option<i64>

期权字段(仅港美股)

期权成交量

iv: Option<f64>

隐含波动率(%)

iv_rank: Option<f64>

IV等级(%)

iv_percentile: Option<f64>

IV百分位数(%)

market_cap: Option<f64>

行情字段

实时市值

price: Option<f64>

最新价

Implementations

Source

impl EarningsCalendarItem

pub fn name(&self) -> &str

Returns the value of name, or the default value if name is unset.

pub fn earnings_date(&self) -> &str

Returns the value of earnings_date, or the default value if earnings_date is unset.

pub fn earnings_timestamp(&self) -> f64

Returns the value of earnings_timestamp, or the default value if earnings_timestamp is unset.

pub fn pub_type(&self) -> i32

Returns the value of pub_type, or the default value if pub_type is unset.

pub fn period_text(&self) -> &str

Returns the value of period_text, or the default value if period_text is unset.

pub fn option_volume(&self) -> i64

Returns the value of option_volume, or the default value if option_volume is unset.

pub fn iv(&self) -> f64

Returns the value of iv, or the default value if iv is unset.

pub fn iv_rank(&self) -> f64

Returns the value of iv_rank, or the default value if iv_rank is unset.

pub fn iv_percentile(&self) -> f64

Returns the value of iv_percentile, or the default value if iv_percentile is unset.

pub fn market_cap(&self) -> f64

Returns the value of market_cap, or the default value if market_cap is unset.

pub fn price(&self) -> f64

Returns the value of price, or the default value if price is unset.