#[repr(i32)]pub enum Importance {
All = 0,
Low = 1,
Medium = 2,
High = 3,
}Expand description
事件重要性(星级)
Variants
Implementations
Sourceimpl Importance
impl Importance
Sourceimpl Importance
impl Importance
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.