#[repr(i32)]pub enum FieldId {
Show 81 variants
EtfName = 1,
EtfCode = 2,
MstarRating3y = 3,
AnnualYield3y = 4,
Price = 5,
PriceChange = 6,
RatioPriceChange = 7,
Volume = 8,
Turnover = 9,
AssetsSize = 10,
RatioTurnover = 11,
AmplitudePrice = 12,
Multiple = 13,
RatioVolume = 14,
RatioBidAsk = 15,
IsJpTradedEtf = 16,
FundCompany = 17,
IpoTimestamp = 18,
EtfTer = 19,
EtfMer = 20,
ManageFee = 21,
ThemePlateId = 22,
MstarRating = 23,
ManagementStyles = 24,
IsOptionsAvailable = 25,
AnnualReturn = 26,
CumulativeReturn = 27,
Return10000 = 28,
PerformanceRanking = 29,
LongestUptrend = 30,
DistributionYieldTtm = 31,
DividendFrequency = 32,
ExDividendDate = 33,
DividendPaymentDate = 34,
HoldingNum = 35,
HoldingRate = 36,
RegionDistribution = 37,
SectorDistribution = 38,
EquityStyleBox = 39,
FixedIncomeStyleBox = 40,
RiskRanking = 41,
TrackingError = 42,
ACoefficient = 43,
MaxDrawdown = 44,
MaxDrawdownRecDay = 45,
StandardDeviation = 46,
BCoefficient = 47,
RSquared = 48,
SharpeRatio = 49,
TreynorRatio = 50,
InformationRatio = 51,
SortinoRatio = 52,
CalmarRatio = 53,
VolumeDayAverage = 54,
PeRatio = 55,
PbRatio = 56,
PsRatio = 57,
Roa = 58,
Roe = 59,
ForcastEps5yGrowth = 60,
ForcastBps5yGrowth = 61,
ForcastRev5yGrowth = 62,
IndexEtfPlateId = 63,
UseOptionStrategy = 64,
DistributionYieldLfy = 65,
PremiumRate = 66,
HoldingRateList = 67,
RegionDistributionList = 68,
SectorDistributionList = 69,
HighDividendPlateId = 70,
ScreenPlateId = 71,
Hv = 72,
RelatedStockId = 73,
OpenPrice = 74,
PrevClosePrice = 75,
HighPrice = 76,
LowPrice = 77,
BidPrice = 78,
AskPrice = 79,
BidVolume = 80,
AskVolume = 81,
}Variants
EtfName = 1
EtfCode = 2
MstarRating3y = 3
AnnualYield3y = 4
Price = 5
PriceChange = 6
RatioPriceChange = 7
Volume = 8
Turnover = 9
AssetsSize = 10
RatioTurnover = 11
AmplitudePrice = 12
Multiple = 13
RatioVolume = 14
RatioBidAsk = 15
IsJpTradedEtf = 16
FundCompany = 17
IpoTimestamp = 18
EtfTer = 19
EtfMer = 20
ManageFee = 21
ThemePlateId = 22
MstarRating = 23
ManagementStyles = 24
IsOptionsAvailable = 25
AnnualReturn = 26
CumulativeReturn = 27
Return10000 = 28
PerformanceRanking = 29
LongestUptrend = 30
DistributionYieldTtm = 31
DividendFrequency = 32
ExDividendDate = 33
DividendPaymentDate = 34
HoldingNum = 35
HoldingRate = 36
RegionDistribution = 37
SectorDistribution = 38
EquityStyleBox = 39
FixedIncomeStyleBox = 40
RiskRanking = 41
TrackingError = 42
ACoefficient = 43
MaxDrawdown = 44
MaxDrawdownRecDay = 45
StandardDeviation = 46
BCoefficient = 47
RSquared = 48
SharpeRatio = 49
TreynorRatio = 50
InformationRatio = 51
SortinoRatio = 52
CalmarRatio = 53
VolumeDayAverage = 54
PeRatio = 55
PbRatio = 56
PsRatio = 57
Roa = 58
Roe = 59
ForcastEps5yGrowth = 60
ForcastBps5yGrowth = 61
ForcastRev5yGrowth = 62
IndexEtfPlateId = 63
UseOptionStrategy = 64
DistributionYieldLfy = 65
PremiumRate = 66
HoldingRateList = 67
RegionDistributionList = 68
SectorDistributionList = 69
HighDividendPlateId = 70
ScreenPlateId = 71
Hv = 72
RelatedStockId = 73
OpenPrice = 74
PrevClosePrice = 75
HighPrice = 76
LowPrice = 77
BidPrice = 78
AskPrice = 79
BidVolume = 80
AskVolume = 81
Implementations
Sourceimpl FieldId
impl FieldId
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.