#[repr(i32)]pub enum PeriodId {
Show 18 variants
PeriodNone = 0,
Period5Mintue = 1,
Period1Day = 2,
Period7Day = 3,
Period10Day = 4,
Period1Month = 5,
Period2Month = 6,
Period3Month = 7,
Period1Year = 8,
Period3Year = 9,
Period5Year = 10,
Period10Year = 11,
PeriodYtd = 12,
Period5Day = 13,
Period20Day = 14,
Period60Day = 15,
Period120Day = 16,
Period250Day = 17,
}Variants
PeriodNone = 0
Period5Mintue = 1
Period1Day = 2
Period7Day = 3
Period10Day = 4
Period1Month = 5
Period2Month = 6
Period3Month = 7
Period1Year = 8
Period3Year = 9
Period5Year = 10
Period10Year = 11
PeriodYtd = 12
Period5Day = 13
Period20Day = 14
Period60Day = 15
Period120Day = 16
Period250Day = 17
Implementations
Sourceimpl PeriodId
impl PeriodId
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.