pub struct ComboEvent {
pub event_security: Security,
pub event_name: Option<String>,
pub combo_contracts: Vec<Security>,
pub series_security: Option<Security>,
pub category: Option<String>,
pub competition: Option<String>,
pub competition_scope: Option<String>,
}Expand description
可 Combo 事件项
Fields
event_security: Security事件标的 {market=101, code=“EC.xxx”}
event_name: Option<String>事件名称(多语言)
combo_contracts: Vec<Security>可组合的合约列表(contract 级预览,全量走 Qot_GetEventContract)
series_security: Option<Security>所属 Series
category: Option<String>一级分类标识
competition: Option<String>赛事名称(多语言)
competition_scope: Option<String>赛事类型/玩法(多语言)
Implementations
Sourceimpl ComboEvent
impl ComboEvent
Sourcepub fn event_name(&self) -> &str
pub fn event_name(&self) -> &str
Returns the value of event_name, or the default value if event_name is unset.
Sourcepub fn category(&self) -> &str
pub fn category(&self) -> &str
Returns the value of category, or the default value if category is unset.
Sourcepub fn competition(&self) -> &str
pub fn competition(&self) -> &str
Returns the value of competition, or the default value if competition is unset.
Sourcepub fn competition_scope(&self) -> &str
pub fn competition_scope(&self) -> &str
Returns the value of competition_scope, or the default value if competition_scope is unset.