pub struct C2s {
pub security: Security,
pub kline_source: Option<i32>,
pub pre_side: Option<i32>,
pub ktype: Option<i32>,
pub max_count: Option<i32>,
}Fields
security: Security合约标的(单只,必填,contract_id)
kline_source: Option<i32>K线来源(None/OrderBookYes),优先级高于 preSide
pre_side: Option<i32>方向(klineSource=None 时必传 YES/NO)
ktype: Option<i32>K线类型,复用通用 KLType(仅支持 KLType_1Min/KLType_60Min/KLType_Day,其余报错)
max_count: Option<i32>最大返回条数(上限1000)
Implementations
Sourceimpl C2s
impl C2s
Sourcepub fn kline_source(&self) -> EcKlineSource
pub fn kline_source(&self) -> EcKlineSource
Returns the enum value of kline_source, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_kline_source(&mut self, value: EcKlineSource)
pub fn set_kline_source(&mut self, value: EcKlineSource)
Sets kline_source to the provided enum value.
Sourcepub fn pre_side(&self) -> PredSide
pub fn pre_side(&self) -> PredSide
Returns the enum value of pre_side, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_pre_side(&mut self, value: PredSide)
pub fn set_pre_side(&mut self, value: PredSide)
Sets pre_side to the provided enum value.