pub struct MilestoneItem {
pub milestone_security: Security,
pub title: Option<String>,
pub category: Option<String>,
pub type: Option<i32>,
pub start_date: Option<String>,
pub end_date: Option<String>,
pub primary_event_security: Option<Security>,
pub related_event_list: Vec<Security>,
pub notification_message: Option<String>,
}Expand description
里程碑项
Fields
milestone_security: Security里程碑标的
title: Option<String>里程碑名称(多语言)
category: Option<String>一级分类标识
type: Option<i32>里程碑类型
start_date: Option<String>开始时间(UTC ISO8601,形如 2025-09-26T18:30:00Z)
end_date: Option<String>结束时间(UTC ISO8601,形如 2025-09-26T18:30:00Z)
primary_event_security: Option<Security>主事件标的
关联事件标的列表
notification_message: Option<String>通知消息(多语言)
Implementations
Sourceimpl MilestoneItem
impl MilestoneItem
Sourcepub fn title(&self) -> &str
pub fn title(&self) -> &str
Returns the value of title, or the default value if title is unset.
Sourcepub fn category(&self) -> &str
pub fn category(&self) -> &str
Returns the value of category, or the default value if category is unset.
Sourcepub fn type(&self) -> EcMilestoneType
pub fn type(&self) -> EcMilestoneType
Returns the enum value of type, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_type(&mut self, value: EcMilestoneType)
pub fn set_type(&mut self, value: EcMilestoneType)
Sets type to the provided enum value.
Sourcepub fn start_date(&self) -> &str
pub fn start_date(&self) -> &str
Returns the value of start_date, or the default value if start_date is unset.
Sourcepub fn end_date(&self) -> &str
pub fn end_date(&self) -> &str
Returns the value of end_date, or the default value if end_date is unset.
Sourcepub fn notification_message(&self) -> &str
pub fn notification_message(&self) -> &str
Returns the value of notification_message, or the default value if notification_message is unset.