pub struct SeriesItem {
pub series_security: Security,
pub series_name: Option<String>,
pub category: Option<String>,
pub tags: Vec<String>,
pub frequency: Option<i32>,
}Expand description
Series 项
Fields
series_security: Security{market=101, code=“EC.KXRATECUTCOUNT”}
series_name: Option<String>Series 名称(多语言)
category: Option<String>一级分类标识
二级分类标识列表(一个 series 可归属多个 tag)
frequency: Option<i32>频率
Implementations
Sourceimpl SeriesItem
impl SeriesItem
Sourcepub fn series_name(&self) -> &str
pub fn series_name(&self) -> &str
Returns the value of series_name, or the default value if series_name is unset.
Sourcepub fn category(&self) -> &str
pub fn category(&self) -> &str
Returns the value of category, or the default value if category is unset.
Sourcepub fn frequency(&self) -> EcFrequency
pub fn frequency(&self) -> EcFrequency
Returns the enum value of frequency, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_frequency(&mut self, value: EcFrequency)
pub fn set_frequency(&mut self, value: EcFrequency)
Sets frequency to the provided enum value.