pub struct RevenueBreakdownGroup {
pub type: Option<i32>,
pub item_list: Vec<MainIncomeItem>,
}Expand description
单一维度主营构成数据
Fields
type: Option<i32>维度类型(详见 Qot_Common.RevenueBreakdownType 定义)
item_list: Vec<MainIncomeItem>该维度主营构成数据列表
Implementations
Sourceimpl RevenueBreakdownGroup
impl RevenueBreakdownGroup
Sourcepub fn type(&self) -> RevenueBreakdownType
pub fn type(&self) -> RevenueBreakdownType
Returns the enum value of type, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_type(&mut self, value: RevenueBreakdownType)
pub fn set_type(&mut self, value: RevenueBreakdownType)
Sets type to the provided enum value.