pub struct C2s {
pub security: Security,
pub statement_type: Option<i32>,
pub financial_type: Option<i32>,
pub currency_code: Option<String>,
pub next_key: Option<String>,
pub num: Option<i32>,
}Fields
security: Security股票
statement_type: Option<i32>财务报表类型(详见 Qot_Common.FinancialStatementsType 定义),默认利润表(Income=1)
financial_type: Option<i32>财报类型,详见 Qot_Common.F10Type 定义,支持 0-7, 9-11,默认 10(QuarterlyAnnual)
currency_code: Option<String>币种代码(ISO 4217),如 CNY、USD、HKD、SGD、JPY、CAD、AUD;不填返回原始货币数据
next_key: Option<String>分页标识,首次不填,续拉时填上次返回的 nextKey;“-1” 表示无更多数据
num: Option<i32>每页返回数量,默认 10,范围 1~50
Implementations
Sourceimpl C2s
impl C2s
Sourcepub fn statement_type(&self) -> FinancialStatementsType
pub fn statement_type(&self) -> FinancialStatementsType
Returns the enum value of statement_type, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_statement_type(&mut self, value: FinancialStatementsType)
pub fn set_statement_type(&mut self, value: FinancialStatementsType)
Sets statement_type to the provided enum value.
Sourcepub fn financial_type(&self) -> F10Type
pub fn financial_type(&self) -> F10Type
Returns the enum value of financial_type, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_financial_type(&mut self, value: F10Type)
pub fn set_financial_type(&mut self, value: F10Type)
Sets financial_type to the provided enum value.
Sourcepub fn currency_code(&self) -> &str
pub fn currency_code(&self) -> &str
Returns the value of currency_code, or the default value if currency_code is unset.