#[repr(i32)]pub enum FundType {
Show 17 variants
Currency = 1,
Bonds = 2,
Equity = 3,
Index = 4,
Balanced = 5,
Fof = 6,
Qdii = 7,
ShortTerm = 8,
FutuFof = 9,
StructuredNotes = 10,
Liquidity = 11,
Commodity = 12,
Alternative = 13,
Reit = 14,
CnavMmf = 15,
PrivateFund = 66,
Others = 1_000,
}Expand description
Static source catalogs. Dynamic company/theme/set identifiers are supplied by their server-owned discovery feeds and intentionally have no local enum.
Variants
Currency = 1
Bonds = 2
Equity = 3
Index = 4
Balanced = 5
Fof = 6
Qdii = 7
ShortTerm = 8
FutuFof = 9
StructuredNotes = 10
Liquidity = 11
Commodity = 12
Alternative = 13
Reit = 14
PrivateFund = 66
Others = 1_000
Implementations
Sourceimpl FundType
impl FundType
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.