pub struct IndicatorStrategyCondition {
pub strategy_id: u64,
pub period: i32,
pub over_similar: Option<Interval>,
}Fields
strategy_id: u64period: i32over_similar: Option<Interval>Trait Implementations
Sourceimpl Clone for IndicatorStrategyCondition
impl Clone for IndicatorStrategyCondition
Sourcefn clone(&self) -> IndicatorStrategyCondition
fn clone(&self) -> IndicatorStrategyCondition
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for IndicatorStrategyCondition
Sourceimpl Debug for IndicatorStrategyCondition
impl Debug for IndicatorStrategyCondition
Sourceimpl Default for IndicatorStrategyCondition
impl Default for IndicatorStrategyCondition
Sourceimpl<'de> Deserialize<'de> for IndicatorStrategyConditionwhere
IndicatorStrategyCondition: Default,
impl<'de> Deserialize<'de> for IndicatorStrategyConditionwhere
IndicatorStrategyCondition: Default,
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for IndicatorStrategyCondition
Sourceimpl Hash for IndicatorStrategyCondition
impl Hash for IndicatorStrategyCondition
Sourceimpl Message for IndicatorStrategyCondition
impl Message for IndicatorStrategyCondition
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for IndicatorStrategyCondition
impl PartialEq for IndicatorStrategyCondition
Sourcefn eq(&self, other: &IndicatorStrategyCondition) -> bool
fn eq(&self, other: &IndicatorStrategyCondition) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for IndicatorStrategyCondition