pub struct QuoteShowItem {
pub title: Option<String>,
pub value: Option<i64>,
pub precision: Option<u32>,
pub text: Option<String>,
pub content_type: Option<i32>,
pub color_text: Option<String>,
}Fields
title: Option<String>value: Option<i64>precision: Option<u32>text: Option<String>content_type: Option<i32>color_text: Option<String>Implementations
Sourceimpl QuoteShowItem
impl QuoteShowItem
Sourcepub fn title(&self) -> &str
pub fn title(&self) -> &str
Returns the value of title, or the default value if title is unset.
Sourcepub fn precision(&self) -> u32
pub fn precision(&self) -> u32
Returns the value of precision, or the default value if precision is unset.
Sourcepub fn content_type(&self) -> i32
pub fn content_type(&self) -> i32
Returns the value of content_type, or the default value if content_type is unset.
Sourcepub fn color_text(&self) -> &str
pub fn color_text(&self) -> &str
Returns the value of color_text, or the default value if color_text is unset.