#[repr(i32)]pub enum FutureFieldId {
Show 24 variants
FutureCode = 1,
FutureName = 2,
FuturePrice = 3,
FutureChangeRate = 4,
FutureChangePrice = 5,
FutureBuyPrice = 6,
FutureSellPrice = 7,
FutureBuyVolume = 8,
FutureSellVolume = 9,
FutureVolume = 10,
FutureHoldings = 11,
FutureDayAddVolume = 12,
FutureOpenPrice = 13,
FutureHighPrice = 14,
FutureLowPrice = 15,
FutureLastTradeDate = 16,
FutureLastTradePrice = 17,
FutureLastPrice = 18,
FutureMarket = 19,
FutureExchange = 20,
FutureType = 21,
FutureCurrency = 22,
FutureTradingStatus = 23,
FutureManageWeight = 24,
}Variants
FutureCode = 1
FutureName = 2
FuturePrice = 3
FutureChangeRate = 4
FutureChangePrice = 5
FutureBuyPrice = 6
FutureSellPrice = 7
FutureBuyVolume = 8
FutureSellVolume = 9
FutureVolume = 10
FutureHoldings = 11
FutureDayAddVolume = 12
FutureOpenPrice = 13
FutureHighPrice = 14
FutureLowPrice = 15
FutureLastTradeDate = 16
FutureLastTradePrice = 17
FutureLastPrice = 18
FutureMarket = 19
FutureExchange = 20
FutureType = 21
FutureCurrency = 22
FutureTradingStatus = 23
FutureManageWeight = 24
Implementations
Sourceimpl FutureFieldId
impl FutureFieldId
Sourceimpl FutureFieldId
impl FutureFieldId
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.