#[repr(i32)]pub enum FutureScreenCurrencyItems {
CurrencyUsd = 1,
CurrencyHkd = 2,
CurrencyCnh = 3,
CurrencyJpy = 4,
CurrencySgd = 5,
CurrencyOthers = 6,
CurrencyMyr = 7,
}Variants
CurrencyUsd = 1
CurrencyHkd = 2
CurrencyCnh = 3
CurrencyJpy = 4
CurrencySgd = 5
CurrencyOthers = 6
CurrencyMyr = 7
Implementations
Sourceimpl FutureScreenCurrencyItems
impl FutureScreenCurrencyItems
Sourcepub const fn is_valid(value: i32) -> bool
pub const fn is_valid(value: i32) -> bool
Returns true if value is a variant of FutureScreenCurrencyItems.
Sourcepub fn from_i32(value: i32) -> Option<FutureScreenCurrencyItems>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<FutureScreenCurrencyItems>
Use the TryFrom<i32> implementation instead
Converts an i32 to a FutureScreenCurrencyItems, or None if value is not a valid variant.
Sourceimpl FutureScreenCurrencyItems
impl FutureScreenCurrencyItems
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.