#[repr(i32)]pub enum StockType {
TypeFuture = 2,
}Expand description
Static source catalogs. Screen factor IDs remain uint64 on the wire because the discovery protocol is the authority for future additions.
Variants
TypeFuture = 2
Implementations
Sourceimpl StockType
impl StockType
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.