#[repr(i32)]pub enum HotListSortField {
Unknown = 0,
TradeHeat = 1,
SearchHeat = 2,
NewsHeat = 3,
AverageHeat = 4,
}Expand description
排序字段
Variants
Implementations
Sourceimpl HotListSortField
impl HotListSortField
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.