S2c

Struct S2c 

pub struct S2c {
Show 15 fields pub institution_name: Option<String>, pub description: Option<String>, pub position_value: Option<f64>, pub last_position_value: Option<f64>, pub position_value_change_pct: Option<f64>, pub total_holding_count: Option<i64>, pub holding_change_count: Option<i64>, pub new_count: Option<i32>, pub sold_out_count: Option<i32>, pub increase_count: Option<i32>, pub decrease_count: Option<i32>, pub top10_pct: Option<f64>, pub top10_pct_change: Option<f64>, pub disclosure_date: Option<String>, pub currency: Option<String>,
}

Fields

institution_name: Option<String>

机构名称

description: Option<String>

机构简介

position_value: Option<f64>

持仓市值

last_position_value: Option<f64>

上期持仓市值

position_value_change_pct: Option<f64>

市值变化比例(%)

total_holding_count: Option<i64>

总持仓数

holding_change_count: Option<i64>

持仓变动数

new_count: Option<i32>

建仓标的数

sold_out_count: Option<i32>

清仓标的数

increase_count: Option<i32>

增持标的数

decrease_count: Option<i32>

减持标的数

top10_pct: Option<f64>

Top10持股占比(%)

top10_pct_change: Option<f64>

Top10占比变动(%)

disclosure_date: Option<String>

披露日期(yyyy-MM-dd)

currency: Option<String>

币种

Implementations

Source

impl S2c

pub fn institution_name(&self) -> &str

Returns the value of institution_name, or the default value if institution_name is unset.

pub fn description(&self) -> &str

Returns the value of description, or the default value if description is unset.

pub fn position_value(&self) -> f64

Returns the value of position_value, or the default value if position_value is unset.

pub fn last_position_value(&self) -> f64

Returns the value of last_position_value, or the default value if last_position_value is unset.

pub fn position_value_change_pct(&self) -> f64

Returns the value of position_value_change_pct, or the default value if position_value_change_pct is unset.

pub fn total_holding_count(&self) -> i64

Returns the value of total_holding_count, or the default value if total_holding_count is unset.

pub fn holding_change_count(&self) -> i64

Returns the value of holding_change_count, or the default value if holding_change_count is unset.

pub fn new_count(&self) -> i32

Returns the value of new_count, or the default value if new_count is unset.

pub fn sold_out_count(&self) -> i32

Returns the value of sold_out_count, or the default value if sold_out_count is unset.

pub fn increase_count(&self) -> i32

Returns the value of increase_count, or the default value if increase_count is unset.

pub fn decrease_count(&self) -> i32

Returns the value of decrease_count, or the default value if decrease_count is unset.

pub fn top10_pct(&self) -> f64

Returns the value of top10_pct, or the default value if top10_pct is unset.

pub fn top10_pct_change(&self) -> f64

Returns the value of top10_pct_change, or the default value if top10_pct_change is unset.

pub fn disclosure_date(&self) -> &str

Returns the value of disclosure_date, or the default value if disclosure_date is unset.

pub fn currency(&self) -> &str

Returns the value of currency, or the default value if currency is unset.