JpIpoExData

Struct JpIpoExData 

pub struct JpIpoExData {
Show 30 fields pub ipo_price_min: f64, pub ipo_price_max: f64, pub issue_size: i64, pub lot_size: Option<i32>, pub eqty_issued_shares: Option<i64>, pub isin: Option<String>, pub issued_shares: Option<i64>, pub industry: Option<String>, pub market_segment: Option<String>, pub approval_time: Option<String>, pub approval_timestamp: Option<f64>, pub issue_confirm_time: Option<String>, pub issue_confirm_timestamp: Option<f64>, pub price_confirm_start_time: Option<String>, pub price_confirm_start_timestamp: Option<f64>, pub price_confirm_end_time: Option<String>, pub price_confirm_end_timestamp: Option<f64>, pub inquiry_start_time: Option<String>, pub inquiry_start_timestamp: Option<f64>, pub inquiry_end_time: Option<String>, pub inquiry_end_timestamp: Option<f64>, pub apply_start_time: Option<String>, pub apply_start_timestamp: Option<f64>, pub apply_end_time: Option<String>, pub apply_end_timestamp: Option<f64>, pub draw_time: Option<String>, pub draw_timestamp: Option<f64>, pub winning_time: Option<String>, pub winning_timestamp: Option<f64>, pub etf_info: Option<JpetfBriefInfo>,
}
日本Ipo列表额外数据

Fields

ipo_price_min: f64

最低发行价

ipo_price_max: f64

最高发行价

issue_size: i64

发行量

lot_size: Option<i32>

CMD 20751 GetIPOList 扩展字段

每手股数

eqty_issued_shares: Option<i64>

总股本

isin: Option<String>

ISIN代码 目前仅支持 JP ETF

issued_shares: Option<i64>

已发行股本,本次IPO前股本

industry: Option<String>

行业板块

market_segment: Option<String>

细分市场

approval_time: Option<String>

时间节点字符串与时间戳成对

获批上市时间字符串

approval_timestamp: Option<f64>

获批上市时间戳

issue_confirm_time: Option<String>

发行条件确定时间字符串

issue_confirm_timestamp: Option<f64>

发行条件确定时间戳

price_confirm_start_time: Option<String>

发行价确定开始时间字符串

price_confirm_start_timestamp: Option<f64>

发行价确定开始时间戳

price_confirm_end_time: Option<String>

发行价确定结束时间字符串

price_confirm_end_timestamp: Option<f64>

发行价确定结束时间戳

inquiry_start_time: Option<String>

询价期开始时间字符串

inquiry_start_timestamp: Option<f64>

询价期开始时间戳

inquiry_end_time: Option<String>

询价期结束时间字符串

inquiry_end_timestamp: Option<f64>

询价期结束时间戳

apply_start_time: Option<String>

申购期开始时间字符串

apply_start_timestamp: Option<f64>

申购期开始时间戳

apply_end_time: Option<String>

申购期结束时间字符串

apply_end_timestamp: Option<f64>

申购期结束时间戳

draw_time: Option<String>

抽签时间字符串

draw_timestamp: Option<f64>

抽签时间戳

winning_time: Option<String>

中签公布时间字符串

winning_timestamp: Option<f64>

中签公布时间戳

etf_info: Option<JpetfBriefInfo>

JP ETF 信息

仅 JP ETF 下发

Implementations

Source

impl JpIpoExData

pub fn lot_size(&self) -> i32

Returns the value of lot_size, or the default value if lot_size is unset.

pub fn eqty_issued_shares(&self) -> i64

Returns the value of eqty_issued_shares, or the default value if eqty_issued_shares is unset.

pub fn isin(&self) -> &str

Returns the value of isin, or the default value if isin is unset.

pub fn issued_shares(&self) -> i64

Returns the value of issued_shares, or the default value if issued_shares is unset.

pub fn industry(&self) -> &str

Returns the value of industry, or the default value if industry is unset.

pub fn market_segment(&self) -> &str

Returns the value of market_segment, or the default value if market_segment is unset.

pub fn approval_time(&self) -> &str

Returns the value of approval_time, or the default value if approval_time is unset.

pub fn approval_timestamp(&self) -> f64

Returns the value of approval_timestamp, or the default value if approval_timestamp is unset.

pub fn issue_confirm_time(&self) -> &str

Returns the value of issue_confirm_time, or the default value if issue_confirm_time is unset.

pub fn issue_confirm_timestamp(&self) -> f64

Returns the value of issue_confirm_timestamp, or the default value if issue_confirm_timestamp is unset.

pub fn price_confirm_start_time(&self) -> &str

Returns the value of price_confirm_start_time, or the default value if price_confirm_start_time is unset.

pub fn price_confirm_start_timestamp(&self) -> f64

Returns the value of price_confirm_start_timestamp, or the default value if price_confirm_start_timestamp is unset.

pub fn price_confirm_end_time(&self) -> &str

Returns the value of price_confirm_end_time, or the default value if price_confirm_end_time is unset.

pub fn price_confirm_end_timestamp(&self) -> f64

Returns the value of price_confirm_end_timestamp, or the default value if price_confirm_end_timestamp is unset.

pub fn inquiry_start_time(&self) -> &str

Returns the value of inquiry_start_time, or the default value if inquiry_start_time is unset.

pub fn inquiry_start_timestamp(&self) -> f64

Returns the value of inquiry_start_timestamp, or the default value if inquiry_start_timestamp is unset.

pub fn inquiry_end_time(&self) -> &str

Returns the value of inquiry_end_time, or the default value if inquiry_end_time is unset.

pub fn inquiry_end_timestamp(&self) -> f64

Returns the value of inquiry_end_timestamp, or the default value if inquiry_end_timestamp is unset.

pub fn apply_start_time(&self) -> &str

Returns the value of apply_start_time, or the default value if apply_start_time is unset.

pub fn apply_start_timestamp(&self) -> f64

Returns the value of apply_start_timestamp, or the default value if apply_start_timestamp is unset.

pub fn apply_end_time(&self) -> &str

Returns the value of apply_end_time, or the default value if apply_end_time is unset.

pub fn apply_end_timestamp(&self) -> f64

Returns the value of apply_end_timestamp, or the default value if apply_end_timestamp is unset.

pub fn draw_time(&self) -> &str

Returns the value of draw_time, or the default value if draw_time is unset.

pub fn draw_timestamp(&self) -> f64

Returns the value of draw_timestamp, or the default value if draw_timestamp is unset.

pub fn winning_time(&self) -> &str

Returns the value of winning_time, or the default value if winning_time is unset.

pub fn winning_timestamp(&self) -> f64

Returns the value of winning_timestamp, or the default value if winning_timestamp is unset.