pub struct LatestNewsItem {Show 19 fields
pub audio_urls: Vec<String>,
pub content: Option<String>,
pub detail_url: Option<String>,
pub futu_source: Option<String>,
pub id: Option<i64>,
pub is_auto_translated: Option<i32>,
pub level: Option<i32>,
pub news_type: Option<i32>,
pub news_unique_id: Option<String>,
pub origin_lang: Option<String>,
pub pic: Option<String>,
pub related_stock_ids: Vec<u64>,
pub time: Option<i64>,
pub title: Option<String>,
pub news_content_type: Option<u32>,
pub source: Option<String>,
pub source_id: Option<i64>,
pub show_translate_button: Option<bool>,
pub new_news_id: Option<String>,
}Fields
audio_urls: Vec<String>content: Option<String>detail_url: Option<String>futu_source: Option<String>id: Option<i64>is_auto_translated: Option<i32>level: Option<i32>news_type: Option<i32>news_unique_id: Option<String>origin_lang: Option<String>pic: Option<String>time: Option<i64>title: Option<String>news_content_type: Option<u32>source: Option<String>source_id: Option<i64>new_news_id: Option<String>Implementations
Sourceimpl LatestNewsItem
impl LatestNewsItem
Sourcepub fn content(&self) -> &str
pub fn content(&self) -> &str
Returns the value of content, or the default value if content is unset.
Sourcepub fn detail_url(&self) -> &str
pub fn detail_url(&self) -> &str
Returns the value of detail_url, or the default value if detail_url is unset.
Sourcepub fn futu_source(&self) -> &str
pub fn futu_source(&self) -> &str
Returns the value of futu_source, or the default value if futu_source is unset.
Sourcepub fn is_auto_translated(&self) -> i32
pub fn is_auto_translated(&self) -> i32
Returns the value of is_auto_translated, or the default value if is_auto_translated is unset.
Sourcepub fn news_type(&self) -> i32
pub fn news_type(&self) -> i32
Returns the value of news_type, or the default value if news_type is unset.
Sourcepub fn news_unique_id(&self) -> &str
pub fn news_unique_id(&self) -> &str
Returns the value of news_unique_id, or the default value if news_unique_id is unset.
Sourcepub fn origin_lang(&self) -> &str
pub fn origin_lang(&self) -> &str
Returns the value of origin_lang, or the default value if origin_lang is unset.
Sourcepub fn title(&self) -> &str
pub fn title(&self) -> &str
Returns the value of title, or the default value if title is unset.
Sourcepub fn news_content_type(&self) -> u32
pub fn news_content_type(&self) -> u32
Returns the value of news_content_type, or the default value if news_content_type is unset.
Sourcepub fn source(&self) -> &str
pub fn source(&self) -> &str
Returns the value of source, or the default value if source is unset.
Sourcepub fn source_id(&self) -> i64
pub fn source_id(&self) -> i64
Returns the value of source_id, or the default value if source_id is unset.
Returns the value of show_translate_button, or the default value if show_translate_button is unset.
Sourcepub fn new_news_id(&self) -> &str
pub fn new_news_id(&self) -> &str
Returns the value of new_news_id, or the default value if new_news_id is unset.