#[repr(i32)]pub enum MacroRegion {
Unknown = 0,
Hk = 1,
Us = 2,
Jp = 3,
Sg = 4,
Au = 5,
Ca = 6,
My = 7,
Cn = 8,
}Expand description
宏观数据国家/地区
Variants
Unknown = 0
未知
Hk = 1
香港
Us = 2
美国
Jp = 3
日本
Sg = 4
新加坡
Au = 5
澳大利亚
Ca = 6
加拿大
My = 7
马来西亚
Cn = 8
中国(沪深)
Implementations
Sourceimpl MacroRegion
impl MacroRegion
Sourceimpl MacroRegion
impl MacroRegion
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.