#[repr(i32)]pub enum TickerType {
Unknown = 0,
Buy = 1,
Sell = 2,
Neutral = 3,
}Expand description
成交方向
Variants
Implementations
Sourceimpl TickerType
impl TickerType
Sourceimpl TickerType
impl TickerType
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.