EventItem

Struct EventItem 

pub struct EventItem {
Show 35 fields pub option: Option<Security>, pub owner: Option<Security>, pub symbol: Option<String>, pub fill_time: Option<String>, pub fill_timestamp: Option<f64>, pub ticker_type: Option<i32>, pub price: Option<f64>, pub volume: Option<i64>, pub turnover: Option<f64>, pub option_type: Option<i32>, pub strike_price: Option<f64>, pub strike_time: Option<String>, pub strike_timestamp: Option<f64>, pub dte: Option<i32>, pub underlying_price: Option<f64>, pub otm: Option<f64>, pub bid_price: Option<f64>, pub ask_price: Option<f64>, pub iv: Option<f64>, pub total_volume: Option<i64>, pub total_open_interest: Option<i64>, pub vo_ratio: Option<f64>, pub delta: Option<f64>, pub gamma: Option<f64>, pub vega: Option<f64>, pub theta: Option<f64>, pub rho: Option<f64>, pub sentiment: Option<i32>, pub order_type_list: Vec<i32>, pub strategy_type: Option<i32>, pub earnings_time: Option<String>, pub earnings_pub_type: Option<i32>, pub corporate_action_list: Vec<CorporateAction>, pub industry_plate_list: Vec<Security>, pub concept_plate_list: Vec<Security>,
}
单条异动记录

Fields

option: Option<Security>

标识

期权合约标识

owner: Option<Security>

标的股票标识

symbol: Option<String>

标的display code(如TSLA)

fill_time: Option<String>

成交信息

成交时间(“yyyy-MM-dd HH:mm:ss”)

fill_timestamp: Option<f64>

成交时间(Unix秒,精度到毫秒)

ticker_type: Option<i32>

TickerType,成交方向

price: Option<f64>

成交价

volume: Option<i64>

成交量(张)

turnover: Option<f64>

成交额

option_type: Option<i32>

期权合约属性

Qot_Common.OptionType,CALL/PUT

strike_price: Option<f64>

行权价

strike_time: Option<String>

到期日(“yyyy-MM-dd”)

strike_timestamp: Option<f64>

到期日(Unix秒)

dte: Option<i32>

距到期天数

underlying_price: Option<f64>

行情快照(异动发生时刻)

标的价格

otm: Option<f64>

价外比率(百分比值,如-17.18表示-17.18%)

bid_price: Option<f64>

买一价

ask_price: Option<f64>

卖一价

iv: Option<f64>

隐含波动率(百分比值)

total_volume: Option<i64>

期权当日总成交量

total_open_interest: Option<i64>

期权当日总持仓量

vo_ratio: Option<f64>

量仓比(百分比值)

delta: Option<f64>

希腊值

gamma: Option<f64>vega: Option<f64>theta: Option<f64>rho: Option<f64>sentiment: Option<i32>

市场情绪与订单分类

MarketSentiment

order_type_list: Vec<i32>

OrderType列表

strategy_type: Option<i32>

TickerStrategy

earnings_time: Option<String>

关联信息

财报日期(“yyyy-MM-dd”)

earnings_pub_type: Option<i32>

Qot_OptionCommon.EarningsPubType,财报发布类型(盘前/盘后)

corporate_action_list: Vec<CorporateAction>

公司行动列表

industry_plate_list: Vec<Security>

行业板块列表

concept_plate_list: Vec<Security>

概念板块列表

Implementations

Source

impl EventItem

pub fn symbol(&self) -> &str

Returns the value of symbol, or the default value if symbol is unset.

pub fn fill_time(&self) -> &str

Returns the value of fill_time, or the default value if fill_time is unset.

pub fn fill_timestamp(&self) -> f64

Returns the value of fill_timestamp, or the default value if fill_timestamp is unset.

pub fn ticker_type(&self) -> i32

Returns the value of ticker_type, or the default value if ticker_type is unset.

pub fn price(&self) -> f64

Returns the value of price, or the default value if price is unset.

pub fn volume(&self) -> i64

Returns the value of volume, or the default value if volume is unset.

pub fn turnover(&self) -> f64

Returns the value of turnover, or the default value if turnover is unset.

pub fn option_type(&self) -> i32

Returns the value of option_type, or the default value if option_type is unset.

pub fn strike_price(&self) -> f64

Returns the value of strike_price, or the default value if strike_price is unset.

pub fn strike_time(&self) -> &str

Returns the value of strike_time, or the default value if strike_time is unset.

pub fn strike_timestamp(&self) -> f64

Returns the value of strike_timestamp, or the default value if strike_timestamp is unset.

pub fn dte(&self) -> i32

Returns the value of dte, or the default value if dte is unset.

pub fn underlying_price(&self) -> f64

Returns the value of underlying_price, or the default value if underlying_price is unset.

pub fn otm(&self) -> f64

Returns the value of otm, or the default value if otm is unset.

pub fn bid_price(&self) -> f64

Returns the value of bid_price, or the default value if bid_price is unset.

pub fn ask_price(&self) -> f64

Returns the value of ask_price, or the default value if ask_price is unset.

pub fn iv(&self) -> f64

Returns the value of iv, or the default value if iv is unset.

pub fn total_volume(&self) -> i64

Returns the value of total_volume, or the default value if total_volume is unset.

pub fn total_open_interest(&self) -> i64

Returns the value of total_open_interest, or the default value if total_open_interest is unset.

pub fn vo_ratio(&self) -> f64

Returns the value of vo_ratio, or the default value if vo_ratio is unset.

pub fn delta(&self) -> f64

Returns the value of delta, or the default value if delta is unset.

pub fn gamma(&self) -> f64

Returns the value of gamma, or the default value if gamma is unset.

pub fn vega(&self) -> f64

Returns the value of vega, or the default value if vega is unset.

pub fn theta(&self) -> f64

Returns the value of theta, or the default value if theta is unset.

pub fn rho(&self) -> f64

Returns the value of rho, or the default value if rho is unset.

pub fn sentiment(&self) -> i32

Returns the value of sentiment, or the default value if sentiment is unset.

pub fn strategy_type(&self) -> i32

Returns the value of strategy_type, or the default value if strategy_type is unset.

pub fn earnings_time(&self) -> &str

Returns the value of earnings_time, or the default value if earnings_time is unset.

pub fn earnings_pub_type(&self) -> i32

Returns the value of earnings_pub_type, or the default value if earnings_pub_type is unset.