EventAlertItem

Struct EventAlertItem 

pub struct EventAlertItem {
Show 17 fields pub key: Option<i64>, pub enable: Option<bool>, pub option_market: Option<i32>, pub watchlist_group_name: Option<String>, pub underlying: Option<Security>, pub option_type: Option<i32>, pub side_type_list: Vec<i32>, pub order_type_list: Vec<i32>, pub market_cap_range: Option<Interval>, pub expiry_days_range: Option<Interval>, pub price_range: Option<Interval>, pub size_range: Option<Interval>, pub premium_range: Option<Interval>, pub iv_range: Option<Interval>, pub earnings_date_begin: Option<String>, pub earnings_date_end: Option<String>, pub note: Option<String>,
}
告警项

Fields

key: Option<i64>

–– 标识 ––

告警唯一标识(新增时不传,修改/删除时必传)

enable: Option<bool>

告警开关(true=开启, false=暂停)

option_market: Option<i32>

–– 告警范围(三选一,全不填或填多个后台拒绝) ––

OptionMarket 市场品类

watchlist_group_name: Option<String>

自选股分组名称

underlying: Option<Security>

指定标的

option_type: Option<i32>

–– 枚举筛选条件 ––

期权类型:CALL(1)/PUT(2),不传默认全部

side_type_list: Vec<i32>

成交方向:BUY(1)/SELL(2)/NEUTRAL(3)(复用 TickerType),不传默认全部

order_type_list: Vec<i32>

订单类型(Qot_GetOptionEvent.OptionOrderType),不传默认全部

market_cap_range: Option<Interval>

–– 范围筛选条件(Interval 复用 Qot_GetOptionEvent 定义) ––

标的市值范围

expiry_days_range: Option<Interval>

距到期天数范围

price_range: Option<Interval>

异动成交价范围

size_range: Option<Interval>

异动成交量范围(张)

premium_range: Option<Interval>

异动成交额范围

iv_range: Option<Interval>

隐含波动率范围(%)

earnings_date_begin: Option<String>

–– 财报时间筛选(必须同时传入 begin 和 end,且 end >= begin) ––

财报时间筛选起始日期,格式 yyyy-MM-dd,必须与 earningsDateEnd 同时传入

earnings_date_end: Option<String>

财报时间筛选截止日期,格式 yyyy-MM-dd,必须与 earningsDateBegin 同时传入,且不能小于起始日期

note: Option<String>

–– 备注 ––

备注(最多 20 字)

Implementations

Source

impl EventAlertItem

pub fn key(&self) -> i64

Returns the value of key, or the default value if key is unset.

pub fn enable(&self) -> bool

Returns the value of enable, or the default value if enable is unset.

pub fn option_market(&self) -> i32

Returns the value of option_market, or the default value if option_market is unset.

pub fn watchlist_group_name(&self) -> &str

Returns the value of watchlist_group_name, or the default value if watchlist_group_name is unset.

pub fn option_type(&self) -> i32

Returns the value of option_type, or the default value if option_type is unset.

pub fn earnings_date_begin(&self) -> &str

Returns the value of earnings_date_begin, or the default value if earnings_date_begin is unset.

pub fn earnings_date_end(&self) -> &str

Returns the value of earnings_date_end, or the default value if earnings_date_end is unset.

pub fn note(&self) -> &str

Returns the value of note, or the default value if note is unset.