SellerItem

Struct SellerItem 

pub struct SellerItem {
Show 18 fields pub option: Security, pub name: Option<String>, pub option_type: Option<i32>, pub strike_price: Option<f64>, pub strike_time: Option<String>, pub strike_timestamp: Option<f64>, pub left_days: Option<i32>, pub option_price: Option<f64>, pub stock_price: Option<f64>, pub premium: Option<f64>, pub otm_degree: Option<f64>, pub iv: Option<f64>, pub interval_return: Option<f64>, pub annualized_return: Option<f64>, pub itm_probability: Option<f64>, pub striked_interval_return: Option<f64>, pub striked_annualized_return: Option<f64>, pub owner: Option<Security>,
}
卖方策略合约项

Fields

option: Security

期权合约

name: Option<String>

期权名称

option_type: Option<i32>

Qot_Common.OptionType (CALL/PUT)

strike_price: Option<f64>

行权价

strike_time: Option<String>

到期日(“yyyy-MM-dd”)

strike_timestamp: Option<f64>

到期日时间戳(秒)

left_days: Option<i32>

距到期天数

option_price: Option<f64>

期权价格

stock_price: Option<f64>

标的当前价

premium: Option<f64>

权利金(=期权价x合约乘数)

otm_degree: Option<f64>

价外程度(%)

iv: Option<f64>

隐含波动率(%)

interval_return: Option<f64>

区间收益率(%)

annualized_return: Option<f64>

年化收益率(%)

itm_probability: Option<f64>

行权概率(%)

striked_interval_return: Option<f64>

Covered Call 专属

被行权区间收益率(%)

striked_annualized_return: Option<f64>

被行权年化收益率(%)

owner: Option<Security>

标的信息

标的证券

Implementations

Source

impl SellerItem

pub fn name(&self) -> &str

Returns the value of name, or the default value if name is unset.

pub fn option_type(&self) -> i32

Returns the value of option_type, or the default value if option_type is unset.

pub fn strike_price(&self) -> f64

Returns the value of strike_price, or the default value if strike_price is unset.

pub fn strike_time(&self) -> &str

Returns the value of strike_time, or the default value if strike_time is unset.

pub fn strike_timestamp(&self) -> f64

Returns the value of strike_timestamp, or the default value if strike_timestamp is unset.

pub fn left_days(&self) -> i32

Returns the value of left_days, or the default value if left_days is unset.

pub fn option_price(&self) -> f64

Returns the value of option_price, or the default value if option_price is unset.

pub fn stock_price(&self) -> f64

Returns the value of stock_price, or the default value if stock_price is unset.

pub fn premium(&self) -> f64

Returns the value of premium, or the default value if premium is unset.

pub fn otm_degree(&self) -> f64

Returns the value of otm_degree, or the default value if otm_degree is unset.

pub fn iv(&self) -> f64

Returns the value of iv, or the default value if iv is unset.

pub fn interval_return(&self) -> f64

Returns the value of interval_return, or the default value if interval_return is unset.

pub fn annualized_return(&self) -> f64

Returns the value of annualized_return, or the default value if annualized_return is unset.

pub fn itm_probability(&self) -> f64

Returns the value of itm_probability, or the default value if itm_probability is unset.

pub fn striked_interval_return(&self) -> f64

Returns the value of striked_interval_return, or the default value if striked_interval_return is unset.

pub fn striked_annualized_return(&self) -> f64

Returns the value of striked_annualized_return, or the default value if striked_annualized_return is unset.