ZeroDteContractItem

Struct ZeroDteContractItem 

pub struct ZeroDteContractItem {
Show 17 fields pub option: Security, pub name: Option<String>, pub option_type: Option<i32>, pub option_price: Option<f64>, pub change_rate: Option<f64>, pub volume: Option<i64>, pub open_interest: Option<i64>, pub iv: Option<f64>, pub delta: Option<f64>, pub gamma: Option<f64>, pub vega: Option<f64>, pub theta: Option<f64>, pub rho: Option<f64>, pub buy_break_even_point: Option<f64>, pub buy_to_bep: Option<f64>, pub buy_profit_probability: Option<f64>, pub sell_profit_probability: Option<f64>,
}
合约项

Fields

option: Securityname: Option<String>option_type: Option<i32>

Qot_Common.OptionType

option_price: Option<f64>change_rate: Option<f64>

涨跌幅(该字段为百分比字段,默认不展示%,如20实际对应20%)

volume: Option<i64>open_interest: Option<i64>iv: Option<f64>

(%)

delta: Option<f64>gamma: Option<f64>vega: Option<f64>theta: Option<f64>rho: Option<f64>buy_break_even_point: Option<f64>

价格

buy_to_bep: Option<f64>

(%)

buy_profit_probability: Option<f64>

(%)

sell_profit_probability: Option<f64>

(%)

Implementations

Source

impl ZeroDteContractItem

pub fn name(&self) -> &str

Returns the value of name, or the default value if name is unset.

pub fn option_type(&self) -> i32

Returns the value of option_type, or the default value if option_type is unset.

pub fn option_price(&self) -> f64

Returns the value of option_price, or the default value if option_price is unset.

pub fn change_rate(&self) -> f64

Returns the value of change_rate, or the default value if change_rate is unset.

pub fn volume(&self) -> i64

Returns the value of volume, or the default value if volume is unset.

pub fn open_interest(&self) -> i64

Returns the value of open_interest, or the default value if open_interest is unset.

pub fn iv(&self) -> f64

Returns the value of iv, or the default value if iv is unset.

pub fn delta(&self) -> f64

Returns the value of delta, or the default value if delta is unset.

pub fn gamma(&self) -> f64

Returns the value of gamma, or the default value if gamma is unset.

pub fn vega(&self) -> f64

Returns the value of vega, or the default value if vega is unset.

pub fn theta(&self) -> f64

Returns the value of theta, or the default value if theta is unset.

pub fn rho(&self) -> f64

Returns the value of rho, or the default value if rho is unset.

pub fn buy_break_even_point(&self) -> f64

Returns the value of buy_break_even_point, or the default value if buy_break_even_point is unset.

pub fn buy_to_bep(&self) -> f64

Returns the value of buy_to_bep, or the default value if buy_to_bep is unset.

pub fn buy_profit_probability(&self) -> f64

Returns the value of buy_profit_probability, or the default value if buy_profit_probability is unset.

pub fn sell_profit_probability(&self) -> f64

Returns the value of sell_profit_probability, or the default value if sell_profit_probability is unset.