pub struct S2c {
pub highest: Option<f64>,
pub average: Option<f64>,
pub lowest: Option<f64>,
pub rating: Option<i32>,
pub total: Option<i32>,
pub update_time: Option<i64>,
pub update_time_str: Option<String>,
pub buy: Option<f64>,
pub hold: Option<f64>,
pub sell: Option<f64>,
pub strong_buy: Option<f64>,
pub underperform: Option<f64>,
}Fields
highest: Option<f64>最高目标价
average: Option<f64>平均目标价
lowest: Option<f64>最低目标价
rating: Option<i32>近3个月分析师综合评级,详见 Qot_Common.ResearchRatingType 定义;美股仅返回 Sell(1)/Hold(3)/Buy(4),非美市场另支持 Underperform(2)/StrongBuy(5)
total: Option<i32>近3个月参与评级的分析师总人数
update_time: Option<i64>评级数据更新时间戳(秒)
update_time_str: Option<String>评级数据更新时间字符串,格式 YYYY-MM-DD,对应市场时区
buy: Option<f64>Buy 评级占比,百分号前的值,如 12.34 表示 12.34%
hold: Option<f64>Hold 评级占比,百分号前的值,如 12.34 表示 12.34%
sell: Option<f64>Sell 评级占比,百分号前的值,如 12.34 表示 12.34%
strong_buy: Option<f64>以下字段仅非美市场支持,US 市场不返回
Strong Buy 评级占比,百分号前的值,如 12.34 表示 12.34%;仅非美市场
underperform: Option<f64>Underperform 评级占比,百分号前的值,如 12.34 表示 12.34%;仅非美市场
Implementations
Sourceimpl S2c
impl S2c
Sourcepub fn highest(&self) -> f64
pub fn highest(&self) -> f64
Returns the value of highest, or the default value if highest is unset.
Sourcepub fn average(&self) -> f64
pub fn average(&self) -> f64
Returns the value of average, or the default value if average is unset.
Sourcepub fn lowest(&self) -> f64
pub fn lowest(&self) -> f64
Returns the value of lowest, or the default value if lowest is unset.
Sourcepub fn rating(&self) -> ResearchRatingType
pub fn rating(&self) -> ResearchRatingType
Returns the enum value of rating, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_rating(&mut self, value: ResearchRatingType)
pub fn set_rating(&mut self, value: ResearchRatingType)
Sets rating to the provided enum value.
Sourcepub fn update_time(&self) -> i64
pub fn update_time(&self) -> i64
Returns the value of update_time, or the default value if update_time is unset.
Sourcepub fn update_time_str(&self) -> &str
pub fn update_time_str(&self) -> &str
Returns the value of update_time_str, or the default value if update_time_str is unset.
Sourcepub fn strong_buy(&self) -> f64
pub fn strong_buy(&self) -> f64
Returns the value of strong_buy, or the default value if strong_buy is unset.
Sourcepub fn underperform(&self) -> f64
pub fn underperform(&self) -> f64
Returns the value of underperform, or the default value if underperform is unset.