pub struct RatingItem {
pub analyst_uid: Option<String>,
pub institution_uid: Option<String>,
pub rating: Option<i32>,
pub target_price: Option<f64>,
pub recommendation_date: Option<i64>,
pub recommendation_date_str: Option<String>,
pub rating_url: Option<String>,
pub update_time: Option<i64>,
pub update_time_str: Option<String>,
}Fields
analyst_uid: Option<String>分析师唯一标识
institution_uid: Option<String>机构唯一标识
rating: Option<i32>评级(详见 Qot_Common.ResearchRatingType 定义),仅返回 Sell(1)/Hold(3)/Buy(4),数值越大评级越高
target_price: Option<f64>目标价
recommendation_date: Option<i64>评级日期时间戳(秒)
recommendation_date_str: Option<String>评级日期字符串,格式 YYYY-MM-DD,对应市场时区
rating_url: Option<String>评级来源 URL
update_time: Option<i64>更新时间戳(秒)
update_time_str: Option<String>更新时间字符串,格式 YYYY-MM-DD,对应市场时区
Implementations
Sourceimpl RatingItem
impl RatingItem
Sourcepub fn analyst_uid(&self) -> &str
pub fn analyst_uid(&self) -> &str
Returns the value of analyst_uid, or the default value if analyst_uid is unset.
Sourcepub fn institution_uid(&self) -> &str
pub fn institution_uid(&self) -> &str
Returns the value of institution_uid, or the default value if institution_uid is unset.
Sourcepub fn rating(&self) -> ResearchRatingType
pub fn rating(&self) -> ResearchRatingType
Returns the enum value of rating, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_rating(&mut self, value: ResearchRatingType)
pub fn set_rating(&mut self, value: ResearchRatingType)
Sets rating to the provided enum value.
Sourcepub fn target_price(&self) -> f64
pub fn target_price(&self) -> f64
Returns the value of target_price, or the default value if target_price is unset.
Sourcepub fn recommendation_date(&self) -> i64
pub fn recommendation_date(&self) -> i64
Returns the value of recommendation_date, or the default value if recommendation_date is unset.
Sourcepub fn recommendation_date_str(&self) -> &str
pub fn recommendation_date_str(&self) -> &str
Returns the value of recommendation_date_str, or the default value if recommendation_date_str is unset.
Sourcepub fn rating_url(&self) -> &str
pub fn rating_url(&self) -> &str
Returns the value of rating_url, or the default value if rating_url is unset.
Sourcepub fn update_time(&self) -> i64
pub fn update_time(&self) -> i64
Returns the value of update_time, or the default value if update_time is unset.
Sourcepub fn update_time_str(&self) -> &str
pub fn update_time_str(&self) -> &str
Returns the value of update_time_str, or the default value if update_time_str is unset.