WarrantSnapshotExData

Struct WarrantSnapshotExData 

pub struct WarrantSnapshotExData {
Show 25 fields pub conversion_rate: f64, pub warrant_type: i32, pub strike_price: f64, pub maturity_time: String, pub end_trade_time: String, pub owner: Security, pub recovery_price: f64, pub street_volumn: i64, pub issue_volumn: i64, pub street_rate: f64, pub delta: f64, pub implied_volatility: f64, pub premium: f64, pub maturity_timestamp: Option<f64>, pub end_trade_timestamp: Option<f64>, pub leverage: Option<f64>, pub ipop: Option<f64>, pub break_even_point: Option<f64>, pub conversion_price: Option<f64>, pub price_recovery_ratio: Option<f64>, pub score: Option<f64>, pub upper_strike_price: Option<f64>, pub lower_strike_price: Option<f64>, pub in_line_price_status: Option<i32>, pub issuer_code: Option<String>,
}
窝轮类型额外数据

Fields

conversion_rate: f64

换股比率

warrant_type: i32

Qot_Common.WarrantType,窝轮类型

strike_price: f64

行使价

maturity_time: String

到期日时间字符串

end_trade_time: String

最后交易日时间字符串

owner: Security

所属正股

recovery_price: f64

收回价,仅牛熊证支持该字段

street_volumn: i64

街货量

issue_volumn: i64

发行量

street_rate: f64

街货占比(该字段为百分比字段,默认不展示%,如20实际对应20%)

delta: f64

对冲值,仅认购认沽支持该字段

implied_volatility: f64

引申波幅,仅认购认沽支持该字段

premium: f64

溢价(该字段为百分比字段,默认不展示%,如20实际对应20%)

maturity_timestamp: Option<f64>

到期日时间戳

end_trade_timestamp: Option<f64>

最后交易日时间戳

leverage: Option<f64>

杠杆比率(倍)

ipop: Option<f64>

价内/价外(该字段为百分比字段,默认不展示%,如20实际对应20%)

break_even_point: Option<f64>

打和点

conversion_price: Option<f64>

换股价

price_recovery_ratio: Option<f64>

正股距收回价(该字段为百分比字段,默认不展示%,如20实际对应20%)

score: Option<f64>

综合评分

upper_strike_price: Option<f64>

上限价,仅界内证支持该字段

lower_strike_price: Option<f64>

下限价,仅界内证支持该字段

in_line_price_status: Option<i32>

Qot_Common.PriceType, 界内界外,仅界内证支持该字段

issuer_code: Option<String>

发行人代码

Implementations

Source

impl WarrantSnapshotExData

pub fn maturity_timestamp(&self) -> f64

Returns the value of maturity_timestamp, or the default value if maturity_timestamp is unset.

pub fn end_trade_timestamp(&self) -> f64

Returns the value of end_trade_timestamp, or the default value if end_trade_timestamp is unset.

pub fn leverage(&self) -> f64

Returns the value of leverage, or the default value if leverage is unset.

pub fn ipop(&self) -> f64

Returns the value of ipop, or the default value if ipop is unset.

pub fn break_even_point(&self) -> f64

Returns the value of break_even_point, or the default value if break_even_point is unset.

pub fn conversion_price(&self) -> f64

Returns the value of conversion_price, or the default value if conversion_price is unset.

pub fn price_recovery_ratio(&self) -> f64

Returns the value of price_recovery_ratio, or the default value if price_recovery_ratio is unset.

pub fn score(&self) -> f64

Returns the value of score, or the default value if score is unset.

pub fn upper_strike_price(&self) -> f64

Returns the value of upper_strike_price, or the default value if upper_strike_price is unset.

pub fn lower_strike_price(&self) -> f64

Returns the value of lower_strike_price, or the default value if lower_strike_price is unset.

pub fn in_line_price_status(&self) -> i32

Returns the value of in_line_price_status, or the default value if in_line_price_status is unset.

pub fn issuer_code(&self) -> &str

Returns the value of issuer_code, or the default value if issuer_code is unset.