pub struct C2s {
pub security: Security,
pub request_type: Option<i32>,
pub next_key: Option<String>,
pub num: Option<i32>,
pub sort_column: Option<i32>,
pub sort_type: Option<i32>,
pub period_id: Option<i32>,
pub holder_id: Option<i32>,
}Fields
security: Securityrequest_type: Option<i32>请求数据类型,详见 Qot_Common.HolderDetailType 定义,默认按服务端默认逻辑返回
next_key: Option<String>分页标识,首次不填,续拉时填上次返回的 nextKey;“-1” 表示无更多数据
num: Option<i32>每页返回数量,默认 10,范围 1~50
sort_column: Option<i32>排序列,详见 Qot_Common.SortField,61=持股股数(默认)62=持股变动数
sort_type: Option<i32>排序方向,详见 Qot_Common.SortType 定义,默认降序
period_id: Option<i32>指定统计周期 ID;与 Qot_GetShareholdersOverview(3237)返回的 holdingPeriodList 中 periodId 一致;默认 0 表示最新周期
holder_id: Option<i32>按持股人 ID 过滤;默认 0 表示不过滤;可取自 GetShareholdersOverview(3237)、GetShareholdersHoldingChanges(3238)、本协议(3239)、GetInsiderHolderList(3241)、GetInsiderTradeList(3242)返回的 holderId
Implementations
Sourceimpl C2s
impl C2s
Sourcepub fn request_type(&self) -> HolderDetailType
pub fn request_type(&self) -> HolderDetailType
Returns the enum value of request_type, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_request_type(&mut self, value: HolderDetailType)
pub fn set_request_type(&mut self, value: HolderDetailType)
Sets request_type to the provided enum value.
Sourcepub fn next_key(&self) -> &str
pub fn next_key(&self) -> &str
Returns the value of next_key, or the default value if next_key is unset.
Sourcepub fn sort_column(&self) -> SortField
pub fn sort_column(&self) -> SortField
Returns the enum value of sort_column, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_sort_column(&mut self, value: SortField)
pub fn set_sort_column(&mut self, value: SortField)
Sets sort_column to the provided enum value.
Sourcepub fn sort_type(&self) -> SortType
pub fn sort_type(&self) -> SortType
Returns the enum value of sort_type, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_sort_type(&mut self, value: SortType)
pub fn set_sort_type(&mut self, value: SortType)
Sets sort_type to the provided enum value.