pub struct C2s {
pub security: Security,
pub next_key: Option<String>,
pub num: Option<i32>,
pub sort_type: Option<i32>,
pub sort_column: Option<i32>,
pub filter_type: Option<i32>,
}Fields
security: Security股票
next_key: Option<String>分页标识,首次不填,续拉时填上次返回的 nextKey;“-1” 表示无更多数据
num: Option<i32>每页返回数量,默认 10,范围 1~50
sort_type: Option<i32>排序方向,详见 Qot_Common.SortType 定义,默认降序
sort_column: Option<i32>排序字段,详见 Qot_Common.SortField,62=持股变动数(默认)63=持股日期 64=变动比例 65=变动金额 66=持股比例
filter_type: Option<i32>筛选类型,详见 Qot_Common.HoldingChangesFilterType 定义,默认全部
Implementations
Sourceimpl C2s
impl C2s
Sourcepub fn next_key(&self) -> &str
pub fn next_key(&self) -> &str
Returns the value of next_key, or the default value if next_key is unset.
Sourcepub fn sort_type(&self) -> SortType
pub fn sort_type(&self) -> SortType
Returns the enum value of sort_type, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_sort_type(&mut self, value: SortType)
pub fn set_sort_type(&mut self, value: SortType)
Sets sort_type to the provided enum value.
Sourcepub fn sort_column(&self) -> SortField
pub fn sort_column(&self) -> SortField
Returns the enum value of sort_column, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_sort_column(&mut self, value: SortField)
pub fn set_sort_column(&mut self, value: SortField)
Sets sort_column to the provided enum value.
Sourcepub fn filter_type(&self) -> HoldingChangesFilterType
pub fn filter_type(&self) -> HoldingChangesFilterType
Returns the enum value of filter_type, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_filter_type(&mut self, value: HoldingChangesFilterType)
pub fn set_filter_type(&mut self, value: HoldingChangesFilterType)
Sets filter_type to the provided enum value.