#[repr(i32)]pub enum ShortSellingSortField {
Show 15 variants
Unknown = 0,
ShortNumberChange = 1,
ShortRatioChange = 2,
ShortNumber = 3,
ShortRatio = 4,
Volume = 5,
PositionVolume = 6,
PositionRatio = 7,
DaysToCover = 8,
WeekAvgVolume = 9,
WeekAvgShortNumber = 10,
WeekAvgShortRatio = 11,
MonthAvgVolume = 12,
MonthAvgShortNumber = 13,
MonthAvgShortRatio = 14,
}Expand description
排序字段
Variants
Unknown = 0
默认(卖空变化量)
ShortNumberChange = 1
卖空变化量
ShortRatioChange = 2
卖空变化比例
ShortNumber = 3
卖空数量
ShortRatio = 4
卖空比例
Volume = 5
成交量
PositionVolume = 6
空头持仓数量
PositionRatio = 7
空头持仓比例
DaysToCover = 8
回补天数
WeekAvgVolume = 9
近一周日均成交量
WeekAvgShortNumber = 10
近一周日均卖空数量
WeekAvgShortRatio = 11
近一周日均卖空比例
MonthAvgVolume = 12
近一月日均成交量
MonthAvgShortNumber = 13
近一月日均卖空数量
MonthAvgShortRatio = 14
近一月日均卖空比例
Implementations
Sourceimpl ShortSellingSortField
impl ShortSellingSortField
Sourcepub fn is_valid(value: i32) -> bool
pub fn is_valid(value: i32) -> bool
Returns true if value is a variant of ShortSellingSortField.
Sourcepub fn from_i32(value: i32) -> Option<ShortSellingSortField>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<ShortSellingSortField>
Use the TryFrom<i32> implementation instead
Converts an i32 to a ShortSellingSortField, or None if value is not a valid variant.
Sourceimpl ShortSellingSortField
impl ShortSellingSortField
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.