pub struct C2s {Show 14 fields
pub stock_id: u64,
pub seq_from: Option<u32>,
pub seq_to: Option<u32>,
pub page_size: u32,
pub id_type: u32,
pub scene_id: Option<u32>,
pub audio_only: Option<bool>,
pub source: Option<u32>,
pub translate: Option<bool>,
pub seq_mark: Option<String>,
pub caller_biz: Option<i32>,
pub track_info: Option<String>,
pub dedup_ids: Vec<String>,
pub extension_version: u32,
}Fields
stock_id: u64seq_from: Option<u32>seq_to: Option<u32>page_size: u321..50.
id_type: u321 security, 2 plate.
scene_id: Option<u32>audio_only: Option<bool>source: Option<u32>translate: Option<bool>seq_mark: Option<String>caller_biz: Option<i32>track_info: Option<String>dedup_ids: Vec<String>extension_version: u32Must be 1.
Implementations
Sourceimpl C2s
impl C2s
Sourcepub fn seq_from(&self) -> u32
pub fn seq_from(&self) -> u32
Returns the value of seq_from, or the default value if seq_from is unset.
Sourcepub fn seq_to(&self) -> u32
pub fn seq_to(&self) -> u32
Returns the value of seq_to, or the default value if seq_to is unset.
Sourcepub fn scene_id(&self) -> u32
pub fn scene_id(&self) -> u32
Returns the value of scene_id, or the default value if scene_id is unset.
Sourcepub fn audio_only(&self) -> bool
pub fn audio_only(&self) -> bool
Returns the value of audio_only, or the default value if audio_only is unset.
Sourcepub fn source(&self) -> u32
pub fn source(&self) -> u32
Returns the value of source, or the default value if source is unset.
Sourcepub fn translate(&self) -> bool
pub fn translate(&self) -> bool
Returns the value of translate, or the default value if translate is unset.
Sourcepub fn seq_mark(&self) -> &str
pub fn seq_mark(&self) -> &str
Returns the value of seq_mark, or the default value if seq_mark is unset.
Sourcepub fn caller_biz(&self) -> i32
pub fn caller_biz(&self) -> i32
Returns the value of caller_biz, or the default value if caller_biz is unset.
Sourcepub fn track_info(&self) -> &str
pub fn track_info(&self) -> &str
Returns the value of track_info, or the default value if track_info is unset.