pub struct TopMoversRankItem {
pub security: Security,
pub name: Option<String>,
pub cur_price: Option<f64>,
pub change_ratio: Option<f64>,
pub change_amount: Option<f64>,
pub turnover: Option<f64>,
pub volume: Option<i64>,
pub turnover_ratio: Option<f64>,
pub pe_ttm: Option<f64>,
pub amplitude: Option<f64>,
pub market_cap: Option<f64>,
pub volume_ratio: Option<f64>,
}Expand description
盘中领涨/领跌数据项
Fields
security: Security股票
name: Option<String>名称
cur_price: Option<f64>最新价
change_ratio: Option<f64>涨跌幅(%)
change_amount: Option<f64>涨跌额
turnover: Option<f64>成交额
volume: Option<i64>成交量
turnover_ratio: Option<f64>换手率(%)
pe_ttm: Option<f64>市盈率TTM
amplitude: Option<f64>振幅(%)
market_cap: Option<f64>市值
volume_ratio: Option<f64>量比
Implementations
Sourceimpl TopMoversRankItem
impl TopMoversRankItem
Sourcepub fn cur_price(&self) -> f64
pub fn cur_price(&self) -> f64
Returns the value of cur_price, or the default value if cur_price is unset.
Sourcepub fn change_ratio(&self) -> f64
pub fn change_ratio(&self) -> f64
Returns the value of change_ratio, or the default value if change_ratio is unset.
Sourcepub fn change_amount(&self) -> f64
pub fn change_amount(&self) -> f64
Returns the value of change_amount, or the default value if change_amount is unset.
Sourcepub fn turnover(&self) -> f64
pub fn turnover(&self) -> f64
Returns the value of turnover, or the default value if turnover is unset.
Sourcepub fn volume(&self) -> i64
pub fn volume(&self) -> i64
Returns the value of volume, or the default value if volume is unset.
Sourcepub fn turnover_ratio(&self) -> f64
pub fn turnover_ratio(&self) -> f64
Returns the value of turnover_ratio, or the default value if turnover_ratio is unset.
Sourcepub fn pe_ttm(&self) -> f64
pub fn pe_ttm(&self) -> f64
Returns the value of pe_ttm, or the default value if pe_ttm is unset.
Sourcepub fn amplitude(&self) -> f64
pub fn amplitude(&self) -> f64
Returns the value of amplitude, or the default value if amplitude is unset.
Sourcepub fn market_cap(&self) -> f64
pub fn market_cap(&self) -> f64
Returns the value of market_cap, or the default value if market_cap is unset.
Sourcepub fn volume_ratio(&self) -> f64
pub fn volume_ratio(&self) -> f64
Returns the value of volume_ratio, or the default value if volume_ratio is unset.