pub struct C2s {
pub security: Security,
pub valuation_type: Option<i32>,
pub interval_type: Option<i32>,
}Expand description
===== 请求 / 响应 =====
Fields
security: Security股票
valuation_type: Option<i32>估值类型,详见 Qot_Common.ValuationType 定义,默认 0(Unknown,使用推荐类型)
interval_type: Option<i32>历史数据时间周期,详见 Qot_Common.ValuationIntervalType 定义
Implementations
Sourceimpl C2s
impl C2s
Sourcepub fn valuation_type(&self) -> ValuationType
pub fn valuation_type(&self) -> ValuationType
Returns the enum value of valuation_type, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_valuation_type(&mut self, value: ValuationType)
pub fn set_valuation_type(&mut self, value: ValuationType)
Sets valuation_type to the provided enum value.
Sourcepub fn interval_type(&self) -> ValuationIntervalType
pub fn interval_type(&self) -> ValuationIntervalType
Returns the enum value of interval_type, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_interval_type(&mut self, value: ValuationIntervalType)
pub fn set_interval_type(&mut self, value: ValuationIntervalType)
Sets interval_type to the provided enum value.