pub struct C2s {
pub security: Security,
pub valuation_type: Option<i32>,
pub next_key: Option<String>,
pub num: Option<i32>,
pub sort_type: Option<i32>,
pub sort_id: Option<i32>,
pub filter_security: Option<Security>,
}Fields
security: Security股票
valuation_type: Option<i32>估值类型,详见 Qot_Common.ValuationType 定义,支持 1-3,默认 1(PE)
next_key: Option<String>分页标识,首次不填,续拉时填上次返回的 nextKey;“-1” 表示无更多数据
num: Option<i32>每页返回数量,默认 10,范围 1~50
sort_type: Option<i32>排序方向,详见 Qot_Common.SortType 定义,默认升序(SortType_Asc=2)
sort_id: Option<i32>排序列,详见 Qot_Common.SortField,51=市值(默认)52=估值 53=预测估值 54=历史分位
filter_security: Option<Security>板块:仅指数成分股估值有效,按板块筛选成分股,不传则不筛选
Implementations
Sourceimpl C2s
impl C2s
Sourcepub fn valuation_type(&self) -> ValuationType
pub fn valuation_type(&self) -> ValuationType
Returns the enum value of valuation_type, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_valuation_type(&mut self, value: ValuationType)
pub fn set_valuation_type(&mut self, value: ValuationType)
Sets valuation_type to the provided enum value.
Sourcepub fn next_key(&self) -> &str
pub fn next_key(&self) -> &str
Returns the value of next_key, or the default value if next_key is unset.
Sourcepub fn sort_type(&self) -> SortType
pub fn sort_type(&self) -> SortType
Returns the enum value of sort_type, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_sort_type(&mut self, value: SortType)
pub fn set_sort_type(&mut self, value: SortType)
Sets sort_type to the provided enum value.
Sourcepub fn sort_id(&self) -> SortField
pub fn sort_id(&self) -> SortField
Returns the enum value of sort_id, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_sort_id(&mut self, value: SortField)
pub fn set_sort_id(&mut self, value: SortField)
Sets sort_id to the provided enum value.