pub struct WatchlistNewsItem {Show 18 fields
pub item_type: Option<i32>,
pub news_id: Option<u64>,
pub news_type: Option<u32>,
pub title: Option<String>,
pub abstract: Option<String>,
pub time: Option<i64>,
pub url: Option<String>,
pub pic: Option<String>,
pub source: Option<String>,
pub stock_ids: Vec<u64>,
pub news_unique_id: Option<String>,
pub origin_lang: Option<String>,
pub show_translate_button: Option<bool>,
pub new_news_id: Option<String>,
pub futu_source: Option<String>,
pub news_content_type: Option<u32>,
pub link_type: Option<u32>,
pub is_auto_translated: Option<u32>,
}Fields
item_type: Option<i32>news_id: Option<u64>news_type: Option<u32>title: Option<String>abstract: Option<String>time: Option<i64>url: Option<String>pic: Option<String>source: Option<String>stock_ids: Vec<u64>news_unique_id: Option<String>origin_lang: Option<String>new_news_id: Option<String>futu_source: Option<String>news_content_type: Option<u32>link_type: Option<u32>is_auto_translated: Option<u32>Implementations
Sourceimpl WatchlistNewsItem
impl WatchlistNewsItem
Sourcepub fn item_type(&self) -> i32
pub fn item_type(&self) -> i32
Returns the value of item_type, or the default value if item_type is unset.
Sourcepub fn news_id(&self) -> u64
pub fn news_id(&self) -> u64
Returns the value of news_id, or the default value if news_id is unset.
Sourcepub fn news_type(&self) -> u32
pub fn news_type(&self) -> u32
Returns the value of news_type, or the default value if news_type is unset.
Sourcepub fn title(&self) -> &str
pub fn title(&self) -> &str
Returns the value of title, or the default value if title is unset.
Sourcepub fn abstract(&self) -> &str
pub fn abstract(&self) -> &str
Returns the value of abstract, or the default value if abstract is unset.
Sourcepub fn source(&self) -> &str
pub fn source(&self) -> &str
Returns the value of source, or the default value if source is unset.
Sourcepub fn news_unique_id(&self) -> &str
pub fn news_unique_id(&self) -> &str
Returns the value of news_unique_id, or the default value if news_unique_id is unset.
Sourcepub fn origin_lang(&self) -> &str
pub fn origin_lang(&self) -> &str
Returns the value of origin_lang, or the default value if origin_lang is unset.
Returns the value of show_translate_button, or the default value if show_translate_button is unset.
Sourcepub fn new_news_id(&self) -> &str
pub fn new_news_id(&self) -> &str
Returns the value of new_news_id, or the default value if new_news_id is unset.
Sourcepub fn futu_source(&self) -> &str
pub fn futu_source(&self) -> &str
Returns the value of futu_source, or the default value if futu_source is unset.
Sourcepub fn news_content_type(&self) -> u32
pub fn news_content_type(&self) -> u32
Returns the value of news_content_type, or the default value if news_content_type is unset.
Sourcepub fn link_type(&self) -> u32
pub fn link_type(&self) -> u32
Returns the value of link_type, or the default value if link_type is unset.
Sourcepub fn is_auto_translated(&self) -> u32
pub fn is_auto_translated(&self) -> u32
Returns the value of is_auto_translated, or the default value if is_auto_translated is unset.