#[repr(i32)]pub enum EarningsIndicatorType {
Show 21 variants
Unknown = 0,
OwnerList = 1,
IndexComponent = 2,
Plate = 3,
MarketCap = 4,
ExpirationType = 5,
Iv = 6,
LastReportIvCrush = 7,
HistoryReportIvCrush = 8,
IvRank = 9,
IvPercentile = 10,
Volume = 11,
OpenInterest = 12,
Price = 13,
ChangeRate = 14,
ExpectedMoveRatio = 15,
LastReportChgRate = 16,
HistoryReportChgRate = 17,
EstimateRevenueYoy = 18,
EstimateEpsYoy = 19,
EarningsDayRange = 20,
}Expand description
财报机会筛选因子类型
Variants
Unknown = 0
OwnerList = 1
【确切值】自选股列表(securityList)
IndexComponent = 2
【确切值】所属指数(valueList, IndexComponentType)
Plate = 3
【确切值】所属行业/板块(valueList, 板块ID)
MarketCap = 4
【范围】市值
ExpirationType = 5
【确切值】到期类型(valueList, ExpirationType)
Iv = 6
【范围】隐含波动率(%)
LastReportIvCrush = 7
【范围】上次IV Crush(%)
HistoryReportIvCrush = 8
【范围】历史IV Crush(%)
IvRank = 9
【范围】IV等级(%)
IvPercentile = 10
【范围】IV百分位数(%)
Volume = 11
【范围】期权成交量
OpenInterest = 12
【范围】期权持仓量
Price = 13
【范围】最新价
ChangeRate = 14
【范围】涨跌幅(%)
ExpectedMoveRatio = 15
【范围】预测波动(%)
LastReportChgRate = 16
【范围】上次财报日涨跌幅(%)
HistoryReportChgRate = 17
【范围】历史财报日涨跌幅(%)
EstimateRevenueYoy = 18
【范围】预测营收同比(%)
EstimateEpsYoy = 19
【范围】预测EPS同比(%)
EarningsDayRange = 20
【范围】距财报日天数
Implementations
Sourceimpl EarningsIndicatorType
impl EarningsIndicatorType
Sourcepub const fn is_valid(value: i32) -> bool
pub const fn is_valid(value: i32) -> bool
Returns true if value is a variant of EarningsIndicatorType.
Sourcepub fn from_i32(value: i32) -> Option<EarningsIndicatorType>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<EarningsIndicatorType>
Use the TryFrom<i32> implementation instead
Converts an i32 to a EarningsIndicatorType, or None if value is not a valid variant.
Sourceimpl EarningsIndicatorType
impl EarningsIndicatorType
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.