#[repr(i32)]pub enum IndexComponentType {
Unknown = 0,
Dji = 1,
Ixic = 2,
Ndx = 3,
Spx = 4,
}Expand description
指数成分类型
Variants
Implementations
Sourceimpl IndexComponentType
impl IndexComponentType
Sourcepub fn from_i32(value: i32) -> Option<IndexComponentType>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<IndexComponentType>
Use the TryFrom<i32> implementation instead
Converts an i32 to a IndexComponentType, or None if value is not a valid variant.
Sourceimpl IndexComponentType
impl IndexComponentType
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.