#[repr(i32)]pub enum OptionHvTimeRange {
Unknown = 0,
OptionHvTimeRange30day = 1,
OptionHvTimeRange60day = 2,
OptionHvTimeRange90day = 3,
OptionHvTimeRange120day = 4,
OptionHvTimeRange365day = 5,
}Expand description
历史波动率时间范围
Variants
Unknown = 0
未知
OptionHvTimeRange30day = 1
30日
OptionHvTimeRange60day = 2
60日
OptionHvTimeRange90day = 3
90日
OptionHvTimeRange120day = 4
120日
OptionHvTimeRange365day = 5
365日
Implementations
Sourceimpl OptionHvTimeRange
impl OptionHvTimeRange
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.