#[repr(i32)]pub enum OptionRankType {
Unknown = 0,
Volume = 1,
Turnover = 2,
Oi = 3,
OiIncrement = 4,
OiDecrement = 5,
OiMarketCap = 6,
OiMarketCapIncrement = 7,
OiMarketCapDecrement = 8,
ChangeRate = 9,
Iv = 10,
}Expand description
期权合约排行类型
Variants
Unknown = 0
未知
Volume = 1
成交量排行
Turnover = 2
成交额排行
Oi = 3
持仓量排行
OiIncrement = 4
增仓量(日)排行
OiDecrement = 5
减仓量(日)排行
OiMarketCap = 6
持仓额排行
OiMarketCapIncrement = 7
增仓额(日)排行
OiMarketCapDecrement = 8
减仓额(日)排行
ChangeRate = 9
涨跌幅排行
Iv = 10
隐含波动率排行
Implementations
Sourceimpl OptionRankType
impl OptionRankType
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.