#[repr(i32)]pub enum SellerIndicatorType {
Show 27 variants
Unknown = 0,
OwnerList = 1,
StockCategory = 2,
Volume = 3,
OpenInterest = 4,
Iv = 5,
Hv = 6,
IvRank = 7,
IvPercentile = 8,
MarketCap = 9,
Price = 10,
ChangeRate = 11,
Plate = 12,
ExpirationType = 13,
LeftDays = 14,
OptionExpirationType = 15,
StrikeDateTimestamp = 16,
Premium = 17,
AnnualizedReturn = 18,
IntervalReturn = 19,
OtmDegree = 20,
OtmProbability = 21,
OptionIv = 22,
BidPrice = 23,
AskPrice = 24,
OptionVolume = 25,
OptionOpenInterest = 26,
}Expand description
卖方专区筛选因子类型
Variants
Unknown = 0
OwnerList = 1
–– 标的级 ––
【确切值】自选股列表(securityList)
StockCategory = 2
【确切值】标的品类(valueList, StockCategory)
Volume = 3
【范围】期权总成交量(默认>0)
OpenInterest = 4
【范围】期权总持仓量(默认>0)
Iv = 5
【范围】标的IV(%)
Hv = 6
【范围】标的HV(%)
IvRank = 7
【范围】IV等级(%)
IvPercentile = 8
【范围】IV百分位数(%)
MarketCap = 9
【范围】标的市值(默认>10B)
Price = 10
【范围】标的最新价(默认>$1)
ChangeRate = 11
【范围】标的涨跌幅(%)
Plate = 12
【确切值】板块(valueList, 板块ID)
ExpirationType = 13
【确切值】到期类型(valueList, ExpirationType)
LeftDays = 14
–– 期权级 ––
【范围】距到期日(天)(默认>0)
OptionExpirationType = 15
【确切值】期权到期类型(valueList, ExpirationType)
StrikeDateTimestamp = 16
【确切值】到期日时间戳(valueList, 秒)
Premium = 17
【范围】权利金
AnnualizedReturn = 18
【范围】年化收益率(%)
IntervalReturn = 19
【范围】区间收益率(%)
OtmDegree = 20
【范围】价外程度(%)(默认>0)
OtmProbability = 21
【范围】价外概率(%)
OptionIv = 22
【范围】期权隐含波动率(%)
BidPrice = 23
【范围】期权买价(默认>$0.01)
AskPrice = 24
【范围】期权卖价(默认>$0.01)
OptionVolume = 25
【范围】期权成交量(默认>0)
OptionOpenInterest = 26
【范围】期权持仓量(默认>0)
Implementations
Sourceimpl SellerIndicatorType
impl SellerIndicatorType
Sourcepub const fn is_valid(value: i32) -> bool
pub const fn is_valid(value: i32) -> bool
Returns true if value is a variant of SellerIndicatorType.
Sourcepub fn from_i32(value: i32) -> Option<SellerIndicatorType>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<SellerIndicatorType>
Use the TryFrom<i32> implementation instead
Converts an i32 to a SellerIndicatorType, or None if value is not a valid variant.
Sourceimpl SellerIndicatorType
impl SellerIndicatorType
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.