UnderlyingRankIndicatorType

Enum UnderlyingRankIndicatorType 

#[repr(i32)]
pub enum UnderlyingRankIndicatorType {
Show 14 variants Unknown = 0, OwnerList = 1, StockCategory = 2, Volume = 3, OpenInterest = 4, Iv = 5, Hv = 6, IvRank = 7, IvPercentile = 8, IvChange = 9, HvChange = 10, VolumeRatio = 11, OiRatio = 12, MarketCap = 13,
}
标的排行筛选因子类型

Variants



Unknown = 0



OwnerList = 1

【确切值】指定标的列表(securityList)



StockCategory = 2

【确切值】标的品类(valueList, StockCategory)



Volume = 3

【范围】总成交量



OpenInterest = 4

【范围】总持仓量



Iv = 5

【范围】IV(%)



Hv = 6

【范围】HV(%)



IvRank = 7

【范围】IV Rank(%)



IvPercentile = 8

【范围】IV Percentile(%)



IvChange = 9

【范围】IV变化率(%)



HvChange = 10

【范围】HV变化率(%)



VolumeRatio = 11

【范围】成交量P/C比值(%)



OiRatio = 12

【范围】持仓量P/C比值(%)



MarketCap = 13

【范围】市值

Implementations

Source

impl UnderlyingRankIndicatorType

pub fn is_valid(value: i32) -> bool

Returns true if value is a variant of UnderlyingRankIndicatorType.

pub fn from_i32(value: i32) -> Option<UnderlyingRankIndicatorType>

👎Deprecated:

Use the TryFrom<i32> implementation instead

Converts an i32 to a UnderlyingRankIndicatorType, or None if value is not a valid variant.

Source

impl UnderlyingRankIndicatorType

pub fn as_str_name(&self) -> &'static str

String value of the enum field names used in the ProtoBuf definition.

The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.

pub fn from_str_name(value: &str) -> Option<Self>

Creates an enum from field names used in the ProtoBuf definition.