#[repr(i32)]pub enum ZeroDteContractIndicatorType {
Show 16 variants
Unknown = 0,
OptionType = 1,
Volume = 2,
OpenInterest = 3,
Iv = 4,
Delta = 5,
Gamma = 6,
Theta = 7,
Vega = 8,
Rho = 9,
Price = 10,
ChangeRate = 11,
BreakEvenPoint = 12,
ToBep = 13,
BuyProfitProbability = 14,
SellProfitProbability = 15,
}Expand description
末日期权合约筛选因子类型
Variants
Unknown = 0
OptionType = 1
【确切值】期权方向(Qot_Common.OptionType: 1=Call, 2=Put)
Volume = 2
【范围】成交量
OpenInterest = 3
【范围】未平仓数
Iv = 4
【范围】隐含波动率(%)
Delta = 5
【范围】Delta
Gamma = 6
【范围】Gamma
Theta = 7
【范围】Theta
Vega = 8
【范围】Vega
Rho = 9
【范围】Rho
Price = 10
【范围】最新价
ChangeRate = 11
【范围】涨跌幅(%)
BreakEvenPoint = 12
【范围】盈亏平衡点
ToBep = 13
【范围】到盈亏平衡点(%)
BuyProfitProbability = 14
【范围】买入盈利概率(%)
SellProfitProbability = 15
【范围】卖出盈利概率(%)
Implementations
Sourceimpl ZeroDteContractIndicatorType
impl ZeroDteContractIndicatorType
Sourcepub fn is_valid(value: i32) -> bool
pub fn is_valid(value: i32) -> bool
Returns true if value is a variant of ZeroDteContractIndicatorType.
Sourcepub fn from_i32(value: i32) -> Option<ZeroDteContractIndicatorType>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<ZeroDteContractIndicatorType>
Use the TryFrom<i32> implementation instead
Converts an i32 to a ZeroDteContractIndicatorType, or None if value is not a valid variant.
Sourceimpl ZeroDteContractIndicatorType
impl ZeroDteContractIndicatorType
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.