#[repr(i32)]pub enum ZeroDteIndicatorType {
Unknown = 0,
OwnerList = 1,
HasEarningsThisWeek = 2,
Volume = 3,
OpenInterest = 4,
Iv = 5,
Hv = 6,
IvRank = 7,
IvPercentile = 8,
Price = 9,
ChangeRate = 10,
}Expand description
末日期权标的筛选因子类型
Variants
Unknown = 0
OwnerList = 1
【确切值】自选股列表(securityList)
HasEarningsThisWeek = 2
【确切值】本周是否有财报(valueList: 0=不限, 1=有, 2=无)
Volume = 3
【范围】期权总成交量
OpenInterest = 4
【范围】期权总持仓量
Iv = 5
【范围】隐含波动率(%)
Hv = 6
【范围】历史波动率(%)
IvRank = 7
【范围】IV等级(%)
IvPercentile = 8
【范围】IV百分位数(%)
Price = 9
【范围】最新价
ChangeRate = 10
【范围】涨跌幅(%)
Implementations
Sourceimpl ZeroDteIndicatorType
impl ZeroDteIndicatorType
Sourcepub fn is_valid(value: i32) -> bool
pub fn is_valid(value: i32) -> bool
Returns true if value is a variant of ZeroDteIndicatorType.
Sourcepub fn from_i32(value: i32) -> Option<ZeroDteIndicatorType>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<ZeroDteIndicatorType>
Use the TryFrom<i32> implementation instead
Converts an i32 to a ZeroDteIndicatorType, or None if value is not a valid variant.
Sourceimpl ZeroDteIndicatorType
impl ZeroDteIndicatorType
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.