#[repr(i32)]pub enum MarketCategory {
UsStock = 0,
UsIndex = 1,
UsFuture = 2,
HkStock = 3,
HkIndex = 4,
JpStock = 5,
JpIndex = 6,
}Expand description
期权市场品类 (枚举值与后台 FTCmdOptionMarket.MarketCategory 一致, 直接透传)
Variants
UsStock = 0
美股股票期权
UsIndex = 1
美股指数期权
UsFuture = 2
美股期货期权
HkStock = 3
港股股票期权
HkIndex = 4
港股指数期权
JpStock = 5
日股股票期权
JpIndex = 6
日股指数期权
Implementations
Sourceimpl MarketCategory
impl MarketCategory
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.