OptionIndicatorType

Enum OptionIndicatorType 

#[repr(i32)]
pub enum OptionIndicatorType {
Show 46 variants Unknown = 0, StrikePrice = 1_001, LeftDay = 1_002, OptionType = 1_003, ExerciseType = 1_004, ExpirationType = 1_005, StrikeDateTimestamp = 1_007, InTheMoney = 2_001, Price = 2_002, MidPrice = 2_003, BidPrice = 2_004, AskPrice = 2_005, BidAskSpread = 2_006, BidVolume = 2_007, AskVolume = 2_008, BidAskVolumeRatio = 2_009, ChangeRatio = 2_010, Volume = 2_011, Turnover = 2_012, OpenInterest = 2_013, OpenInterestMarketCap = 2_014, VolOiRatio = 2_018, Premium = 2_021, ImpliedVolatility = 3_001, HistoryVolatility = 3_002, IvhvRatio = 3_003, Delta = 3_004, Gamma = 3_005, Vega = 3_006, Theta = 3_007, Rho = 3_008, LeverageRatio = 3_009, EffectiveGearing = 3_010, BuyToBep = 3_011, SellToBep = 3_012, BuyProfitProbability = 3_013, SellProfitProbability = 3_014, IntrinsicValuePer = 3_015, TimeValuePer = 3_016, ItmDegree = 3_017, OtmDegree = 3_018, ItmProbability = 3_019, OtmProbability = 3_020, SellAnnualizedReturn = 3_021, IntervalReturn = 3_022, BuyBreakEvenPoint = 3_023,
}
期权筛选因子类型

Variants



Unknown = 0

未知



StrikePrice = 1_001

期权静态信息

【范围】行权价



LeftDay = 1_002

【范围】距离到期日天数



OptionType = 1_003

【确切值】期权类型(CALL/PUT)



ExerciseType = 1_004

【确切值】行权方式(美式/欧式)



ExpirationType = 1_005

【确切值】到期类型(周/月/季)



StrikeDateTimestamp = 1_007

【确切值】到期日时间戳(秒)



InTheMoney = 2_001

期权实时行情

【确切值】价内/价外(0:价外,1:价内)



Price = 2_002

【范围】期权价格



MidPrice = 2_003

【范围】期权中间价



BidPrice = 2_004

【范围】买价



AskPrice = 2_005

【范围】卖价



BidAskSpread = 2_006

【范围】买卖价差



BidVolume = 2_007

【范围】买量



AskVolume = 2_008

【范围】卖量



BidAskVolumeRatio = 2_009

【范围】买卖量比



ChangeRatio = 2_010

【范围】涨跌幅



Volume = 2_011

【范围】成交量



Turnover = 2_012

【范围】成交额



OpenInterest = 2_013

【范围】持仓量



OpenInterestMarketCap = 2_014

【范围】持仓市值



VolOiRatio = 2_018

【范围】成交量/持仓量



Premium = 2_021

⚠️ filter 不支持(后端 option_screener_svc 未实装, 入口拦截报错); sort/retrieve 可用

【范围】权利金, 仅 sort/retrieve



ImpliedVolatility = 3_001

期权分析指标

【范围】隐含波动率



HistoryVolatility = 3_002

【范围】历史波动率



IvhvRatio = 3_003

【范围】IV/HV



Delta = 3_004

【范围】Delta



Gamma = 3_005

【范围】Gamma



Vega = 3_006

【范围】Vega



Theta = 3_007

【范围】Theta



Rho = 3_008

【范围】Rho



LeverageRatio = 3_009

【范围】杠杆比率



EffectiveGearing = 3_010

【范围】有效杠杆



BuyToBep = 3_011

【范围】买入到盈亏平衡点比率



SellToBep = 3_012

【范围】卖出到盈亏平衡点比率



BuyProfitProbability = 3_013

【范围】买入盈利概率



SellProfitProbability = 3_014

【范围】卖出盈利概率



IntrinsicValuePer = 3_015

【范围】内在价值百分比



TimeValuePer = 3_016

【范围】时间价值百分比



ItmDegree = 3_017

【范围】价内程度



OtmDegree = 3_018

【范围】价外程度



ItmProbability = 3_019

【范围】价内概率



OtmProbability = 3_020

【范围】价外概率



SellAnnualizedReturn = 3_021

【范围】卖出年化收益率



IntervalReturn = 3_022

【范围】卖出区间收益率



BuyBreakEvenPoint = 3_023

👎Deprecated

⚠️ 已废弃: 不支持 filter/sort/retrieve, 传入会报错。新代码请使用 BuyToBep(3011)。

已废弃, 传入会报错

Implementations

Source

impl OptionIndicatorType

pub fn is_valid(value: i32) -> bool

Returns true if value is a variant of OptionIndicatorType.

pub fn from_i32(value: i32) -> Option<OptionIndicatorType>

👎Deprecated:

Use the TryFrom<i32> implementation instead

Converts an i32 to a OptionIndicatorType, or None if value is not a valid variant.

Source

impl OptionIndicatorType

pub fn as_str_name(&self) -> &'static str

String value of the enum field names used in the ProtoBuf definition.

The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.

pub fn from_str_name(value: &str) -> Option<Self>

Creates an enum from field names used in the ProtoBuf definition.