OptionScreenItem

Struct OptionScreenItem 

pub struct OptionScreenItem {
Show 48 fields pub security: Option<Security>, pub option_name: Option<String>, pub strike_price: Option<f64>, pub strike_date: Option<i64>, pub option_type: Option<i32>, pub exercise_type: Option<i32>, pub expiration_type: Option<i32>, pub in_the_money: Option<i32>, pub left_day: Option<i32>, pub price: Option<f64>, pub mid_price: Option<f64>, pub bid_price: Option<f64>, pub ask_price: Option<f64>, pub bid_ask_spread: Option<f64>, pub bid_volume: Option<i64>, pub ask_volume: Option<i64>, pub change_ratio: Option<f64>, pub volume: Option<i64>, pub turnover: Option<f64>, pub open_interest: Option<i64>, pub bid_ask_volume_ratio: Option<f64>, pub open_interest_market_cap: Option<f64>, pub vol_oi_ratio: Option<f64>, pub premium: Option<f64>, pub implied_volatility: Option<f64>, pub delta: Option<f64>, pub gamma: Option<f64>, pub vega: Option<f64>, pub theta: Option<f64>, pub rho: Option<f64>, pub leverage_ratio: Option<f64>, pub effective_gearing: Option<f64>, pub itm_probability: Option<f64>, pub buy_break_even_point: Option<f64>, pub underlying_info: Option<UnderlyingInfo>, pub history_volatility: Option<f64>, pub iv_hv_ratio: Option<f64>, pub buy_to_bep: Option<f64>, pub sell_to_bep: Option<f64>, pub buy_profit_probability: Option<f64>, pub sell_profit_probability: Option<f64>, pub intrinsic_value_per: Option<f64>, pub time_value_per: Option<f64>, pub itm_degree: Option<f64>, pub otm_degree: Option<f64>, pub otm_probability: Option<f64>, pub sell_annualized_return: Option<f64>, pub interval_return: Option<f64>,
}
期权数据项

Fields

security: Option<Security>

期权证券信息

option_name: Option<String>

期权名称

strike_price: Option<f64>

行权价

strike_date: Option<i64>

行权日(格式YYYYMMDD)

option_type: Option<i32>

期权类型(CALL/PUT)

exercise_type: Option<i32>

行权方式

expiration_type: Option<i32>

到期类型

in_the_money: Option<i32>

价内/价外(0:价外,1:价内)

left_day: Option<i32>

距到期天数

price: Option<f64>

行情数据

期权价格

mid_price: Option<f64>

中间价

bid_price: Option<f64>

买价

ask_price: Option<f64>

卖价

bid_ask_spread: Option<f64>

买卖价差

bid_volume: Option<i64>

买量

ask_volume: Option<i64>

卖量

change_ratio: Option<f64>

涨跌幅

volume: Option<i64>

成交量

turnover: Option<f64>

成交额

open_interest: Option<i64>

持仓量

bid_ask_volume_ratio: Option<f64>

买卖量比

open_interest_market_cap: Option<f64>

持仓市值

vol_oi_ratio: Option<f64>

成交量/持仓量

premium: Option<f64>

权利金

implied_volatility: Option<f64>

Greeks

隐含波动率

delta: Option<f64>

Delta

gamma: Option<f64>

Gamma

vega: Option<f64>

Vega

theta: Option<f64>

Theta

rho: Option<f64>

Rho

leverage_ratio: Option<f64>

杠杆比率

effective_gearing: Option<f64>

有效杠杆

itm_probability: Option<f64>

价内概率

buy_break_even_point: Option<f64>
👎Deprecated

⚠️ 历史字段: 后端未返回对应数据, 已弃用, 始终不填充 新代码请用 buyToBep (字段 53)

已弃用, 始终为空

underlying_info: Option<UnderlyingInfo>

标的信息

标的信息

history_volatility: Option<f64>

期权分析指标 (续)

历史波动率

iv_hv_ratio: Option<f64>

IV/HV

buy_to_bep: Option<f64>

买入到盈亏平衡点比率

sell_to_bep: Option<f64>

卖出到盈亏平衡点比率

buy_profit_probability: Option<f64>

买入盈利概率

sell_profit_probability: Option<f64>

卖出盈利概率

intrinsic_value_per: Option<f64>

内在价值百分比

time_value_per: Option<f64>

时间价值百分比

itm_degree: Option<f64>

价内程度

otm_degree: Option<f64>

价外程度

otm_probability: Option<f64>

价外概率

sell_annualized_return: Option<f64>

卖出年化收益率

interval_return: Option<f64>

卖出区间收益率

Implementations

Source

impl OptionScreenItem

pub fn option_name(&self) -> &str

Returns the value of option_name, or the default value if option_name is unset.

pub fn strike_price(&self) -> f64

Returns the value of strike_price, or the default value if strike_price is unset.

pub fn strike_date(&self) -> i64

Returns the value of strike_date, or the default value if strike_date is unset.

pub fn option_type(&self) -> i32

Returns the value of option_type, or the default value if option_type is unset.

pub fn exercise_type(&self) -> i32

Returns the value of exercise_type, or the default value if exercise_type is unset.

pub fn expiration_type(&self) -> i32

Returns the value of expiration_type, or the default value if expiration_type is unset.

pub fn in_the_money(&self) -> i32

Returns the value of in_the_money, or the default value if in_the_money is unset.

pub fn left_day(&self) -> i32

Returns the value of left_day, or the default value if left_day is unset.

pub fn price(&self) -> f64

Returns the value of price, or the default value if price is unset.

pub fn mid_price(&self) -> f64

Returns the value of mid_price, or the default value if mid_price is unset.

pub fn bid_price(&self) -> f64

Returns the value of bid_price, or the default value if bid_price is unset.

pub fn ask_price(&self) -> f64

Returns the value of ask_price, or the default value if ask_price is unset.

pub fn bid_ask_spread(&self) -> f64

Returns the value of bid_ask_spread, or the default value if bid_ask_spread is unset.

pub fn bid_volume(&self) -> i64

Returns the value of bid_volume, or the default value if bid_volume is unset.

pub fn ask_volume(&self) -> i64

Returns the value of ask_volume, or the default value if ask_volume is unset.

pub fn change_ratio(&self) -> f64

Returns the value of change_ratio, or the default value if change_ratio is unset.

pub fn volume(&self) -> i64

Returns the value of volume, or the default value if volume is unset.

pub fn turnover(&self) -> f64

Returns the value of turnover, or the default value if turnover is unset.

pub fn open_interest(&self) -> i64

Returns the value of open_interest, or the default value if open_interest is unset.

pub fn bid_ask_volume_ratio(&self) -> f64

Returns the value of bid_ask_volume_ratio, or the default value if bid_ask_volume_ratio is unset.

pub fn open_interest_market_cap(&self) -> f64

Returns the value of open_interest_market_cap, or the default value if open_interest_market_cap is unset.

pub fn vol_oi_ratio(&self) -> f64

Returns the value of vol_oi_ratio, or the default value if vol_oi_ratio is unset.

pub fn premium(&self) -> f64

Returns the value of premium, or the default value if premium is unset.

pub fn implied_volatility(&self) -> f64

Returns the value of implied_volatility, or the default value if implied_volatility is unset.

pub fn delta(&self) -> f64

Returns the value of delta, or the default value if delta is unset.

pub fn gamma(&self) -> f64

Returns the value of gamma, or the default value if gamma is unset.

pub fn vega(&self) -> f64

Returns the value of vega, or the default value if vega is unset.

pub fn theta(&self) -> f64

Returns the value of theta, or the default value if theta is unset.

pub fn rho(&self) -> f64

Returns the value of rho, or the default value if rho is unset.

pub fn leverage_ratio(&self) -> f64

Returns the value of leverage_ratio, or the default value if leverage_ratio is unset.

pub fn effective_gearing(&self) -> f64

Returns the value of effective_gearing, or the default value if effective_gearing is unset.

pub fn itm_probability(&self) -> f64

Returns the value of itm_probability, or the default value if itm_probability is unset.

pub fn buy_break_even_point(&self) -> f64

Returns the value of buy_break_even_point, or the default value if buy_break_even_point is unset.

pub fn history_volatility(&self) -> f64

Returns the value of history_volatility, or the default value if history_volatility is unset.

pub fn iv_hv_ratio(&self) -> f64

Returns the value of iv_hv_ratio, or the default value if iv_hv_ratio is unset.

pub fn buy_to_bep(&self) -> f64

Returns the value of buy_to_bep, or the default value if buy_to_bep is unset.

pub fn sell_to_bep(&self) -> f64

Returns the value of sell_to_bep, or the default value if sell_to_bep is unset.

pub fn buy_profit_probability(&self) -> f64

Returns the value of buy_profit_probability, or the default value if buy_profit_probability is unset.

pub fn sell_profit_probability(&self) -> f64

Returns the value of sell_profit_probability, or the default value if sell_profit_probability is unset.

pub fn intrinsic_value_per(&self) -> f64

Returns the value of intrinsic_value_per, or the default value if intrinsic_value_per is unset.

pub fn time_value_per(&self) -> f64

Returns the value of time_value_per, or the default value if time_value_per is unset.

pub fn itm_degree(&self) -> f64

Returns the value of itm_degree, or the default value if itm_degree is unset.

pub fn otm_degree(&self) -> f64

Returns the value of otm_degree, or the default value if otm_degree is unset.

pub fn otm_probability(&self) -> f64

Returns the value of otm_probability, or the default value if otm_probability is unset.

pub fn sell_annualized_return(&self) -> f64

Returns the value of sell_annualized_return, or the default value if sell_annualized_return is unset.

pub fn interval_return(&self) -> f64

Returns the value of interval_return, or the default value if interval_return is unset.