UnderlyingInfo

Struct UnderlyingInfo 

pub struct UnderlyingInfo {
    pub stock_id: Option<u64>,
    pub iv: Option<f64>,
    pub hv: Option<f64>,
    pub iv_rank: Option<f64>,
    pub iv_percentile: Option<f64>,
    pub market_cap: Option<f64>,
    pub price: Option<f64>,
    pub change_ratio: Option<f64>,
}
标的统计信息

Fields

stock_id: Option<u64>

标的股票ID

iv: Option<f64>

标的IV

hv: Option<f64>

标的HV

iv_rank: Option<f64>

IV Rank

iv_percentile: Option<f64>

IV Percentile

market_cap: Option<f64>

市值

price: Option<f64>

标的价格

change_ratio: Option<f64>

涨跌幅

Implementations

Source

impl UnderlyingInfo

pub fn stock_id(&self) -> u64

Returns the value of stock_id, or the default value if stock_id is unset.

pub fn iv(&self) -> f64

Returns the value of iv, or the default value if iv is unset.

pub fn hv(&self) -> f64

Returns the value of hv, or the default value if hv is unset.

pub fn iv_rank(&self) -> f64

Returns the value of iv_rank, or the default value if iv_rank is unset.

pub fn iv_percentile(&self) -> f64

Returns the value of iv_percentile, or the default value if iv_percentile is unset.

pub fn market_cap(&self) -> f64

Returns the value of market_cap, or the default value if market_cap is unset.

pub fn price(&self) -> f64

Returns the value of price, or the default value if price is unset.

pub fn change_ratio(&self) -> f64

Returns the value of change_ratio, or the default value if change_ratio is unset.