#[repr(i32)]pub enum SetPriceReminderOp {
Unknown = 0,
Add = 1,
Del = 2,
Enable = 3,
Disable = 4,
Modify = 5,
DelAll = 6,
}Variants
Unknown = 0
Add = 1
新增
Del = 2
删除
Enable = 3
启用
Disable = 4
禁用
Modify = 5
修改
DelAll = 6
删除该支股票下所有到价提醒
Implementations
Sourceimpl SetPriceReminderOp
impl SetPriceReminderOp
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.