pub struct C2s {
pub operation: i32,
pub stock_id: u64,
pub title: Option<String>,
pub detail: Option<String>,
pub is_display: Option<u32>,
pub extension_version: u32,
}Fields
operation: i32stock_id: u64title: Option<String>detail: Option<String>is_display: Option<u32>extension_version: u32Implementations
Sourceimpl C2s
impl C2s
Sourcepub fn operation(&self) -> Operation
pub fn operation(&self) -> Operation
Returns the enum value of operation, or the default if the field is set to an invalid enum value.
Sourcepub fn set_operation(&mut self, value: Operation)
pub fn set_operation(&mut self, value: Operation)
Sets operation to the provided enum value.
Sourcepub fn title(&self) -> &str
pub fn title(&self) -> &str
Returns the value of title, or the default value if title is unset.
Sourcepub fn detail(&self) -> &str
pub fn detail(&self) -> &str
Returns the value of detail, or the default value if detail is unset.
Sourcepub fn is_display(&self) -> u32
pub fn is_display(&self) -> u32
Returns the value of is_display, or the default value if is_display is unset.