pub struct S2c {
pub outcome: i32,
pub backend_ret_code_present: bool,
pub backend_ret_code: Option<u32>,
pub ranges_valid: bool,
pub raw_sensitive_ranges: Vec<SensitiveRange>,
pub derived_sensitive_ranges: Vec<SensitiveRange>,
}Fields
outcome: i32backend_ret_code_present: boolbackend_ret_code: Option<u32>ranges_valid: boolraw_sensitive_ranges: Vec<SensitiveRange>derived_sensitive_ranges: Vec<SensitiveRange>Implementations
Sourceimpl S2c
impl S2c
Sourcepub fn outcome(&self) -> Outcome
pub fn outcome(&self) -> Outcome
Returns the enum value of outcome, or the default if the field is set to an invalid enum value.
Sourcepub fn set_outcome(&mut self, value: Outcome)
pub fn set_outcome(&mut self, value: Outcome)
Sets outcome to the provided enum value.
Sourcepub fn backend_ret_code(&self) -> u32
pub fn backend_ret_code(&self) -> u32
Returns the value of backend_ret_code, or the default value if backend_ret_code is unset.