#[repr(i32)]pub enum AccumulateField {
Unknown = 0,
ChangeRate = 1,
Amplitude = 2,
Volume = 3,
Turnover = 4,
TurnoverRate = 5,
}Expand description
累积属性
Variants
Unknown = 0
未知
ChangeRate = 1
涨跌幅(精确到小数点后 3 位,超出部分会被舍弃)例如填写[-10.2,20.4]值区间(该字段为百分比字段,默认不展示 %,如 20 实际对应 20%)
Amplitude = 2
振幅(精确到小数点后 3 位,超出部分会被舍弃)例如填写[0.5,20.6]值区间(该字段为百分比字段,默认不展示 %,如 20 实际对应 20%)
Volume = 3
日均成交量(精确到小数点后 0 位,超出部分会被舍弃)例如填写[2000,70000]值区间(精确到小数点后 0 位,超出部分会被舍弃)
Turnover = 4
日均成交额(精确到小数点后 3 位,超出部分会被舍弃)例如填写[1400,890000]值区间
TurnoverRate = 5
换手率(精确到小数点后 3 位,超出部分会被舍弃)例如填写[2,30]值区间(该字段为百分比字段,默认不展示 %,如 20 实际对应 20%)
Implementations
Sourceimpl AccumulateField
impl AccumulateField
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.