FinancialField

Enum FinancialField 

#[repr(i32)]
pub enum FinancialField {
Show 47 variants Unknown = 0, NetProfit = 1, NetProfitGrowth = 2, SumOfBusiness = 3, SumOfBusinessGrowth = 4, NetProfitRate = 5, GrossProfitRate = 6, DebtAssetsRate = 7, ReturnOnEquityRate = 8, Roic = 9, Roattm = 10, Ebitttm = 11, Ebitda = 12, OperatingMarginTtm = 13, EbitMargin = 14, EbitdaMargin = 15, FinancialCostRate = 16, OperatingProfitTtm = 17, ShareholderNetProfitTtm = 18, NetProfitCashCoverTtm = 19, CurrentRatio = 20, QuickRatio = 21, CurrentAssetRatio = 22, CurrentDebtRatio = 23, EquityMultiplier = 24, PropertyRatio = 25, CashAndCashEquivalents = 26, TotalAssetTurnover = 27, FixedAssetTurnover = 28, InventoryTurnover = 29, OperatingCashFlowTtm = 30, AccountsReceivable = 31, EbitGrowthRate = 32, OperatingProfitGrowthRate = 33, TotalAssetsGrowthRate = 34, ProfitToShareholdersGrowthRate = 35, ProfitBeforeTaxGrowthRate = 36, EpsGrowthRate = 37, RoeGrowthRate = 38, RoicGrowthRate = 39, NocfGrowthRate = 40, NocfPerShareGrowthRate = 41, OperatingRevenueCashCover = 42, OperatingProfitToTotalProfit = 43, BasicEps = 44, DilutedEps = 45, NocfPerShare = 46,
}
财务属性

Variants



Unknown = 0

基础财务属性

未知



NetProfit = 1

净利润(精确到小数点后 3 位,超出部分会被舍弃)例如填写[100000000,2500000000]值区间



NetProfitGrowth = 2

净利润增长率(精确到小数点后 3 位,超出部分会被舍弃)例如填写[-10,300]值区间(该字段为百分比字段,默认不展示 %,如 20 实际对应 20%)



SumOfBusiness = 3

营业收入(精确到小数点后 3 位,超出部分会被舍弃)例如填写[100000000,6400000000]值区间



SumOfBusinessGrowth = 4

营收同比增长率(精确到小数点后 3 位,超出部分会被舍弃)例如填写[-5,200]值区间(该字段为百分比字段,默认不展示 %,如 20 实际对应 20%)



NetProfitRate = 5

净利率(精确到小数点后 3 位,超出部分会被舍弃)例如填写[10,113]值区间(该字段为百分比字段,默认不展示 %,如 20 实际对应 20%)



GrossProfitRate = 6

毛利率(精确到小数点后 3 位,超出部分会被舍弃)例如填写[4,65]值区间(该字段为百分比字段,默认不展示 %,如 20 实际对应 20%)



DebtAssetsRate = 7

资产负债率(精确到小数点后 3 位,超出部分会被舍弃)例如填写[5,470]值区间(该字段为百分比字段,默认不展示 %,如 20 实际对应 20%)



ReturnOnEquityRate = 8

净资产收益率(精确到小数点后 3 位,超出部分会被舍弃)例如填写[20,230]值区间(该字段为百分比字段,默认不展示 %,如 20 实际对应 20%)



Roic = 9

盈利能力属性

投入资本回报率(精确到小数点后 3 位,超出部分会被舍弃)例如填写 [1.0,10.0] 值区间(该字段为百分比字段,默认不展示 %,如 20 实际对应 20%)



Roattm = 10

资产回报率 TTM(精确到小数点后 3 位,超出部分会被舍弃)例如填写 [1.0,10.0] 值区间(该字段为百分比字段,默认不展示 %,如 20 实际对应 20%。仅适用于年报。)



Ebitttm = 11

息税前利润 TTM(精确到小数点后 3 位,超出部分会被舍弃)例如填写 [1000000000,1000000000] 值区间(单位:元。仅适用于年报。)



Ebitda = 12

税息折旧及摊销前利润(精确到小数点后 3 位,超出部分会被舍弃)例如填写 [1000000000,1000000000] 值区间(单位:元)



OperatingMarginTtm = 13

营业利润率 TTM(精确到小数点后 3 位,超出部分会被舍弃)例如填写 [1.0,10.0] 值区间(该字段为百分比字段,默认不展示 %,如 20 实际对应 20%。仅适用于年报。)



EbitMargin = 14

EBIT利润率(精确到小数点后 3 位,超出部分会被舍弃)例如填写 [1.0,10.0] 值区间(该字段为百分比字段,默认不展示 %,如 20 实际对应 20%)



EbitdaMargin = 15

EBITDA利润率(精确到小数点后 3 位,超出部分会被舍弃)例如填写 [1.0,10.0] 值区间(该字段为百分比字段,默认不展示 %,如 20 实际对应 20%)



FinancialCostRate = 16

财务成本率(精确到小数点后 3 位,超出部分会被舍弃)例如填写 [1.0,10.0] 值区间(该字段为百分比字段,默认不展示 %,如 20 实际对应 20%)



OperatingProfitTtm = 17

营业利润 TTM(精确到小数点后 3 位,超出部分会被舍弃)例如填写 [1000000000,1000000000] 值区间 (单位:元。仅适用于年报。)



ShareholderNetProfitTtm = 18

归属于母公司的净利润(精确到小数点后 3 位,超出部分会被舍弃)例如填写 [1000000000,1000000000] 值区间 (单位:元。仅适用于年报。)



NetProfitCashCoverTtm = 19

盈利中的现金收入比例(精确到小数点后 3 位,超出部分会被舍弃)例如填写 [1.0,60.0] 值区间(该字段为百分比字段,默认不展示 %,如 20 实际对应 20%。仅适用于年报。)



CurrentRatio = 20

偿债能力属性

流动比率(精确到小数点后 3 位,超出部分会被舍弃)例如填写 [100,250] 值区间(该字段为百分比字段,默认不展示 %,如 20 实际对应 20%)



QuickRatio = 21

速动比率(精确到小数点后 3 位,超出部分会被舍弃)例如填写 [100,250] 值区间(该字段为百分比字段,默认不展示 %,如 20 实际对应 20%)



CurrentAssetRatio = 22

清债能力属性

流动资产率(精确到小数点后 3 位,超出部分会被舍弃)例如填写 [10,100] 值区间(该字段为百分比字段,默认不展示 %,如 20 实际对应 20%)



CurrentDebtRatio = 23

流动负债率(精确到小数点后 3 位,超出部分会被舍弃)例如填写 [10,100] 值区间(该字段为百分比字段,默认不展示 %,如 20 实际对应 20%)



EquityMultiplier = 24

权益乘数(精确到小数点后 3 位,超出部分会被舍弃)例如填写 [100,180] 值区间



PropertyRatio = 25

产权比率(精确到小数点后 3 位,超出部分会被舍弃)例如填写 [50,100] 值区间 (该字段为百分比字段,默认不展示 %,如 20 实际对应 20%)



CashAndCashEquivalents = 26

现金和现金等价(精确到小数点后 3 位,超出部分会被舍弃)例如填写 [1000000000,1000000000] 值区间(单位:元)



TotalAssetTurnover = 27

运营能力属性

总资产周转率(精确到小数点后 3 位,超出部分会被舍弃)例如填写 [50,100] 值区间 (该字段为百分比字段,默认不展示 %,如 20 实际对应 20%)



FixedAssetTurnover = 28

固定资产周转率(精确到小数点后 3 位,超出部分会被舍弃)例如填写 [50,100] 值区间 (该字段为百分比字段,默认不展示 %,如 20 实际对应 20%)



InventoryTurnover = 29

存货周转率(精确到小数点后 3 位,超出部分会被舍弃)例如填写 [50,100] 值区间 (该字段为百分比字段,默认不展示 %,如 20 实际对应 20%)



OperatingCashFlowTtm = 30

经营活动现金流 TTM(精确到小数点后 3 位,超出部分会被舍弃)例如填写 [1000000000,1000000000] 值区间(单位:元。仅适用于年报。)



AccountsReceivable = 31

应收账款净额(精确到小数点后 3 位,超出部分会被舍弃)例如填写 [1000000000,1000000000] 值区间 例如填写 [1000000000,1000000000] 值区间 (单位:元)



EbitGrowthRate = 32

成长能力属性

EBIT同比增长率(精确到小数点后 3 位,超出部分会被舍弃)例如填写 [1.0,10.0] 值区间 (该字段为百分比字段,默认不展示 %,如 20 实际对应 20%)



OperatingProfitGrowthRate = 33

营业利润同比增长率(精确到小数点后 3 位,超出部分会被舍弃)例如填写 [1.0,10.0] 值区间 (该字段为百分比字段,默认不展示 %,如 20 实际对应 20%)



TotalAssetsGrowthRate = 34

总资产同比增长率(精确到小数点后 3 位,超出部分会被舍弃)例如填写 [1.0,10.0] 值区间 (该字段为百分比字段,默认不展示 %,如 20 实际对应 20%)



ProfitToShareholdersGrowthRate = 35

归母净利润同比增长率(精确到小数点后 3 位,超出部分会被舍弃)例如填写 [1.0,10.0] 值区间 (该字段为百分比字段,默认不展示 %,如 20 实际对应 20%)



ProfitBeforeTaxGrowthRate = 36

总利润同比增长率(精确到小数点后 3 位,超出部分会被舍弃)例如填写 [1.0,10.0] 值区间 (该字段为百分比字段,默认不展示 %,如 20 实际对应 20%)



EpsGrowthRate = 37

EPS同比增长率(精确到小数点后 3 位,超出部分会被舍弃)例如填写 [1.0,10.0] 值区间 (该字段为百分比字段,默认不展示 %,如 20 实际对应 20%)



RoeGrowthRate = 38

ROE同比增长率(精确到小数点后 3 位,超出部分会被舍弃)例如填写 [1.0,10.0] 值区间 (该字段为百分比字段,默认不展示 %,如 20 实际对应 20%)



RoicGrowthRate = 39

ROIC同比增长率(精确到小数点后 3 位,超出部分会被舍弃)例如填写 [1.0,10.0] 值区间 (该字段为百分比字段,默认不展示 %,如 20 实际对应 20%)



NocfGrowthRate = 40

经营现金流同比增长率(精确到小数点后 3 位,超出部分会被舍弃)例如填写 [1.0,10.0] 值区间 (该字段为百分比字段,默认不展示 %,如 20 实际对应 20%)



NocfPerShareGrowthRate = 41

每股经营现金流同比增长率(精确到小数点后 3 位,超出部分会被舍弃)例如填写 [1.0,10.0] 值区间 (该字段为百分比字段,默认不展示 %,如 20 实际对应 20%)



OperatingRevenueCashCover = 42

现金流属性

经营现金收入比(精确到小数点后 3 位,超出部分会被舍弃)例如填写 [10,100] 值区间(该字段为百分比字段,默认不展示 %,如 20 实际对应 20%)



OperatingProfitToTotalProfit = 43

营业利润占比(精确到小数点后 3 位,超出部分会被舍弃)例如填写 [10,100] 值区间 (该字段为百分比字段,默认不展示 %,如 20 实际对应 20%)



BasicEps = 44

市场表现属性

基本每股收益(精确到小数点后 3 位,超出部分会被舍弃)例如填写 [0.1,10] 值区间 (单位:元)



DilutedEps = 45

稀释每股收益(精确到小数点后 3 位,超出部分会被舍弃)例如填写 [0.1,10] 值区间 (单位:元)



NocfPerShare = 46

每股经营现金净流量(精确到小数点后 3 位,超出部分会被舍弃)例如填写 [0.1,10] 值区间 (单位:元)

Implementations

Source

impl FinancialField

pub fn is_valid(value: i32) -> bool

Returns true if value is a variant of FinancialField.

pub fn from_i32(value: i32) -> Option<FinancialField>

👎Deprecated: Use the TryFrom<i32> implementation instead

Converts an i32 to a FinancialField, or None if value is not a valid variant.

Source

impl FinancialField

pub fn as_str_name(&self) -> &'static str

String value of the enum field names used in the ProtoBuf definition.

The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.

pub fn from_str_name(value: &str) -> Option<Self>

Creates an enum from field names used in the ProtoBuf definition.