#[repr(i32)]pub enum FinancialQuarter {
Unknown = 0,
Annual = 1,
FirstQuarter = 2,
Interim = 3,
ThirdQuarter = 4,
MostRecentQuarter = 5,
}Expand description
财务时间周期
Variants
Unknown = 0
未知
Annual = 1
年报
FirstQuarter = 2
一季报
Interim = 3
中报
ThirdQuarter = 4
三季报
MostRecentQuarter = 5
最近季报
Implementations
Sourceimpl FinancialQuarter
impl FinancialQuarter
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.