#[repr(i32)]pub enum RelativePosition {
Unknown = 0,
More = 1,
Less = 2,
CrossUp = 3,
CrossDown = 4,
}Expand description
相对位置比较
Variants
Unknown = 0
未知
More = 1
大于,first位于second的上方
Less = 2
小于,first位于second的下方
CrossUp = 3
升穿,first从下往上穿second
CrossDown = 4
跌穿,first从上往下穿second
Implementations
Sourceimpl RelativePosition
impl RelativePosition
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.