pub struct RetrieveQuery {
pub basic_property: Option<PropertyBasic>,
pub simple_property: Option<PropertySimple>,
pub cumulative_property: Option<PropertyCumulative>,
pub financial_property: Option<PropertyFinancial>,
pub indicator_property: Option<PropertyIndicator>,
pub featured_property: Option<PropertyFeatured>,
pub broker_property: Option<PropertyBroker>,
pub option_property: Option<PropertyOption>,
pub kline_shape_property: Option<PropertyKlineShape>,
}Expand description
取回属性设置 (各字段互斥, 仅设置其中一个)
Fields
basic_property: Option<PropertyBasic>simple_property: Option<PropertySimple>cumulative_property: Option<PropertyCumulative>financial_property: Option<PropertyFinancial>indicator_property: Option<PropertyIndicator>featured_property: Option<PropertyFeatured>broker_property: Option<PropertyBroker>option_property: Option<PropertyOption>kline_shape_property: Option<PropertyKlineShape>Trait Implementations
Sourceimpl Clone for RetrieveQuery
impl Clone for RetrieveQuery
Sourcefn clone(&self) -> RetrieveQuery
fn clone(&self) -> RetrieveQuery
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RetrieveQuery
impl Debug for RetrieveQuery
Sourceimpl Default for RetrieveQuery
impl Default for RetrieveQuery
Sourceimpl<'de> Deserialize<'de> for RetrieveQuerywhere
RetrieveQuery: Default,
impl<'de> Deserialize<'de> for RetrieveQuerywhere
RetrieveQuery: Default,
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for RetrieveQuery
impl Hash for RetrieveQuery
Sourceimpl Message for RetrieveQuery
impl Message for RetrieveQuery
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for RetrieveQuery
impl PartialEq for RetrieveQuery
Sourceimpl Serialize for RetrieveQuery
impl Serialize for RetrieveQuery
impl Eq for RetrieveQuery
impl StructuralPartialEq for RetrieveQuery