pub struct RspItemResult {
pub basic_property_result: Option<ResultPropertyBasic>,
pub simple_property_result: Option<ResultPropertySimple>,
pub cumulative_property_result: Option<ResultPropertyCumulative>,
pub financial_property_result: Option<ResultPropertyFinancial>,
pub indicator_property_result: Option<ResultPropertyIndicator>,
pub featured_property_result: Option<ResultPropertyFeatured>,
pub broker_property_result: Option<ResultPropertyBroker>,
pub option_property_result: Option<ResultPropertyOption>,
pub kline_shape_property_result: Option<ResultPropertyKlineShape>,
}Expand description
单条结果 (各字段互斥)
Fields
basic_property_result: Option<ResultPropertyBasic>simple_property_result: Option<ResultPropertySimple>cumulative_property_result: Option<ResultPropertyCumulative>financial_property_result: Option<ResultPropertyFinancial>indicator_property_result: Option<ResultPropertyIndicator>featured_property_result: Option<ResultPropertyFeatured>broker_property_result: Option<ResultPropertyBroker>option_property_result: Option<ResultPropertyOption>kline_shape_property_result: Option<ResultPropertyKlineShape>Trait Implementations
Sourceimpl Clone for RspItemResult
impl Clone for RspItemResult
Sourcefn clone(&self) -> RspItemResult
fn clone(&self) -> RspItemResult
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RspItemResult
impl Debug for RspItemResult
Sourceimpl Default for RspItemResult
impl Default for RspItemResult
Sourceimpl<'de> Deserialize<'de> for RspItemResultwhere
RspItemResult: Default,
impl<'de> Deserialize<'de> for RspItemResultwhere
RspItemResult: Default,
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Message for RspItemResult
impl Message for RspItemResult
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for RspItemResult
impl PartialEq for RspItemResult
Sourceimpl Serialize for RspItemResult
impl Serialize for RspItemResult
impl StructuralPartialEq for RspItemResult