pub struct ScreenQuery {
pub simple_field_query: Option<QuerySimpleField>,
pub plate_query: Option<QueryPlate>,
pub simple_property_query: Option<QueryPropertySimple>,
pub cumulative_property_query: Option<QueryPropertyCumulative>,
pub financial_property_query: Option<QueryPropertyFinancial>,
pub indicator_positional_query: Option<QueryIndicatorPositional>,
pub indicator_pattern_query: Option<QueryIndicatorPattern>,
pub featured_property_query: Option<QueryPropertyFeatured>,
pub broker_holdings_query: Option<QueryPropertyBroker>,
pub kline_shape_query: Option<QueryKlineShape>,
pub option_query: Option<QueryPropertyOption>,
}Expand description
筛选过滤器 (各字段互斥, 仅设置其中一个)
Fields
simple_field_query: Option<QuerySimpleField>plate_query: Option<QueryPlate>simple_property_query: Option<QueryPropertySimple>cumulative_property_query: Option<QueryPropertyCumulative>financial_property_query: Option<QueryPropertyFinancial>indicator_positional_query: Option<QueryIndicatorPositional>indicator_pattern_query: Option<QueryIndicatorPattern>featured_property_query: Option<QueryPropertyFeatured>broker_holdings_query: Option<QueryPropertyBroker>kline_shape_query: Option<QueryKlineShape>option_query: Option<QueryPropertyOption>Trait Implementations
Sourceimpl Clone for ScreenQuery
impl Clone for ScreenQuery
Sourcefn clone(&self) -> ScreenQuery
fn clone(&self) -> ScreenQuery
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ScreenQuery
impl Debug for ScreenQuery
Sourceimpl Default for ScreenQuery
impl Default for ScreenQuery
Sourceimpl<'de> Deserialize<'de> for ScreenQuerywhere
ScreenQuery: Default,
impl<'de> Deserialize<'de> for ScreenQuerywhere
ScreenQuery: Default,
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Message for ScreenQuery
impl Message for ScreenQuery
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for ScreenQuery
impl PartialEq for ScreenQuery
Sourceimpl Serialize for ScreenQuery
impl Serialize for ScreenQuery
impl StructuralPartialEq for ScreenQuery