WarrantItem

Struct WarrantItem 

pub struct WarrantItem {
Show 43 fields pub stock_id: Option<u64>, pub stock_owner: Option<u64>, pub issuer_id: Option<u32>, pub warrant_type: Option<i32>, pub strike_price: Option<f64>, pub maturity_date: Option<u64>, pub last_trade_date: Option<u64>, pub conversion_ratio: Option<f64>, pub lastclose_price: Option<f64>, pub recovery_price: Option<f64>, pub stock_owner_price: Option<f64>, pub current_price: Option<f64>, pub volume: Option<u64>, pub turnover: Option<f64>, pub sell_vol: Option<u64>, pub buy_vol: Option<u64>, pub sell_price: Option<f64>, pub buy_price: Option<f64>, pub street_rate: Option<f64>, pub high_price: Option<f64>, pub low_price: Option<f64>, pub implied_volatility: Option<f64>, pub delta: Option<f64>, pub status: Option<i32>, pub street_rate_new: Option<f64>, pub score: Option<f64>, pub premium: Option<f64>, pub leverage: Option<f64>, pub effective_leverage: Option<f64>, pub break_even_point: Option<f64>, pub ipop: Option<f64>, pub amplitude: Option<f64>, pub fx_score: Option<f64>, pub ipo_time: Option<u64>, pub street_vol: Option<u64>, pub lot_size: Option<u32>, pub issue_size: Option<u64>, pub ipo_price: Option<f64>, pub upper_strike_price: Option<f64>, pub lower_strike_price: Option<f64>, pub iw_price_status: Option<u32>, pub sensitivity: Option<f64>, pub price_recovery_ratio: Option<f64>,
}

Fields

stock_id: Option<u64>

股票ID (u64 StockHash)

stock_owner: Option<u64>

正股ID

issuer_id: Option<u32>

发行人ID

warrant_type: Option<i32>

类型: 1=认购, 2=认沽, 3=牛证, 4=熊证, 5=界内证

strike_price: Option<f64>

行使价

maturity_date: Option<u64>

到期日 (时间戳秒)

last_trade_date: Option<u64>

最后交易日 (时间戳秒)

conversion_ratio: Option<f64>

换股比率

lastclose_price: Option<f64>

昨收价

recovery_price: Option<f64>

收回价, 仅牛熊证

stock_owner_price: Option<f64>

field 11-19 reserved

正股价

current_price: Option<f64>

最新价

volume: Option<u64>

成交量

turnover: Option<f64>

成交额

sell_vol: Option<u64>

卖量

buy_vol: Option<u64>

买量

sell_price: Option<f64>

卖出价

buy_price: Option<f64>

买入价

street_rate: Option<f64>

街货占比

high_price: Option<f64>

最高价

low_price: Option<f64>

最低价

implied_volatility: Option<f64>

引伸波幅

delta: Option<f64>

对冲值

status: Option<i32>

状态: 0=正常, 1=停牌, 2=终止交易, 3=待上市

street_rate_new: Option<f64>

街货占比(新)

score: Option<f64>

综合评分

premium: Option<f64>

溢价 (%)

leverage: Option<f64>

杠杆比率

effective_leverage: Option<f64>

有效杠杆

break_even_point: Option<f64>

打和点

ipop: Option<f64>

价内/价外 (%)

amplitude: Option<f64>

振幅 (%)

fx_score: Option<f64>

发行评分

ipo_time: Option<u64>

上市日期 (时间戳秒)

street_vol: Option<u64>

街货量

lot_size: Option<u32>

每手数量

issue_size: Option<u64>

发行量

ipo_price: Option<f64>

发行价

upper_strike_price: Option<f64>

上限价, 仅界内证

lower_strike_price: Option<f64>

下限价, 仅界内证

iw_price_status: Option<u32>

界内证价格状态: 0=界内, 1=界外

sensitivity: Option<f64>

敏感度

price_recovery_ratio: Option<f64>

正股距收回价 (%)

Implementations

Source

impl WarrantItem

pub fn stock_id(&self) -> u64

Returns the value of stock_id, or the default value if stock_id is unset.

pub fn stock_owner(&self) -> u64

Returns the value of stock_owner, or the default value if stock_owner is unset.

pub fn issuer_id(&self) -> u32

Returns the value of issuer_id, or the default value if issuer_id is unset.

pub fn warrant_type(&self) -> i32

Returns the value of warrant_type, or the default value if warrant_type is unset.

pub fn strike_price(&self) -> f64

Returns the value of strike_price, or the default value if strike_price is unset.

pub fn maturity_date(&self) -> u64

Returns the value of maturity_date, or the default value if maturity_date is unset.

pub fn last_trade_date(&self) -> u64

Returns the value of last_trade_date, or the default value if last_trade_date is unset.

pub fn conversion_ratio(&self) -> f64

Returns the value of conversion_ratio, or the default value if conversion_ratio is unset.

pub fn lastclose_price(&self) -> f64

Returns the value of lastclose_price, or the default value if lastclose_price is unset.

pub fn recovery_price(&self) -> f64

Returns the value of recovery_price, or the default value if recovery_price is unset.

pub fn stock_owner_price(&self) -> f64

Returns the value of stock_owner_price, or the default value if stock_owner_price is unset.

pub fn current_price(&self) -> f64

Returns the value of current_price, or the default value if current_price is unset.

pub fn volume(&self) -> u64

Returns the value of volume, or the default value if volume is unset.

pub fn turnover(&self) -> f64

Returns the value of turnover, or the default value if turnover is unset.

pub fn sell_vol(&self) -> u64

Returns the value of sell_vol, or the default value if sell_vol is unset.

pub fn buy_vol(&self) -> u64

Returns the value of buy_vol, or the default value if buy_vol is unset.

pub fn sell_price(&self) -> f64

Returns the value of sell_price, or the default value if sell_price is unset.

pub fn buy_price(&self) -> f64

Returns the value of buy_price, or the default value if buy_price is unset.

pub fn street_rate(&self) -> f64

Returns the value of street_rate, or the default value if street_rate is unset.

pub fn high_price(&self) -> f64

Returns the value of high_price, or the default value if high_price is unset.

pub fn low_price(&self) -> f64

Returns the value of low_price, or the default value if low_price is unset.

pub fn implied_volatility(&self) -> f64

Returns the value of implied_volatility, or the default value if implied_volatility is unset.

pub fn delta(&self) -> f64

Returns the value of delta, or the default value if delta is unset.

pub fn status(&self) -> i32

Returns the value of status, or the default value if status is unset.

pub fn street_rate_new(&self) -> f64

Returns the value of street_rate_new, or the default value if street_rate_new is unset.

pub fn score(&self) -> f64

Returns the value of score, or the default value if score is unset.

pub fn premium(&self) -> f64

Returns the value of premium, or the default value if premium is unset.

pub fn leverage(&self) -> f64

Returns the value of leverage, or the default value if leverage is unset.

pub fn effective_leverage(&self) -> f64

Returns the value of effective_leverage, or the default value if effective_leverage is unset.

pub fn break_even_point(&self) -> f64

Returns the value of break_even_point, or the default value if break_even_point is unset.

pub fn ipop(&self) -> f64

Returns the value of ipop, or the default value if ipop is unset.

pub fn amplitude(&self) -> f64

Returns the value of amplitude, or the default value if amplitude is unset.

pub fn fx_score(&self) -> f64

Returns the value of fx_score, or the default value if fx_score is unset.

pub fn ipo_time(&self) -> u64

Returns the value of ipo_time, or the default value if ipo_time is unset.

pub fn street_vol(&self) -> u64

Returns the value of street_vol, or the default value if street_vol is unset.

pub fn lot_size(&self) -> u32

Returns the value of lot_size, or the default value if lot_size is unset.

pub fn issue_size(&self) -> u64

Returns the value of issue_size, or the default value if issue_size is unset.

pub fn ipo_price(&self) -> f64

Returns the value of ipo_price, or the default value if ipo_price is unset.

pub fn upper_strike_price(&self) -> f64

Returns the value of upper_strike_price, or the default value if upper_strike_price is unset.

pub fn lower_strike_price(&self) -> f64

Returns the value of lower_strike_price, or the default value if lower_strike_price is unset.

pub fn iw_price_status(&self) -> u32

Returns the value of iw_price_status, or the default value if iw_price_status is unset.

pub fn sensitivity(&self) -> f64

Returns the value of sensitivity, or the default value if sensitivity is unset.

pub fn price_recovery_ratio(&self) -> f64

Returns the value of price_recovery_ratio, or the default value if price_recovery_ratio is unset.