#[repr(i32)]pub enum Currency {
Unknown = 0,
Hkd = 1,
Usd = 2,
Cnh = 3,
Jpy = 4,
Sgd = 5,
Aud = 6,
Cad = 7,
Myr = 8,
}Expand description
货币种类
Variants
Unknown = 0
未知货币
Hkd = 1
港币
Usd = 2
美元
Cnh = 3
离岸人民币
Jpy = 4
日元
Sgd = 5
新币
Aud = 6
澳元
Cad = 7
加拿大元
Myr = 8
马来西亚林吉特
Implementations
Sourceimpl Currency
impl Currency
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.