#[repr(i32)]pub enum ExposureLevel {
Unknown = 0,
Normal = 1,
NearLimit = 2,
Restricted = 3,
Safe = 4,
Moderate = 5,
Warning = 6,
MarginCall = 7,
}Variants
Unknown = 0
未知
Normal = 1
正常
NearLimit = 2
即将用尽
Restricted = 3
受限
Safe = 4
安全
Moderate = 5
适中
Warning = 6
预警
MarginCall = 7
危险
Implementations
Sourceimpl ExposureLevel
impl ExposureLevel
Sourceimpl ExposureLevel
impl ExposureLevel
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.