#[repr(i32)]pub enum ModifyOrderOp {
Unknown = 0,
Normal = 1,
Cancel = 2,
Disable = 3,
Enable = 4,
Delete = 5,
}Expand description
修改订单的操作类型
Variants
Unknown = 0
港股支持全部操作,美股目前仅支持ModifyOrderOp_Normal和ModifyOrderOp_Cancel
未知操作
Normal = 1
修改订单的价格、数量等,即以前的改单
Cancel = 2
撤单
Disable = 3
失效
Enable = 4
生效
Delete = 5
删除
Implementations
Sourceimpl ModifyOrderOp
impl ModifyOrderOp
Sourceimpl ModifyOrderOp
impl ModifyOrderOp
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.