#[repr(i32)]pub enum OrderGroupType {
Unknown = 0,
Normal = 1,
Bracket = 2,
Group = 3,
Basket = 4,
Oco = 5,
}Expand description
v1.8 daemon additive order-relation type. Values intentionally differ from backend odr_sys_cmn.GroupType so Unknown remains distinct from backend NORMAL=0. relationExt.orderGroupTypeRaw preserves the server numeric value.
Variants
Implementations
Sourceimpl OrderGroupType
impl OrderGroupType
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.