#[repr(i32)]pub enum PositionSide {
Long = 0,
Unknown = -1,
Short = 1,
}Expand description
持仓方向类型
Variants
Implementations
Sourceimpl PositionSide
impl PositionSide
Sourceimpl PositionSide
impl PositionSide
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.