#[repr(i32)]pub enum SimAccType {
Unknown = 0,
Stock = 1,
Option = 2,
Futures = 3,
StockAndOption = 4,
}Expand description
模拟交易账户类型
Variants
Unknown = 0
未知
Stock = 1
股票模拟账户(仅用于交易证券类产品,不支持交易期权)
Option = 2
期权模拟账户(仅用于交易期权,不支持交易股票证券类产品)
Futures = 3
期货模拟账户
StockAndOption = 4
股票和期权模拟账户(支持交易股票和期权)
Implementations
Sourceimpl SimAccType
impl SimAccType
Sourceimpl SimAccType
impl SimAccType
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.