TrdAccType

Enum TrdAccType 

#[repr(i32)]
pub enum TrdAccType { Unknown = 0, Cash = 1, Margin = 2, Tfsa = 3, Rrsp = 4, Srrsp = 5, Derivatives = 6, }
交易账户类型

Variants



Unknown = 0

未知类型



Cash = 1

现金账户



Margin = 2

保证金账户



Tfsa = 3

加拿大免税账户



Rrsp = 4

加拿大注册退休账户



Srrsp = 5

加拿大配偶退休账户



Derivatives = 6

日本衍生品账户

Implementations

Source

impl TrdAccType

pub fn is_valid(value: i32) -> bool

Returns true if value is a variant of TrdAccType.

pub fn from_i32(value: i32) -> Option<TrdAccType>

👎Deprecated: Use the TryFrom<i32> implementation instead

Converts an i32 to a TrdAccType, or None if value is not a valid variant.

Source

impl TrdAccType

pub fn as_str_name(&self) -> &'static str

String value of the enum field names used in the ProtoBuf definition.

The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.

pub fn from_str_name(value: &str) -> Option<Self>

Creates an enum from field names used in the ProtoBuf definition.