#[repr(i32)]pub enum TrdSecMarket {
Unknown = 0,
Hk = 1,
Us = 2,
CnSh = 31,
CnSz = 32,
Sg = 41,
Jp = 51,
Au = 61,
My = 71,
Ca = 81,
Fx = 91,
}Expand description
可交易证券所属市场,目前主要是区分A股的沪市和深市,香港和美国暂不需要细分
Variants
Unknown = 0
未知市场
Hk = 1
香港市场(股票、窝轮、牛熊、期权、期货等)
Us = 2
美国市场(股票、期权、期货等)
CnSh = 31
沪股市场(股票)
CnSz = 32
深股市场(股票)
Sg = 41
新加坡市场(期货)
Jp = 51
日本市场(期货)
Au = 61
澳大利亚
My = 71
马来西亚
Ca = 81
加拿大
Fx = 91
外汇
Implementations
Sourceimpl TrdSecMarket
impl TrdSecMarket
Sourceimpl TrdSecMarket
impl TrdSecMarket
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.