#[repr(i32)]pub enum TrdSide {
Unknown = 0,
Buy = 1,
Sell = 2,
SellShort = 3,
BuyBack = 4,
}Expand description
交易方向
Variants
Unknown = 0
客户端下单只传Buy或Sell即可,SellShort是美股订单时服务器返回有此方向,BuyBack目前不存在,但也不排除服务器会传
未知方向
Buy = 1
买入
Sell = 2
卖出
SellShort = 3
卖空
BuyBack = 4
买回
Implementations
Sourceimpl TrdSide
impl TrdSide
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.