TrdSubAccType

Enum TrdSubAccType 

#[repr(i32)]
pub enum TrdSubAccType {
Show 17 variants None = 0, JpGeneral = 1, JpTokutei = 2, JpNisaGeneral = 3, JpNisaTsumitate = 4, JpGeneralShort = 5, JpTokuteiShort = 6, JpHonpoGeneral = 7, JpGaikokuGeneral = 8, JpHonpoTokutei = 9, JpGaikokuTokutei = 10, JpDerivativeLong = 11, JpDerivativeShort = 12, JpHonpoDerivativeGeneral = 13, JpGaikokuDerivativeGeneral = 14, JpHonpoDerivativeTokutei = 15, JpGaikokuDerivativeTokutei = 16,
}
JP子账户类型

Variants



None = 0

未知



JpGeneral = 1

日本-一般口座-long



JpTokutei = 2

日本-特定口座-long



JpNisaGeneral = 3

日本-一般NISA



JpNisaTsumitate = 4

日本-累计NISA



JpGeneralShort = 5

JP支持信用账户新增如下六种子账户类型

日本-一般口座-Short



JpTokuteiShort = 6

日本-特定口座-Short



JpHonpoGeneral = 7

日本-本国信用交易抵押品-一般



JpGaikokuGeneral = 8

日本-外国信用交易抵押品-一般



JpHonpoTokutei = 9

日本-本国信用交易抵押品-特定



JpGaikokuTokutei = 10

日本-外国信用交易抵押品-特定



JpDerivativeLong = 11

JP支持衍生品账户新增如下六种子账户类型

日本-衍生品-Long



JpDerivativeShort = 12

日本-衍生品-Short



JpHonpoDerivativeGeneral = 13

日本-本国衍生品证据金-一般



JpGaikokuDerivativeGeneral = 14

日本-外国衍生品证据金-一般



JpHonpoDerivativeTokutei = 15

日本-本国衍生品证据金-特定



JpGaikokuDerivativeTokutei = 16

日本-外国衍生品证据金-特定

Implementations

Source

impl TrdSubAccType

pub fn is_valid(value: i32) -> bool

Returns true if value is a variant of TrdSubAccType.

pub fn from_i32(value: i32) -> Option<TrdSubAccType>

👎Deprecated: Use the TryFrom<i32> implementation instead

Converts an i32 to a TrdSubAccType, or None if value is not a valid variant.

Source

impl TrdSubAccType

pub fn as_str_name(&self) -> &'static str

String value of the enum field names used in the ProtoBuf definition.

The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.

pub fn from_str_name(value: &str) -> Option<Self>

Creates an enum from field names used in the ProtoBuf definition.