Order

Struct Order 

pub struct Order {
Show 28 fields pub trd_side: i32, pub order_type: i32, pub order_status: i32, pub order_id: u64, pub order_id_ex: String, pub code: String, pub name: String, pub qty: f64, pub price: Option<f64>, pub create_time: String, pub update_time: String, pub fill_qty: Option<f64>, pub fill_avg_price: Option<f64>, pub last_err_msg: Option<String>, pub sec_market: Option<i32>, pub create_timestamp: Option<f64>, pub update_timestamp: Option<f64>, pub remark: Option<String>, pub time_in_force: Option<i32>, pub fill_outside_rth: Option<bool>, pub aux_price: Option<f64>, pub trail_type: Option<i32>, pub trail_value: Option<f64>, pub trail_spread: Option<f64>, pub currency: Option<i32>, pub trd_market: Option<i32>, pub session: Option<i32>, pub jp_acc_type: Option<i32>,
}
订单结构

Fields

trd_side: i32

交易方向, 参见TrdSide的枚举定义

order_type: i32

订单类型, 参见OrderType的枚举定义

order_status: i32

订单状态, 参见OrderStatus的枚举定义

order_id: u64

订单号

order_id_ex: String

扩展订单号(仅查问题时备用)

code: String

代码

name: String

名称

qty: f64

订单数量,2位精度,期权单位是“张“

price: Option<f64>

订单价格,3位精度

create_time: String

创建时间,严格按YYYY-MM-DD HH:MM:SS或YYYY-MM-DD HH:MM:SS.MS格式传

update_time: String

最后更新时间,严格按YYYY-MM-DD HH:MM:SS或YYYY-MM-DD HH:MM:SS.MS格式传

fill_qty: Option<f64>

成交数量,2位精度,期权单位是“张“

fill_avg_price: Option<f64>

成交均价,无精度限制

last_err_msg: Option<String>

最后的错误描述,如果有错误,会有此描述最后一次错误的原因,无错误为空

sec_market: Option<i32>

证券所属市场,参见TrdSecMarket的枚举定义

create_timestamp: Option<f64>

创建时间戳

update_timestamp: Option<f64>

最后更新时间戳

remark: Option<String>

用户备注字符串,最大长度64字节

time_in_force: Option<i32>

订单期限,参考 TimeInForce 类的定义

fill_outside_rth: Option<bool>

是否允许美股订单盘前盘后成交

aux_price: Option<f64>

触发价格

trail_type: Option<i32>

跟踪类型, 参见Trd_Common.TrailType的枚举定义

trail_value: Option<f64>

跟踪金额/百分比

trail_spread: Option<f64>

指定价差

currency: Option<i32>

货币类型,取值参考 Currency

trd_market: Option<i32>

交易市场, 参见TrdMarket的枚举定义

session: Option<i32>

美股订单时段, 参见Common.Session的枚举定义

jp_acc_type: Option<i32>

JP子账户类型,取值见 TrdSubAccType

Implementations

Source

impl Order

pub fn price(&self) -> f64

Returns the value of price, or the default value if price is unset.

pub fn fill_qty(&self) -> f64

Returns the value of fill_qty, or the default value if fill_qty is unset.

pub fn fill_avg_price(&self) -> f64

Returns the value of fill_avg_price, or the default value if fill_avg_price is unset.

pub fn last_err_msg(&self) -> &str

Returns the value of last_err_msg, or the default value if last_err_msg is unset.

pub fn sec_market(&self) -> i32

Returns the value of sec_market, or the default value if sec_market is unset.

pub fn create_timestamp(&self) -> f64

Returns the value of create_timestamp, or the default value if create_timestamp is unset.

pub fn update_timestamp(&self) -> f64

Returns the value of update_timestamp, or the default value if update_timestamp is unset.

pub fn remark(&self) -> &str

Returns the value of remark, or the default value if remark is unset.

pub fn time_in_force(&self) -> i32

Returns the value of time_in_force, or the default value if time_in_force is unset.

pub fn fill_outside_rth(&self) -> bool

Returns the value of fill_outside_rth, or the default value if fill_outside_rth is unset.

pub fn aux_price(&self) -> f64

Returns the value of aux_price, or the default value if aux_price is unset.

pub fn trail_type(&self) -> i32

Returns the value of trail_type, or the default value if trail_type is unset.

pub fn trail_value(&self) -> f64

Returns the value of trail_value, or the default value if trail_value is unset.

pub fn trail_spread(&self) -> f64

Returns the value of trail_spread, or the default value if trail_spread is unset.

pub fn currency(&self) -> i32

Returns the value of currency, or the default value if currency is unset.

pub fn trd_market(&self) -> i32

Returns the value of trd_market, or the default value if trd_market is unset.

pub fn session(&self) -> i32

Returns the value of session, or the default value if session is unset.

pub fn jp_acc_type(&self) -> i32

Returns the value of jp_acc_type, or the default value if jp_acc_type is unset.