pub struct OrderRelationExt {
pub extension_version: u32,
pub parent_order_id_ex: Option<String>,
pub order_group_id: Option<String>,
pub order_group_type: Option<i32>,
pub order_group_type_raw: Option<u32>,
}Expand description
v1.8 daemon additive order relation extension carried by Order tag 1000.
Fields
extension_version: u32当前固定为1
parent_order_id_ex: Option<String>backend Order.parent_order_id (field 52)
order_group_id: Option<String>backend Order.order_group_id (field 53)
order_group_type: Option<i32>backend field 54 的 typed projection
order_group_type_raw: Option<u32>原始 numeric,unknown 也必须保留
Implementations
Sourceimpl OrderRelationExt
impl OrderRelationExt
Sourcepub fn parent_order_id_ex(&self) -> &str
pub fn parent_order_id_ex(&self) -> &str
Returns the value of parent_order_id_ex, or the default value if parent_order_id_ex is unset.
Sourcepub fn order_group_id(&self) -> &str
pub fn order_group_id(&self) -> &str
Returns the value of order_group_id, or the default value if order_group_id is unset.
Sourcepub fn order_group_type(&self) -> OrderGroupType
pub fn order_group_type(&self) -> OrderGroupType
Returns the enum value of order_group_type, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_order_group_type(&mut self, value: OrderGroupType)
pub fn set_order_group_type(&mut self, value: OrderGroupType)
Sets order_group_type to the provided enum value.
Sourcepub fn order_group_type_raw(&self) -> u32
pub fn order_group_type_raw(&self) -> u32
Returns the value of order_group_type_raw, or the default value if order_group_type_raw is unset.