#[repr(i32)]pub enum Availability {
Unknown = 0,
Ready = 1,
NotAvailable = 2,
Stale = 3,
}Variants
Unknown = 0
Ready = 1
NotAvailable = 2
account order snapshot has never completed
Stale = 3
reconnect/local incomplete rows invalidate completeness
Implementations
Sourceimpl Availability
impl Availability
Sourceimpl Availability
impl Availability
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.