pub struct S2c {
pub header: TrdHeader,
pub availability: i32,
pub extension_version: u32,
pub order_group_id: Option<String>,
pub order_group_type: Option<i32>,
pub order_group_type_raw: Option<u32>,
pub node_list: Vec<GraphNode>,
pub edge_list: Vec<GraphEdge>,
}Fields
header: TrdHeaderavailability: i32extension_version: u32order_group_id: Option<String>order_group_type: Option<i32>order_group_type_raw: Option<u32>node_list: Vec<GraphNode>edge_list: Vec<GraphEdge>Implementations
Sourceimpl S2c
impl S2c
Sourcepub fn availability(&self) -> Availability
pub fn availability(&self) -> Availability
Returns the enum value of availability, or the default if the field is set to an invalid enum value.
Sourcepub fn set_availability(&mut self, value: Availability)
pub fn set_availability(&mut self, value: Availability)
Sets availability to the provided enum value.
Sourcepub fn order_group_id(&self) -> &str
pub fn order_group_id(&self) -> &str
Returns the value of order_group_id, or the default value if order_group_id is unset.
Sourcepub fn order_group_type(&self) -> OrderGroupType
pub fn order_group_type(&self) -> OrderGroupType
Returns the enum value of order_group_type, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_order_group_type(&mut self, value: OrderGroupType)
pub fn set_order_group_type(&mut self, value: OrderGroupType)
Sets order_group_type to the provided enum value.
Sourcepub fn order_group_type_raw(&self) -> u32
pub fn order_group_type_raw(&self) -> u32
Returns the value of order_group_type_raw, or the default value if order_group_type_raw is unset.