pub struct DerivativeEvent {Show 22 fields
pub event_id: Option<String>,
pub version: Option<u32>,
pub complete_flag: Option<bool>,
pub active_flag: Option<bool>,
pub security_type: Option<u32>,
pub trade_market: Option<u32>,
pub exchange: Option<String>,
pub product_code: Option<String>,
pub product_code_to: Option<String>,
pub underlying_symbol: Option<String>,
pub underlying_cusip: Option<String>,
pub effect_date: Option<u32>,
pub underlying_event_type: Option<String>,
pub underlying_event_type_origin: Option<String>,
pub underlying_event_type_description: Option<String>,
pub strike_price_change: Option<String>,
pub strike_multiplier: Option<String>,
pub multiplier: Option<String>,
pub strike_currency: Option<String>,
pub deliverable_formula: Option<String>,
pub deliverable_info: Vec<DerivativeDeliverable>,
pub update_time: Option<u64>,
}Fields
event_id: Option<String>version: Option<u32>complete_flag: Option<bool>active_flag: Option<bool>security_type: Option<u32>trade_market: Option<u32>exchange: Option<String>product_code: Option<String>product_code_to: Option<String>underlying_symbol: Option<String>underlying_cusip: Option<String>effect_date: Option<u32>underlying_event_type: Option<String>underlying_event_type_origin: Option<String>underlying_event_type_description: Option<String>strike_price_change: Option<String>strike_multiplier: Option<String>multiplier: Option<String>strike_currency: Option<String>deliverable_formula: Option<String>deliverable_info: Vec<DerivativeDeliverable>update_time: Option<u64>Implementations
Sourceimpl DerivativeEvent
impl DerivativeEvent
Sourcepub fn event_id(&self) -> &str
pub fn event_id(&self) -> &str
Returns the value of event_id, or the default value if event_id is unset.
Sourcepub fn version(&self) -> u32
pub fn version(&self) -> u32
Returns the value of version, or the default value if version is unset.
Sourcepub fn complete_flag(&self) -> bool
pub fn complete_flag(&self) -> bool
Returns the value of complete_flag, or the default value if complete_flag is unset.
Sourcepub fn active_flag(&self) -> bool
pub fn active_flag(&self) -> bool
Returns the value of active_flag, or the default value if active_flag is unset.
Sourcepub fn security_type(&self) -> u32
pub fn security_type(&self) -> u32
Returns the value of security_type, or the default value if security_type is unset.
Sourcepub fn trade_market(&self) -> u32
pub fn trade_market(&self) -> u32
Returns the value of trade_market, or the default value if trade_market is unset.
Sourcepub fn exchange(&self) -> &str
pub fn exchange(&self) -> &str
Returns the value of exchange, or the default value if exchange is unset.
Sourcepub fn product_code(&self) -> &str
pub fn product_code(&self) -> &str
Returns the value of product_code, or the default value if product_code is unset.
Sourcepub fn product_code_to(&self) -> &str
pub fn product_code_to(&self) -> &str
Returns the value of product_code_to, or the default value if product_code_to is unset.
Sourcepub fn underlying_symbol(&self) -> &str
pub fn underlying_symbol(&self) -> &str
Returns the value of underlying_symbol, or the default value if underlying_symbol is unset.
Sourcepub fn underlying_cusip(&self) -> &str
pub fn underlying_cusip(&self) -> &str
Returns the value of underlying_cusip, or the default value if underlying_cusip is unset.
Sourcepub fn effect_date(&self) -> u32
pub fn effect_date(&self) -> u32
Returns the value of effect_date, or the default value if effect_date is unset.
Sourcepub fn underlying_event_type(&self) -> &str
pub fn underlying_event_type(&self) -> &str
Returns the value of underlying_event_type, or the default value if underlying_event_type is unset.
Sourcepub fn underlying_event_type_origin(&self) -> &str
pub fn underlying_event_type_origin(&self) -> &str
Returns the value of underlying_event_type_origin, or the default value if underlying_event_type_origin is unset.
Sourcepub fn underlying_event_type_description(&self) -> &str
pub fn underlying_event_type_description(&self) -> &str
Returns the value of underlying_event_type_description, or the default value if underlying_event_type_description is unset.
Sourcepub fn strike_price_change(&self) -> &str
pub fn strike_price_change(&self) -> &str
Returns the value of strike_price_change, or the default value if strike_price_change is unset.
Sourcepub fn strike_multiplier(&self) -> &str
pub fn strike_multiplier(&self) -> &str
Returns the value of strike_multiplier, or the default value if strike_multiplier is unset.
Sourcepub fn multiplier(&self) -> &str
pub fn multiplier(&self) -> &str
Returns the value of multiplier, or the default value if multiplier is unset.
Sourcepub fn strike_currency(&self) -> &str
pub fn strike_currency(&self) -> &str
Returns the value of strike_currency, or the default value if strike_currency is unset.
Sourcepub fn deliverable_formula(&self) -> &str
pub fn deliverable_formula(&self) -> &str
Returns the value of deliverable_formula, or the default value if deliverable_formula is unset.
Sourcepub fn update_time(&self) -> u64
pub fn update_time(&self) -> u64
Returns the value of update_time, or the default value if update_time is unset.