pub struct PositionRisk {
pub position_id: u64,
pub symbol: String,
pub exchange: Option<String>,
pub backend_trade_market: Option<u32>,
pub backend_security_type: Option<u32>,
pub coverage: i32,
pub coverage_message: Option<String>,
pub event_list: Vec<CorporateActionEvent>,
}Fields
position_id: u64symbol: Stringexchange: Option<String>backend_trade_market: Option<u32>backend_security_type: Option<u32>coverage: i32coverage_message: Option<String>event_list: Vec<CorporateActionEvent>Implementations
Sourceimpl PositionRisk
impl PositionRisk
Sourcepub fn exchange(&self) -> &str
pub fn exchange(&self) -> &str
Returns the value of exchange, or the default value if exchange is unset.
Sourcepub fn backend_trade_market(&self) -> u32
pub fn backend_trade_market(&self) -> u32
Returns the value of backend_trade_market, or the default value if backend_trade_market is unset.
Sourcepub fn backend_security_type(&self) -> u32
pub fn backend_security_type(&self) -> u32
Returns the value of backend_security_type, or the default value if backend_security_type is unset.
Sourcepub fn coverage(&self) -> CoverageStatus
pub fn coverage(&self) -> CoverageStatus
Returns the enum value of coverage, or the default if the field is set to an invalid enum value.
Sourcepub fn set_coverage(&mut self, value: CoverageStatus)
pub fn set_coverage(&mut self, value: CoverageStatus)
Sets coverage to the provided enum value.
Sourcepub fn coverage_message(&self) -> &str
pub fn coverage_message(&self) -> &str
Returns the value of coverage_message, or the default value if coverage_message is unset.