pub struct S2c {
pub header: TrdHeader,
pub scope: i32,
pub requested_area: String,
pub requested_currency: String,
pub query_type: Option<i32>,
pub time: Option<i64>,
pub total_yield_value: Option<String>,
pub total_yield_ratio: Option<String>,
pub nodes: Vec<ReturnNode>,
pub time_location: Option<String>,
pub calendar_date: Option<String>,
}Fields
header: TrdHeaderscope: i32requested_area: Stringrequested_currency: Stringquery_type: Option<i32>time: Option<i64>total_yield_value: Option<String>total_yield_ratio: Option<String>nodes: Vec<ReturnNode>time_location: Option<String>calendar_date: Option<String>Implementations
Sourceimpl S2c
impl S2c
Sourcepub fn scope(&self) -> PerformanceScope
pub fn scope(&self) -> PerformanceScope
Returns the enum value of scope, or the default if the field is set to an invalid enum value.
Sourcepub fn set_scope(&mut self, value: PerformanceScope)
pub fn set_scope(&mut self, value: PerformanceScope)
Sets scope to the provided enum value.
Sourcepub fn query_type(&self) -> CalendarQueryType
pub fn query_type(&self) -> CalendarQueryType
Returns the enum value of query_type, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_query_type(&mut self, value: CalendarQueryType)
pub fn set_query_type(&mut self, value: CalendarQueryType)
Sets query_type to the provided enum value.
Sourcepub fn total_yield_value(&self) -> &str
pub fn total_yield_value(&self) -> &str
Returns the value of total_yield_value, or the default value if total_yield_value is unset.
Sourcepub fn total_yield_ratio(&self) -> &str
pub fn total_yield_ratio(&self) -> &str
Returns the value of total_yield_ratio, or the default value if total_yield_ratio is unset.
Sourcepub fn time_location(&self) -> &str
pub fn time_location(&self) -> &str
Returns the value of time_location, or the default value if time_location is unset.
Sourcepub fn calendar_date(&self) -> &str
pub fn calendar_date(&self) -> &str
Returns the value of calendar_date, or the default value if calendar_date is unset.