pub struct MutationResult {
pub state: i32,
pub group_id: Option<String>,
pub order_mapping_list: Vec<OrderMapping>,
pub mapping_complete: bool,
pub need_op_confirm: Option<bool>,
pub action_type: Option<u32>,
pub confirmation_id: Option<String>,
pub confirmation_order_list: Vec<ConfirmationOrder>,
pub message: Option<String>,
}Fields
state: i32group_id: Option<String>order_mapping_list: Vec<OrderMapping>mapping_complete: boolneed_op_confirm: Option<bool>action_type: Option<u32>confirmation_id: Option<String>confirmation_order_list: Vec<ConfirmationOrder>message: Option<String>Implementations
Sourceimpl MutationResult
impl MutationResult
Sourcepub fn state(&self) -> MutationState
pub fn state(&self) -> MutationState
Returns the enum value of state, or the default if the field is set to an invalid enum value.
Sourcepub fn set_state(&mut self, value: MutationState)
pub fn set_state(&mut self, value: MutationState)
Sets state to the provided enum value.
Sourcepub fn group_id(&self) -> &str
pub fn group_id(&self) -> &str
Returns the value of group_id, or the default value if group_id is unset.
Sourcepub fn need_op_confirm(&self) -> bool
pub fn need_op_confirm(&self) -> bool
Returns the value of need_op_confirm, or the default value if need_op_confirm is unset.
Sourcepub fn action_type(&self) -> u32
pub fn action_type(&self) -> u32
Returns the value of action_type, or the default value if action_type is unset.
Sourcepub fn confirmation_id(&self) -> &str
pub fn confirmation_id(&self) -> &str
Returns the value of confirmation_id, or the default value if confirmation_id is unset.