pub struct AlgoParameters {
pub algo_type: i32,
pub start_time: Option<u64>,
pub end_time: Option<u64>,
pub pricing_type: Option<u32>,
pub layering_type: Option<u32>,
pub pricing_iterate_type: Option<u32>,
pub life_cycle: Option<u32>,
pub buy_back: Option<u32>,
pub force_override: Option<u32>,
pub specific: Option<Specific>,
}Fields
algo_type: i32start_time: Option<u64>end_time: Option<u64>pricing_type: Option<u32>layering_type: Option<u32>pricing_iterate_type: Option<u32>life_cycle: Option<u32>buy_back: Option<u32>ROA-only source fields. OpenD has no authoritative ROA context and rejects either field when supplied instead of forwarding a guessed fact.
force_override: Option<u32>specific: Option<Specific>Implementations
Sourceimpl AlgoParameters
impl AlgoParameters
Sourcepub fn algo_type(&self) -> AlgoType
pub fn algo_type(&self) -> AlgoType
Returns the enum value of algo_type, or the default if the field is set to an invalid enum value.
Sourcepub fn set_algo_type(&mut self, value: AlgoType)
pub fn set_algo_type(&mut self, value: AlgoType)
Sets algo_type to the provided enum value.
Sourcepub fn start_time(&self) -> u64
pub fn start_time(&self) -> u64
Returns the value of start_time, or the default value if start_time is unset.
Sourcepub fn end_time(&self) -> u64
pub fn end_time(&self) -> u64
Returns the value of end_time, or the default value if end_time is unset.
Sourcepub fn pricing_type(&self) -> u32
pub fn pricing_type(&self) -> u32
Returns the value of pricing_type, or the default value if pricing_type is unset.
Sourcepub fn layering_type(&self) -> u32
pub fn layering_type(&self) -> u32
Returns the value of layering_type, or the default value if layering_type is unset.
Sourcepub fn pricing_iterate_type(&self) -> u32
pub fn pricing_iterate_type(&self) -> u32
Returns the value of pricing_iterate_type, or the default value if pricing_iterate_type is unset.
Sourcepub fn life_cycle(&self) -> u32
pub fn life_cycle(&self) -> u32
Returns the value of life_cycle, or the default value if life_cycle is unset.
Sourcepub fn buy_back(&self) -> u32
pub fn buy_back(&self) -> u32
Returns the value of buy_back, or the default value if buy_back is unset.
Sourcepub fn force_override(&self) -> u32
pub fn force_override(&self) -> u32
Returns the value of force_override, or the default value if force_override is unset.