pub struct InitialOperation {Show 14 fields
pub idempotency_key: String,
pub client_order_id: String,
pub code: String,
pub sec_market: i32,
pub trd_side: i32,
pub qty: String,
pub price_mode: i32,
pub limit_price: Option<String>,
pub lot_type: u32,
pub order_trade_time_type: Option<u32>,
pub position_open_type: Option<u32>,
pub asset_category: Option<i32>,
pub pdt_protection: Option<bool>,
pub algo: AlgoParameters,
}Fields
idempotency_key: Stringclient_order_id: Stringcode: Stringsec_market: i32trd_side: i32qty: Stringprice_mode: i32limit_price: Option<String>lot_type: u32order_trade_time_type: Option<u32>position_open_type: Option<u32>Required by the guarded handler (Open=1 / Close=2). Kept optional on the wire so omission fails with a typed validation error rather than proto2 decode failure.
asset_category: Option<i32>pdt_protection: Option<bool>algo: AlgoParametersImplementations
Sourceimpl InitialOperation
impl InitialOperation
Sourcepub fn price_mode(&self) -> PriceMode
pub fn price_mode(&self) -> PriceMode
Returns the enum value of price_mode, or the default if the field is set to an invalid enum value.
Sourcepub fn set_price_mode(&mut self, value: PriceMode)
pub fn set_price_mode(&mut self, value: PriceMode)
Sets price_mode to the provided enum value.
Sourcepub fn limit_price(&self) -> &str
pub fn limit_price(&self) -> &str
Returns the value of limit_price, or the default value if limit_price is unset.
Sourcepub fn order_trade_time_type(&self) -> u32
pub fn order_trade_time_type(&self) -> u32
Returns the value of order_trade_time_type, or the default value if order_trade_time_type is unset.
Sourcepub fn position_open_type(&self) -> u32
pub fn position_open_type(&self) -> u32
Returns the value of position_open_type, or the default value if position_open_type is unset.
Sourcepub fn asset_category(&self) -> i32
pub fn asset_category(&self) -> i32
Returns the value of asset_category, or the default value if asset_category is unset.
Sourcepub fn pdt_protection(&self) -> bool
pub fn pdt_protection(&self) -> bool
Returns the value of pdt_protection, or the default value if pdt_protection is unset.