C2s

Struct C2s 

pub struct C2s {
Show 19 fields pub packet_id: PacketId, pub header: TrdHeader, pub trd_side: i32, pub order_type: i32, pub code: String, pub qty: f64, pub price: Option<f64>, pub adjust_price: Option<bool>, pub adjust_side_and_limit: Option<f64>, pub sec_market: Option<i32>, pub remark: Option<String>, pub time_in_force: Option<i32>, pub fill_outside_rth: Option<bool>, pub aux_price: Option<f64>, pub trail_type: Option<i32>, pub trail_value: Option<f64>, pub trail_spread: Option<f64>, pub session: Option<i32>, pub position_id: Option<u64>,
}

Fields

packet_id: PacketId

交易写操作防重放攻击

header: TrdHeader

交易公共参数头

trd_side: i32

交易方向, 参见Trd_Common.TrdSide的枚举定义

order_type: i32

订单类型, 参见Trd_Common.OrderType的枚举定义

code: String

代码,港股必须是5位数字,A股必须是6位数字,美股没限制

qty: f64

数量,期权单位是“张“(精确到小数点后 0 位,超出部分会被舍弃。期权期货单位是“张“)

price: Option<f64>

价格,(证券账户精确到小数点后 3 位,期货账户精确到小数点后 9 位,超出部分会被舍弃)

adjust_price: Option<bool>

以下2个为调整价格使用,都传才有效,对港、A股有意义,因为港股有价位,A股2位精度,美股可不传

是否调整价格,如果价格不合法,是否调整到合法价位,true调整,false不调整

adjust_side_and_limit: Option<f64>

调整方向和调整幅度百分比限制,正数代表向上调整,负数代表向下调整,具体值代表调整幅度限制,如:0.015代表向上调整且幅度不超过1.5%;-0.01代表向下调整且幅度不超过1%

sec_market: Option<i32>

证券所属市场,参见TrdSecMarket的枚举定义

remark: Option<String>

用户备注字符串,最多只能传64字节。可用于标识订单唯一信息等,下单填上,订单结构就会带上。

time_in_force: Option<i32>

订单有效期限,参见TrdCommon_TimeInForce的枚举定义

fill_outside_rth: Option<bool>

是否允许盘前盘后成交。仅适用于美股限价单。默认false

aux_price: Option<f64>

触发价格

trail_type: Option<i32>

跟踪类型, 参见Trd_Common.TrailType的枚举定义

trail_value: Option<f64>

跟踪金额/百分比

trail_spread: Option<f64>

指定价差

session: Option<i32>

美股订单时段, 参见Common.Session的枚举定义

position_id: Option<u64>

持仓ID,JP券商查询平仓数量时使用

Implementations

Source

impl C2s

pub fn price(&self) -> f64

Returns the value of price, or the default value if price is unset.

pub fn adjust_price(&self) -> bool

Returns the value of adjust_price, or the default value if adjust_price is unset.

pub fn adjust_side_and_limit(&self) -> f64

Returns the value of adjust_side_and_limit, or the default value if adjust_side_and_limit is unset.

pub fn sec_market(&self) -> i32

Returns the value of sec_market, or the default value if sec_market is unset.

pub fn remark(&self) -> &str

Returns the value of remark, or the default value if remark is unset.

pub fn time_in_force(&self) -> i32

Returns the value of time_in_force, or the default value if time_in_force is unset.

pub fn fill_outside_rth(&self) -> bool

Returns the value of fill_outside_rth, or the default value if fill_outside_rth is unset.

pub fn aux_price(&self) -> f64

Returns the value of aux_price, or the default value if aux_price is unset.

pub fn trail_type(&self) -> i32

Returns the value of trail_type, or the default value if trail_type is unset.

pub fn trail_value(&self) -> f64

Returns the value of trail_value, or the default value if trail_value is unset.

pub fn trail_spread(&self) -> f64

Returns the value of trail_spread, or the default value if trail_spread is unset.

pub fn session(&self) -> i32

Returns the value of session, or the default value if session is unset.

pub fn position_id(&self) -> u64

Returns the value of position_id, or the default value if position_id is unset.