#[repr(i32)]pub enum SecurityStatus {
Show 22 variants
Unknown = 0,
Normal = 1,
Listing = 2,
Purchasing = 3,
Subscribing = 4,
BeforeDrakTradeOpening = 5,
DrakTrading = 6,
DrakTradeEnd = 7,
ToBeOpen = 8,
Suspended = 9,
Called = 10,
ExpiredLastTradingDate = 11,
Expired = 12,
Delisted = 13,
ChangeToTemporaryCode = 14,
TemporaryCodeTradeEnd = 15,
ChangedPlateTradeEnd = 16,
ChangedCodeTradeEnd = 17,
RecoverableCircuitBreaker = 18,
UnRecoverableCircuitBreaker = 19,
AfterCombination = 20,
AfterTransation = 21,
}Variants
Unknown = 0
未知
Normal = 1
正常状态
Listing = 2
待上市
Purchasing = 3
申购中
Subscribing = 4
认购中
BeforeDrakTradeOpening = 5
暗盘开盘前
DrakTrading = 6
暗盘交易中
DrakTradeEnd = 7
暗盘已收盘
ToBeOpen = 8
待开盘
Suspended = 9
停牌
Called = 10
已收回
ExpiredLastTradingDate = 11
已过最后交易日
Expired = 12
已过期
Delisted = 13
已退市
ChangeToTemporaryCode = 14
公司行动中,交易关闭,转至临时代码交易
TemporaryCodeTradeEnd = 15
临时买卖结束,交易关闭
ChangedPlateTradeEnd = 16
已转板,旧代码交易关闭
ChangedCodeTradeEnd = 17
已换代码,旧代码交易关闭
RecoverableCircuitBreaker = 18
可恢复性熔断
UnRecoverableCircuitBreaker = 19
不可恢复性熔断
AfterCombination = 20
盘后撮合
AfterTransation = 21
盘后交易
Implementations
Sourceimpl SecurityStatus
impl SecurityStatus
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.