#[repr(i32)]pub enum TickerType {
Show 32 variants
Unknown = 0,
Automatch = 1,
Late = 2,
NoneAutomatch = 3,
InterAutomatch = 4,
InterNoneAutomatch = 5,
OddLot = 6,
Auction = 7,
Bulk = 8,
Crash = 9,
CrossMarket = 10,
BulkSold = 11,
FreeOnBoard = 12,
Rule127Or155 = 13,
Delay = 14,
MarketCenterClosePrice = 15,
NextDay = 16,
MarketCenterOpening = 17,
PriorReferencePrice = 18,
MarketCenterOpenPrice = 19,
Seller = 20,
T = 21,
ExtendedTradingHours = 22,
Contingent = 23,
AvgPrice = 24,
OtcSold = 25,
OddLotCrossMarket = 26,
DerivativelyPriced = 27,
ReOpeningPriced = 28,
ClosingPriced = 29,
ComprehensiveDelayPrice = 30,
Overseas = 31,
}Variants
Unknown = 0
未知
Automatch = 1
自动对盘
Late = 2
开市前成交盘
NoneAutomatch = 3
非自动对盘
InterAutomatch = 4
同一证券商自动对盘
InterNoneAutomatch = 5
同一证券商非自动对盘
OddLot = 6
碎股交易
Auction = 7
竞价交易
Bulk = 8
批量交易
Crash = 9
现金交易
CrossMarket = 10
跨市场交易
BulkSold = 11
批量卖出
FreeOnBoard = 12
离价交易
Rule127Or155 = 13
第127条交易(纽交所规则)或第155条交易
Delay = 14
延迟交易
MarketCenterClosePrice = 15
中央收市价
NextDay = 16
隔日交易
MarketCenterOpening = 17
中央开盘价交易
PriorReferencePrice = 18
前参考价
MarketCenterOpenPrice = 19
中央开盘价
Seller = 20
卖方
T = 21
T类交易(盘前和盘后交易)
ExtendedTradingHours = 22
延长交易时段
Contingent = 23
合单交易
AvgPrice = 24
平均价成交
OtcSold = 25
场外售出
OddLotCrossMarket = 26
碎股跨市场交易
DerivativelyPriced = 27
衍生工具定价
ReOpeningPriced = 28
再开盘定价
ClosingPriced = 29
收盘定价
ComprehensiveDelayPrice = 30
综合延迟价格
Overseas = 31
交易的一方不是香港交易所的成员,属于场外交易
Implementations
Sourceimpl TickerType
impl TickerType
Sourceimpl TickerType
impl TickerType
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.