pub struct EarningsBeatItem {Show 18 fields
pub security: Security,
pub name: Option<String>,
pub industry: Option<String>,
pub cur_price: Option<f64>,
pub last_close_price: Option<f64>,
pub change_rate: Option<f64>,
pub market_cap: Option<f64>,
pub pe_ttm: Option<f64>,
pub dividends_ttm: Option<f64>,
pub released_date: Option<String>,
pub beat_ratio: Option<f64>,
pub actual: Option<f64>,
pub estimate: Option<f64>,
pub yoy: Option<f64>,
pub yoy_growth: Option<f64>,
pub earning_day_chg: Option<f64>,
pub term: Option<String>,
pub detail_post_period: Option<i32>,
}Expand description
盈利超预期排行数据项
Fields
security: Security股票
name: Option<String>名称
industry: Option<String>行业
cur_price: Option<f64>行情
最新价
last_close_price: Option<f64>昨收价
change_rate: Option<f64>今日涨跌幅 (%)
market_cap: Option<f64>市值
pe_ttm: Option<f64>市盈率TTM
dividends_ttm: Option<f64>股息率TTM (%)
released_date: Option<String>盈利超预期
发布日期 (如 “2024-01-15”)
beat_ratio: Option<f64>超预期比率 (%)
actual: Option<f64>实际值
estimate: Option<f64>预测值
yoy: Option<f64>去年同期
yoy_growth: Option<f64>同比增长率 (%)
earning_day_chg: Option<f64>财报后首日涨幅 (%)
term: Option<String>财报周期 (如 “2024/Q1”)
detail_post_period: Option<i32>PostPeriodType, 发布具体时段
Implementations
Sourceimpl EarningsBeatItem
impl EarningsBeatItem
Sourcepub fn industry(&self) -> &str
pub fn industry(&self) -> &str
Returns the value of industry, or the default value if industry is unset.
Sourcepub fn cur_price(&self) -> f64
pub fn cur_price(&self) -> f64
Returns the value of cur_price, or the default value if cur_price is unset.
Sourcepub fn last_close_price(&self) -> f64
pub fn last_close_price(&self) -> f64
Returns the value of last_close_price, or the default value if last_close_price is unset.
Sourcepub fn change_rate(&self) -> f64
pub fn change_rate(&self) -> f64
Returns the value of change_rate, or the default value if change_rate is unset.
Sourcepub fn market_cap(&self) -> f64
pub fn market_cap(&self) -> f64
Returns the value of market_cap, or the default value if market_cap is unset.
Sourcepub fn pe_ttm(&self) -> f64
pub fn pe_ttm(&self) -> f64
Returns the value of pe_ttm, or the default value if pe_ttm is unset.
Sourcepub fn dividends_ttm(&self) -> f64
pub fn dividends_ttm(&self) -> f64
Returns the value of dividends_ttm, or the default value if dividends_ttm is unset.
Sourcepub fn released_date(&self) -> &str
pub fn released_date(&self) -> &str
Returns the value of released_date, or the default value if released_date is unset.
Sourcepub fn beat_ratio(&self) -> f64
pub fn beat_ratio(&self) -> f64
Returns the value of beat_ratio, or the default value if beat_ratio is unset.
Sourcepub fn actual(&self) -> f64
pub fn actual(&self) -> f64
Returns the value of actual, or the default value if actual is unset.
Sourcepub fn estimate(&self) -> f64
pub fn estimate(&self) -> f64
Returns the value of estimate, or the default value if estimate is unset.
Sourcepub fn yoy_growth(&self) -> f64
pub fn yoy_growth(&self) -> f64
Returns the value of yoy_growth, or the default value if yoy_growth is unset.
Sourcepub fn earning_day_chg(&self) -> f64
pub fn earning_day_chg(&self) -> f64
Returns the value of earning_day_chg, or the default value if earning_day_chg is unset.
Sourcepub fn detail_post_period(&self) -> i32
pub fn detail_post_period(&self) -> i32
Returns the value of detail_post_period, or the default value if detail_post_period is unset.