pub struct EventItem {
pub event_security: Security,
pub event_name: Option<String>,
pub event_sub_name: Option<String>,
pub status: Option<i32>,
pub series_security: Option<Security>,
pub start_date: Option<String>,
pub end_date: Option<String>,
pub category: Option<String>,
pub tags: Vec<String>,
pub mutually_exclusive: Option<bool>,
pub competition: Option<String>,
pub competition_scope: Option<String>,
}Expand description
事件项
Fields
event_security: Security{market=101, code=“EC.KXGDP-27JAN30”}
event_name: Option<String>事件名称(多语言)
event_sub_name: Option<String>事件副标题(多语言)
status: Option<i32>事件状态
series_security: Option<Security>所属 Series
start_date: Option<String>开始时间(美东时区,形如 2026-06-28 00:00:00)
end_date: Option<String>结束时间(美东时区,形如 2026-06-28 00:00:00)
category: Option<String>一级分类标识
二级分类标识列表(一个 event 可归属多个 tag)
mutually_exclusive: Option<bool>合约结果是否互斥
competition: Option<String>赛事名称(多语言)
competition_scope: Option<String>赛事类型/玩法(多语言)
Implementations
Sourceimpl EventItem
impl EventItem
Sourcepub fn event_name(&self) -> &str
pub fn event_name(&self) -> &str
Returns the value of event_name, or the default value if event_name is unset.
Sourcepub fn event_sub_name(&self) -> &str
pub fn event_sub_name(&self) -> &str
Returns the value of event_sub_name, or the default value if event_sub_name is unset.
Sourcepub fn status(&self) -> EcStatus
pub fn status(&self) -> EcStatus
Returns the enum value of status, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_status(&mut self, value: EcStatus)
pub fn set_status(&mut self, value: EcStatus)
Sets status to the provided enum value.
Sourcepub fn start_date(&self) -> &str
pub fn start_date(&self) -> &str
Returns the value of start_date, or the default value if start_date is unset.
Sourcepub fn end_date(&self) -> &str
pub fn end_date(&self) -> &str
Returns the value of end_date, or the default value if end_date is unset.
Sourcepub fn category(&self) -> &str
pub fn category(&self) -> &str
Returns the value of category, or the default value if category is unset.
Sourcepub fn mutually_exclusive(&self) -> bool
pub fn mutually_exclusive(&self) -> bool
Returns the value of mutually_exclusive, or the default value if mutually_exclusive is unset.
Sourcepub fn competition(&self) -> &str
pub fn competition(&self) -> &str
Returns the value of competition, or the default value if competition is unset.
Sourcepub fn competition_scope(&self) -> &str
pub fn competition_scope(&self) -> &str
Returns the value of competition_scope, or the default value if competition_scope is unset.