pub struct SnapshotItem {Show 19 fields
pub code: Security,
pub name: Option<String>,
pub event_code: Option<Security>,
pub yes_sub_title: Option<String>,
pub no_sub_title: Option<String>,
pub status: Option<i32>,
pub price: Option<f64>,
pub cumulative_volume: Option<f64>,
pub yes_bid: Option<f64>,
pub yes_bid_size: Option<f64>,
pub yes_ask: Option<f64>,
pub yes_ask_size: Option<f64>,
pub no_bid: Option<f64>,
pub no_bid_size: Option<f64>,
pub no_ask: Option<f64>,
pub no_ask_size: Option<f64>,
pub last_trade_time: Option<String>,
pub volume_24h: Option<f64>,
pub open_interest: Option<f64>,
}Expand description
快照数据项
Fields
code: Security合约代码
name: Option<String>合约名称(多语言)
event_code: Option<Security>所属 Event 标的
yes_sub_title: Option<String>YES 子标题(多语言)
no_sub_title: Option<String>NO 子标题(多语言)
status: Option<i32>合约状态
price: Option<f64>最新价格
cumulative_volume: Option<f64>累计成交量
yes_bid: Option<f64>YES 买一
yes_bid_size: Option<f64>YES 买一量
yes_ask: Option<f64>YES 卖一
yes_ask_size: Option<f64>YES 卖一量
no_bid: Option<f64>NO 买一
no_bid_size: Option<f64>NO 买一量
no_ask: Option<f64>NO 卖一
no_ask_size: Option<f64>NO 卖一量
last_trade_time: Option<String>最新一笔成交时间(yyyy-MM-dd HH:mm:ss)
volume_24h: Option<f64>24h 成交量
open_interest: Option<f64>持仓量
Implementations
Sourceimpl SnapshotItem
impl SnapshotItem
Sourcepub fn yes_sub_title(&self) -> &str
pub fn yes_sub_title(&self) -> &str
Returns the value of yes_sub_title, or the default value if yes_sub_title is unset.
Sourcepub fn no_sub_title(&self) -> &str
pub fn no_sub_title(&self) -> &str
Returns the value of no_sub_title, or the default value if no_sub_title is unset.
Sourcepub fn status(&self) -> EcStatus
pub fn status(&self) -> EcStatus
Returns the enum value of status, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_status(&mut self, value: EcStatus)
pub fn set_status(&mut self, value: EcStatus)
Sets status to the provided enum value.
Sourcepub fn cumulative_volume(&self) -> f64
pub fn cumulative_volume(&self) -> f64
Returns the value of cumulative_volume, or the default value if cumulative_volume is unset.
Sourcepub fn yes_bid(&self) -> f64
pub fn yes_bid(&self) -> f64
Returns the value of yes_bid, or the default value if yes_bid is unset.
Sourcepub fn yes_bid_size(&self) -> f64
pub fn yes_bid_size(&self) -> f64
Returns the value of yes_bid_size, or the default value if yes_bid_size is unset.
Sourcepub fn yes_ask(&self) -> f64
pub fn yes_ask(&self) -> f64
Returns the value of yes_ask, or the default value if yes_ask is unset.
Sourcepub fn yes_ask_size(&self) -> f64
pub fn yes_ask_size(&self) -> f64
Returns the value of yes_ask_size, or the default value if yes_ask_size is unset.
Sourcepub fn no_bid(&self) -> f64
pub fn no_bid(&self) -> f64
Returns the value of no_bid, or the default value if no_bid is unset.
Sourcepub fn no_bid_size(&self) -> f64
pub fn no_bid_size(&self) -> f64
Returns the value of no_bid_size, or the default value if no_bid_size is unset.
Sourcepub fn no_ask(&self) -> f64
pub fn no_ask(&self) -> f64
Returns the value of no_ask, or the default value if no_ask is unset.
Sourcepub fn no_ask_size(&self) -> f64
pub fn no_ask_size(&self) -> f64
Returns the value of no_ask_size, or the default value if no_ask_size is unset.
Sourcepub fn last_trade_time(&self) -> &str
pub fn last_trade_time(&self) -> &str
Returns the value of last_trade_time, or the default value if last_trade_time is unset.
Sourcepub fn volume_24h(&self) -> f64
pub fn volume_24h(&self) -> f64
Returns the value of volume_24h, or the default value if volume_24h is unset.
Sourcepub fn open_interest(&self) -> f64
pub fn open_interest(&self) -> f64
Returns the value of open_interest, or the default value if open_interest is unset.