pub struct HeatMapPlateData {Show 13 fields
pub plate: Option<Security>,
pub plate_name: Option<String>,
pub cur_price: Option<f64>,
pub change_rate: Option<f64>,
pub turnover: Option<f64>,
pub volume: Option<i64>,
pub market_val: Option<f64>,
pub pe_avg: Option<f64>,
pub rise_count: Option<i32>,
pub fall_count: Option<i32>,
pub equal_count: Option<i32>,
pub leader_stock: Option<Security>,
pub description: Option<String>,
}Fields
plate: Option<Security>板块
plate_name: Option<String>板块名称
cur_price: Option<f64>最新价
change_rate: Option<f64>涨跌幅(%)
turnover: Option<f64>成交额
volume: Option<i64>成交量
market_val: Option<f64>市值
pe_avg: Option<f64>平均市盈率
rise_count: Option<i32>涨家数
fall_count: Option<i32>跌家数
equal_count: Option<i32>持平数
leader_stock: Option<Security>领涨股
description: Option<String>板块描述
Implementations
Sourceimpl HeatMapPlateData
impl HeatMapPlateData
Sourcepub fn plate_name(&self) -> &str
pub fn plate_name(&self) -> &str
Returns the value of plate_name, or the default value if plate_name is unset.
Sourcepub fn cur_price(&self) -> f64
pub fn cur_price(&self) -> f64
Returns the value of cur_price, or the default value if cur_price is unset.
Sourcepub fn change_rate(&self) -> f64
pub fn change_rate(&self) -> f64
Returns the value of change_rate, or the default value if change_rate is unset.
Sourcepub fn turnover(&self) -> f64
pub fn turnover(&self) -> f64
Returns the value of turnover, or the default value if turnover is unset.
Sourcepub fn volume(&self) -> i64
pub fn volume(&self) -> i64
Returns the value of volume, or the default value if volume is unset.
Sourcepub fn market_val(&self) -> f64
pub fn market_val(&self) -> f64
Returns the value of market_val, or the default value if market_val is unset.
Sourcepub fn pe_avg(&self) -> f64
pub fn pe_avg(&self) -> f64
Returns the value of pe_avg, or the default value if pe_avg is unset.
Sourcepub fn rise_count(&self) -> i32
pub fn rise_count(&self) -> i32
Returns the value of rise_count, or the default value if rise_count is unset.
Sourcepub fn fall_count(&self) -> i32
pub fn fall_count(&self) -> i32
Returns the value of fall_count, or the default value if fall_count is unset.
Sourcepub fn equal_count(&self) -> i32
pub fn equal_count(&self) -> i32
Returns the value of equal_count, or the default value if equal_count is unset.
Sourcepub fn description(&self) -> &str
pub fn description(&self) -> &str
Returns the value of description, or the default value if description is unset.