pub struct OptionRankItem {Show 24 fields
pub option: Security,
pub name: Option<String>,
pub option_type: Option<i32>,
pub oi_increment: Option<i64>,
pub oi_decrement: Option<i64>,
pub oi_market_cap_increment: Option<f64>,
pub oi_market_cap_decrement: Option<f64>,
pub volume: Option<i64>,
pub turnover: Option<f64>,
pub open_interest: Option<i64>,
pub open_interest_market_cap: Option<f64>,
pub iv: Option<f64>,
pub option_price: Option<f64>,
pub change_rate: Option<f64>,
pub mid_price: Option<f64>,
pub bid_price: Option<f64>,
pub bid_volume: Option<i64>,
pub ask_price: Option<f64>,
pub ask_volume: Option<i64>,
pub delta: Option<f64>,
pub gamma: Option<f64>,
pub theta: Option<f64>,
pub vega: Option<f64>,
pub rho: Option<f64>,
}Expand description
期权合约排行项
Fields
option: Security基础标识
期权合约
name: Option<String>期权名称
option_type: Option<i32>Qot_Common.OptionType,期权类型(看涨/看跌)
oi_increment: Option<i64>数据字段
增仓量(>=0)
oi_decrement: Option<i64>减仓量(>=0)
oi_market_cap_increment: Option<f64>增仓额(>=0)
oi_market_cap_decrement: Option<f64>减仓额(>=0)
volume: Option<i64>成交量
turnover: Option<f64>成交额
open_interest: Option<i64>持仓量
open_interest_market_cap: Option<f64>持仓额
iv: Option<f64>隐含波动率(该字段为百分比字段,默认不展示%,如20实际对应20%)
option_price: Option<f64>期权最新价
change_rate: Option<f64>涨跌幅(该字段为百分比字段,默认不展示%,如20实际对应20%)
mid_price: Option<f64>中间价
bid_price: Option<f64>买入价
bid_volume: Option<i64>买量
ask_price: Option<f64>卖出价
ask_volume: Option<i64>卖量
delta: Option<f64>希腊值 Delta
gamma: Option<f64>希腊值 Gamma
theta: Option<f64>希腊值 Theta
vega: Option<f64>希腊值 Vega
rho: Option<f64>希腊值 Rho
Implementations
Sourceimpl OptionRankItem
impl OptionRankItem
Sourcepub fn option_type(&self) -> i32
pub fn option_type(&self) -> i32
Returns the value of option_type, or the default value if option_type is unset.
Sourcepub fn oi_increment(&self) -> i64
pub fn oi_increment(&self) -> i64
Returns the value of oi_increment, or the default value if oi_increment is unset.
Sourcepub fn oi_decrement(&self) -> i64
pub fn oi_decrement(&self) -> i64
Returns the value of oi_decrement, or the default value if oi_decrement is unset.
Sourcepub fn oi_market_cap_increment(&self) -> f64
pub fn oi_market_cap_increment(&self) -> f64
Returns the value of oi_market_cap_increment, or the default value if oi_market_cap_increment is unset.
Sourcepub fn oi_market_cap_decrement(&self) -> f64
pub fn oi_market_cap_decrement(&self) -> f64
Returns the value of oi_market_cap_decrement, or the default value if oi_market_cap_decrement is unset.
Sourcepub fn volume(&self) -> i64
pub fn volume(&self) -> i64
Returns the value of volume, or the default value if volume is unset.
Sourcepub fn turnover(&self) -> f64
pub fn turnover(&self) -> f64
Returns the value of turnover, or the default value if turnover is unset.
Sourcepub fn open_interest(&self) -> i64
pub fn open_interest(&self) -> i64
Returns the value of open_interest, or the default value if open_interest is unset.
Sourcepub fn open_interest_market_cap(&self) -> f64
pub fn open_interest_market_cap(&self) -> f64
Returns the value of open_interest_market_cap, or the default value if open_interest_market_cap is unset.
Sourcepub fn option_price(&self) -> f64
pub fn option_price(&self) -> f64
Returns the value of option_price, or the default value if option_price is unset.
Sourcepub fn change_rate(&self) -> f64
pub fn change_rate(&self) -> f64
Returns the value of change_rate, or the default value if change_rate is unset.
Sourcepub fn mid_price(&self) -> f64
pub fn mid_price(&self) -> f64
Returns the value of mid_price, or the default value if mid_price is unset.
Sourcepub fn bid_price(&self) -> f64
pub fn bid_price(&self) -> f64
Returns the value of bid_price, or the default value if bid_price is unset.
Sourcepub fn bid_volume(&self) -> i64
pub fn bid_volume(&self) -> i64
Returns the value of bid_volume, or the default value if bid_volume is unset.
Sourcepub fn ask_price(&self) -> f64
pub fn ask_price(&self) -> f64
Returns the value of ask_price, or the default value if ask_price is unset.
Sourcepub fn ask_volume(&self) -> i64
pub fn ask_volume(&self) -> i64
Returns the value of ask_volume, or the default value if ask_volume is unset.