pub struct PeriodChangeRankItem {Show 20 fields
pub security: Security,
pub name: Option<String>,
pub cur_price: Option<f64>,
pub change_ratio: Option<f64>,
pub turnover: Option<f64>,
pub volume: Option<i64>,
pub market_cap: Option<f64>,
pub change_rate5_min: Option<f64>,
pub change_rate5_d: Option<f64>,
pub change_rate10_d: Option<f64>,
pub change_rate20_d: Option<f64>,
pub change_rate60_d: Option<f64>,
pub change_rate120_d: Option<f64>,
pub change_rate250_d: Option<f64>,
pub change_rate_ytd: Option<f64>,
pub pe_ttm: Option<f64>,
pub pb: Option<f64>,
pub turnover_ratio: Option<f64>,
pub volume_ratio: Option<f64>,
pub amplitude: Option<f64>,
}Expand description
区间涨跌幅数据项
Fields
security: Security股票
name: Option<String>名称
cur_price: Option<f64>最新价
change_ratio: Option<f64>今日涨跌幅(%)
turnover: Option<f64>成交额
volume: Option<i64>成交量
market_cap: Option<f64>市值
change_rate5_min: Option<f64>5分钟涨跌幅(%)
change_rate5_d: Option<f64>5日涨跌幅(%)
change_rate10_d: Option<f64>10日涨跌幅(%)
change_rate20_d: Option<f64>20日涨跌幅(%)
change_rate60_d: Option<f64>60日涨跌幅(%)
change_rate120_d: Option<f64>120日涨跌幅(%)
change_rate250_d: Option<f64>250日涨跌幅(%)
change_rate_ytd: Option<f64>年初至今涨跌幅(%)
pe_ttm: Option<f64>市盈率TTM
pb: Option<f64>市净率
turnover_ratio: Option<f64>换手率(%)
volume_ratio: Option<f64>量比
amplitude: Option<f64>振幅(%)
Implementations
Sourceimpl PeriodChangeRankItem
impl PeriodChangeRankItem
Sourcepub fn cur_price(&self) -> f64
pub fn cur_price(&self) -> f64
Returns the value of cur_price, or the default value if cur_price is unset.
Sourcepub fn change_ratio(&self) -> f64
pub fn change_ratio(&self) -> f64
Returns the value of change_ratio, or the default value if change_ratio is unset.
Sourcepub fn turnover(&self) -> f64
pub fn turnover(&self) -> f64
Returns the value of turnover, or the default value if turnover is unset.
Sourcepub fn volume(&self) -> i64
pub fn volume(&self) -> i64
Returns the value of volume, or the default value if volume is unset.
Sourcepub fn market_cap(&self) -> f64
pub fn market_cap(&self) -> f64
Returns the value of market_cap, or the default value if market_cap is unset.
Sourcepub fn change_rate5_min(&self) -> f64
pub fn change_rate5_min(&self) -> f64
Returns the value of change_rate5_min, or the default value if change_rate5_min is unset.
Sourcepub fn change_rate5_d(&self) -> f64
pub fn change_rate5_d(&self) -> f64
Returns the value of change_rate5_d, or the default value if change_rate5_d is unset.
Sourcepub fn change_rate10_d(&self) -> f64
pub fn change_rate10_d(&self) -> f64
Returns the value of change_rate10_d, or the default value if change_rate10_d is unset.
Sourcepub fn change_rate20_d(&self) -> f64
pub fn change_rate20_d(&self) -> f64
Returns the value of change_rate20_d, or the default value if change_rate20_d is unset.
Sourcepub fn change_rate60_d(&self) -> f64
pub fn change_rate60_d(&self) -> f64
Returns the value of change_rate60_d, or the default value if change_rate60_d is unset.
Sourcepub fn change_rate120_d(&self) -> f64
pub fn change_rate120_d(&self) -> f64
Returns the value of change_rate120_d, or the default value if change_rate120_d is unset.
Sourcepub fn change_rate250_d(&self) -> f64
pub fn change_rate250_d(&self) -> f64
Returns the value of change_rate250_d, or the default value if change_rate250_d is unset.
Sourcepub fn change_rate_ytd(&self) -> f64
pub fn change_rate_ytd(&self) -> f64
Returns the value of change_rate_ytd, or the default value if change_rate_ytd is unset.
Sourcepub fn pe_ttm(&self) -> f64
pub fn pe_ttm(&self) -> f64
Returns the value of pe_ttm, or the default value if pe_ttm is unset.
Sourcepub fn turnover_ratio(&self) -> f64
pub fn turnover_ratio(&self) -> f64
Returns the value of turnover_ratio, or the default value if turnover_ratio is unset.
Sourcepub fn volume_ratio(&self) -> f64
pub fn volume_ratio(&self) -> f64
Returns the value of volume_ratio, or the default value if volume_ratio is unset.