pub struct StockNewsItem {Show 31 fields
pub bulletin_id: Option<u32>,
pub time: Option<u32>,
pub title: Option<String>,
pub url: Option<String>,
pub source: Option<String>,
pub importance_level: Option<u32>,
pub importance_tag: Option<String>,
pub content_tags: Vec<String>,
pub is_push: Option<u32>,
pub polarity: Option<u32>,
pub is_highlight: Option<u32>,
pub audio_url: Option<String>,
pub audio_duration: Option<u32>,
pub fixed_position: Option<u32>,
pub content_type: Option<u32>,
pub news_type: Option<u32>,
pub origin_lang: Option<String>,
pub pic: Option<String>,
pub post_id: Option<u32>,
pub abstract: Option<String>,
pub translated_title: Option<String>,
pub link_type: Option<u32>,
pub news_unique_id: Option<String>,
pub is_video: Option<u32>,
pub is_auto_translated: Option<u32>,
pub futu_source: Option<String>,
pub content_status: Option<u32>,
pub operation_position: Option<u32>,
pub operation_top_type: Option<i32>,
pub show_translate_button: Option<bool>,
pub new_news_id: Option<String>,
}Fields
bulletin_id: Option<u32>time: Option<u32>title: Option<String>url: Option<String>source: Option<String>importance_level: Option<u32>importance_tag: Option<String>is_push: Option<u32>polarity: Option<u32>is_highlight: Option<u32>audio_url: Option<String>audio_duration: Option<u32>fixed_position: Option<u32>content_type: Option<u32>news_type: Option<u32>origin_lang: Option<String>pic: Option<String>post_id: Option<u32>abstract: Option<String>translated_title: Option<String>link_type: Option<u32>news_unique_id: Option<String>is_video: Option<u32>is_auto_translated: Option<u32>futu_source: Option<String>content_status: Option<u32>operation_position: Option<u32>operation_top_type: Option<i32>new_news_id: Option<String>Implementations
Sourceimpl StockNewsItem
impl StockNewsItem
Sourcepub fn bulletin_id(&self) -> u32
pub fn bulletin_id(&self) -> u32
Returns the value of bulletin_id, or the default value if bulletin_id is unset.
Sourcepub fn title(&self) -> &str
pub fn title(&self) -> &str
Returns the value of title, or the default value if title is unset.
Sourcepub fn source(&self) -> &str
pub fn source(&self) -> &str
Returns the value of source, or the default value if source is unset.
Sourcepub fn importance_level(&self) -> u32
pub fn importance_level(&self) -> u32
Returns the value of importance_level, or the default value if importance_level is unset.
Sourcepub fn importance_tag(&self) -> &str
pub fn importance_tag(&self) -> &str
Returns the value of importance_tag, or the default value if importance_tag is unset.
Sourcepub fn is_push(&self) -> u32
pub fn is_push(&self) -> u32
Returns the value of is_push, or the default value if is_push is unset.
Sourcepub fn polarity(&self) -> u32
pub fn polarity(&self) -> u32
Returns the value of polarity, or the default value if polarity is unset.
Sourcepub fn is_highlight(&self) -> u32
pub fn is_highlight(&self) -> u32
Returns the value of is_highlight, or the default value if is_highlight is unset.
Sourcepub fn audio_url(&self) -> &str
pub fn audio_url(&self) -> &str
Returns the value of audio_url, or the default value if audio_url is unset.
Sourcepub fn audio_duration(&self) -> u32
pub fn audio_duration(&self) -> u32
Returns the value of audio_duration, or the default value if audio_duration is unset.
Sourcepub fn fixed_position(&self) -> u32
pub fn fixed_position(&self) -> u32
Returns the value of fixed_position, or the default value if fixed_position is unset.
Sourcepub fn content_type(&self) -> u32
pub fn content_type(&self) -> u32
Returns the value of content_type, or the default value if content_type is unset.
Sourcepub fn news_type(&self) -> u32
pub fn news_type(&self) -> u32
Returns the value of news_type, or the default value if news_type is unset.
Sourcepub fn origin_lang(&self) -> &str
pub fn origin_lang(&self) -> &str
Returns the value of origin_lang, or the default value if origin_lang is unset.
Sourcepub fn post_id(&self) -> u32
pub fn post_id(&self) -> u32
Returns the value of post_id, or the default value if post_id is unset.
Sourcepub fn abstract(&self) -> &str
pub fn abstract(&self) -> &str
Returns the value of abstract, or the default value if abstract is unset.
Sourcepub fn translated_title(&self) -> &str
pub fn translated_title(&self) -> &str
Returns the value of translated_title, or the default value if translated_title is unset.
Sourcepub fn link_type(&self) -> u32
pub fn link_type(&self) -> u32
Returns the value of link_type, or the default value if link_type is unset.
Sourcepub fn news_unique_id(&self) -> &str
pub fn news_unique_id(&self) -> &str
Returns the value of news_unique_id, or the default value if news_unique_id is unset.
Sourcepub fn is_video(&self) -> u32
pub fn is_video(&self) -> u32
Returns the value of is_video, or the default value if is_video is unset.
Sourcepub fn is_auto_translated(&self) -> u32
pub fn is_auto_translated(&self) -> u32
Returns the value of is_auto_translated, or the default value if is_auto_translated is unset.
Sourcepub fn futu_source(&self) -> &str
pub fn futu_source(&self) -> &str
Returns the value of futu_source, or the default value if futu_source is unset.
Sourcepub fn content_status(&self) -> u32
pub fn content_status(&self) -> u32
Returns the value of content_status, or the default value if content_status is unset.
Sourcepub fn operation_position(&self) -> u32
pub fn operation_position(&self) -> u32
Returns the value of operation_position, or the default value if operation_position is unset.
Sourcepub fn operation_top_type(&self) -> i32
pub fn operation_top_type(&self) -> i32
Returns the value of operation_top_type, or the default value if operation_top_type is unset.
Returns the value of show_translate_button, or the default value if show_translate_button is unset.
Sourcepub fn new_news_id(&self) -> &str
pub fn new_news_id(&self) -> &str
Returns the value of new_news_id, or the default value if new_news_id is unset.