#[repr(i32)]pub enum OptionRankIndicatorType {
Show 19 variants
Unknown = 0,
StockCategory = 1,
MarketCap = 2,
OwnerList = 3,
UnderlyingIv = 4,
UnderlyingHv = 5,
IvRank = 6,
IvPercentile = 7,
Iv = 8,
OptionType = 9,
LeftDays = 10,
InTheMoney = 11,
Volume = 12,
OpenInterest = 13,
Delta = 14,
Gamma = 15,
Theta = 16,
Vega = 17,
Rho = 18,
}Expand description
期权合约排行筛选因子类型
Variants
Unknown = 0
未知
StockCategory = 1
标的级
【确切值】品类(StockCategory)
MarketCap = 2
【范围】市值
OwnerList = 3
【确切值】股票范围(securityList)
UnderlyingIv = 4
【范围】正股IV(%)
UnderlyingHv = 5
【范围】正股HV(%)
IvRank = 6
【范围】IV等级(%)
IvPercentile = 7
【范围】IV百分位数(%)
Iv = 8
期权级
【范围】隐含波动率(%)
OptionType = 9
【确切值】方向(Call/Put)
LeftDays = 10
【范围】距到期日
InTheMoney = 11
【确切值】价内/价外(0=价外,1=价内)
Volume = 12
【范围】成交量
OpenInterest = 13
【范围】持仓量
Delta = 14
【范围】Delta
Gamma = 15
【范围】Gamma
Theta = 16
【范围】Theta
Vega = 17
【范围】Vega
Rho = 18
【范围】Rho
Implementations
Sourceimpl OptionRankIndicatorType
impl OptionRankIndicatorType
Sourcepub fn is_valid(value: i32) -> bool
pub fn is_valid(value: i32) -> bool
Returns true if value is a variant of OptionRankIndicatorType.
Sourcepub fn from_i32(value: i32) -> Option<OptionRankIndicatorType>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<OptionRankIndicatorType>
Use the TryFrom<i32> implementation instead
Converts an i32 to a OptionRankIndicatorType, or None if value is not a valid variant.
Sourceimpl OptionRankIndicatorType
impl OptionRankIndicatorType
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.