#[repr(i32)]pub enum UnderlyingIndicatorType {
Show 17 variants
Unknown = 0,
StockList = 101,
Plate = 103,
IndexList = 106,
Volume = 201,
OpenInterest = 202,
Iv = 203,
Hv = 204,
IvRank = 205,
IvPercentile = 206,
IvChange = 207,
IvChangeRatio = 208,
IvhvRatio = 209,
IvhvSpread = 210,
MarketCap = 401,
StockPrice = 402,
ChangeRatio = 403,
}Expand description
标的筛选因子类型
Variants
Unknown = 0
未知
StockList = 101
标的基本信息
【确切值】指定标的范围(股票ID列表)
Plate = 103
👎Deprecated
⚠️ 不支持: 后端 option_screener_svc 未实装, 传入会被 OpenD 入口拦截并返回错误
【已废弃】指定板块, 后端不支持
IndexList = 106
【确切值】指定指数类型
Volume = 201
标的期权统计
【范围】总成交量
OpenInterest = 202
【范围】总持仓量
Iv = 203
【范围】标的IV
Hv = 204
【范围】标的HV
IvRank = 205
【范围】标的IV Rank
IvPercentile = 206
【范围】标的IV Percentile
IvChange = 207
【范围】标的IV变化量
IvChangeRatio = 208
【范围】标的IV变化率
IvhvRatio = 209
【范围】标的IV/HV
IvhvSpread = 210
【范围】标的IV-HV
MarketCap = 401
行情指标
【范围】标的市值
StockPrice = 402
【范围】标的最新价
ChangeRatio = 403
【范围】涨跌幅
Implementations
Sourceimpl UnderlyingIndicatorType
impl UnderlyingIndicatorType
Sourcepub fn is_valid(value: i32) -> bool
pub fn is_valid(value: i32) -> bool
Returns true if value is a variant of UnderlyingIndicatorType.
Sourcepub fn from_i32(value: i32) -> Option<UnderlyingIndicatorType>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<UnderlyingIndicatorType>
Use the TryFrom<i32> implementation instead
Converts an i32 to a UnderlyingIndicatorType, or None if value is not a valid variant.
Sourceimpl UnderlyingIndicatorType
impl UnderlyingIndicatorType
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.