#[repr(i32)]pub enum PatternField {
Show 21 variants
Unknown = 0,
MaAlignmentLong = 1,
MaAlignmentShort = 2,
EmaAlignmentLong = 3,
EmaAlignmentShort = 4,
RsiGoldCrossLow = 5,
RsiDeathCrossHigh = 6,
RsiTopDivergence = 7,
RsiBottomDivergence = 8,
KdjGoldCrossLow = 9,
KdjDeathCrossHigh = 10,
KdjTopDivergence = 11,
KdjBottomDivergence = 12,
MacdGoldCrossLow = 13,
MacdDeathCrossHigh = 14,
MacdTopDivergence = 15,
MacdBottomDivergence = 16,
BollBreakUpper = 17,
BollLower = 18,
BollCrossMiddleUp = 19,
BollCrossMiddleDown = 20,
}Expand description
形态技术指标属性
Variants
Unknown = 0
未知
MaAlignmentLong = 1
MA多头排列(连续两天MA5>MA10>MA20>MA30>MA60,且当日收盘价大于前一天收盘价)
MaAlignmentShort = 2
MA空头排列(连续两天MA5 <MA10 <MA20 <MA30 <MA60,且当日收盘价小于前一天收盘价)
EmaAlignmentLong = 3
EMA多头排列(连续两天EMA5>EMA10>EMA20>EMA30>EMA60,且当日收盘价大于前一天收盘价)
EmaAlignmentShort = 4
EMA空头排列(连续两天EMA5 <EMA10 <EMA20 <EMA30 <EMA60,且当日收盘价小于前一天收盘价)
RsiGoldCrossLow = 5
RSI低位金叉(50以下,短线RSI上穿长线RSI(前一日短线RSI小于长线RSI,当日短线RSI大于长线RSI))
RsiDeathCrossHigh = 6
RSI高位死叉(50以上,短线RSI下穿长线RSI(前一日短线RSI大于长线RSI,当日短线RSI小于长线RSI))
RsiTopDivergence = 7
RSI顶背离(相邻的两个K线波峰,后面的波峰对应的CLOSE>前面的波峰对应的CLOSE,后面波峰的RSI12值 <前面波峰的RSI12值)
RsiBottomDivergence = 8
RSI底背离(相邻的两个K线波谷,后面的波谷对应的CLOSE <前面的波谷对应的CLOSE,后面波谷的RSI12值>前面波谷的RSI12值)
KdjGoldCrossLow = 9
KDJ低位金叉(KDJ的值都小于或等于30,且前一日K,J值分别小于D值,当日K,J值分别大于D值)
KdjDeathCrossHigh = 10
KDJ高位死叉(KDJ的值都大于或等于70,且前一日K,J值分别大于D值,当日K,J值分别小于D值)
KdjTopDivergence = 11
KDJ顶背离(相邻的两个K线波峰,后面的波峰对应的CLOSE>前面的波峰对应的CLOSE,后面波峰的J值 <前面波峰的J值)
KdjBottomDivergence = 12
KDJ底背离(相邻的两个K线波谷,后面的波谷对应的CLOSE <前面的波谷对应的CLOSE,后面波谷的J值>前面波谷的J值)
MacdGoldCrossLow = 13
MACD低位金叉(DIFF上穿DEA(前一日DIFF小于DEA,当日DIFF大于DEA))
MacdDeathCrossHigh = 14
MACD高位死叉(DIFF下穿DEA(前一日DIFF大于DEA,当日DIFF小于DEA))
MacdTopDivergence = 15
MACD顶背离(相邻的两个K线波峰,后面的波峰对应的CLOSE>前面的波峰对应的CLOSE,后面波峰的macd值 <前面波峰的macd值)
MacdBottomDivergence = 16
MACD底背离(相邻的两个K线波谷,后面的波谷对应的CLOSE <前面的波谷对应的CLOSE,后面波谷的macd值>前面波谷的macd值)
BollBreakUpper = 17
BOLL突破上轨(前一日股价低于上轨值,当日股价大于上轨值)
BollLower = 18
BOLL突破下轨(前一日股价高于下轨值,当日股价小于下轨值)
BollCrossMiddleUp = 19
BOLL向上破中轨(前一日股价低于中轨值,当日股价大于中轨值)
BollCrossMiddleDown = 20
BOLL向下破中轨(前一日股价大于中轨值,当日股价小于中轨值)
Implementations
Sourceimpl PatternField
impl PatternField
Sourceimpl PatternField
impl PatternField
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.