StockField

Enum StockField 

#[repr(i32)]
pub enum StockField {
Show 22 variants Unknown = 0, StockCode = 1, StockName = 2, CurPrice = 3, CurPriceToHighest52WeeksRatio = 4, CurPriceToLowest52WeeksRatio = 5, HighPriceToHighest52WeeksRatio = 6, LowPriceToLowest52WeeksRatio = 7, VolumeRatio = 8, BidAskRatio = 9, LotPrice = 10, MarketVal = 11, PeAnnual = 12, PeTtm = 13, PbRate = 14, ChangeRate5min = 15, ChangeRateBeginYear = 16, Psttm = 17, Pcfttm = 18, TotalShare = 19, FloatShare = 20, FloatMarketVal = 21,
}
简单属性

Variants



Unknown = 0

未知



StockCode = 1

股票代码,不能填区间上下限值。



StockName = 2

股票名称,不能填区间上下限值。



CurPrice = 3

最新价(精确到小数点后 3 位,超出部分会被舍弃)例如填写[10,20]值区间



CurPriceToHighest52WeeksRatio = 4

(现价 - 52周最高)/52周最高,对应PC端离52周高点百分比(精确到小数点后 3 位,超出部分会被舍弃)例如填写[-30,-10]值区间(该字段为百分比字段,默认不展示 %,如 20 实际对应 20%,如20实际对应20%)



CurPriceToLowest52WeeksRatio = 5

(现价 - 52周最低)/52周最低,对应PC端离52周低点百分比(精确到小数点后 3 位,超出部分会被舍弃)例如填写[20,40]值区间(该字段为百分比字段,默认不展示 %,如 20 实际对应 20%)



HighPriceToHighest52WeeksRatio = 6

(今日最高 - 52周最高)/52周最高(精确到小数点后 3 位,超出部分会被舍弃)例如填写[-3,-1]值区间(该字段为百分比字段,默认不展示 %,如 20 实际对应 20%)



LowPriceToLowest52WeeksRatio = 7

(今日最低 - 52周最低)/52周最低(精确到小数点后 3 位,超出部分会被舍弃)例如填写[10,70]值区间(该字段为百分比字段,默认不展示 %,如 20 实际对应 20%)



VolumeRatio = 8

量比(精确到小数点后 3 位,超出部分会被舍弃)例如填写[0.5,30]值区间



BidAskRatio = 9

委比(精确到小数点后 3 位,超出部分会被舍弃)例如填写[-20,80.5]值区间(该字段为百分比字段,默认不展示 %,如 20 实际对应 20%)



LotPrice = 10

每手价格(精确到小数点后 3 位,超出部分会被舍弃)例如填写[40,100]值区间



MarketVal = 11

市值(精确到小数点后 3 位,超出部分会被舍弃)例如填写[50000000,3000000000]值区间



PeAnnual = 12

市盈率(静态)(精确到小数点后 3 位,超出部分会被舍弃)例如填写[-8,65.3]值区间



PeTtm = 13

市盈率 TTM(精确到小数点后 3 位,超出部分会被舍弃)例如填写[-10,20.5]值区间



PbRate = 14

市净率(精确到小数点后 3 位,超出部分会被舍弃)例如填写[0.5,20]值区间



ChangeRate5min = 15

五分钟价格涨跌幅(精确到小数点后 3 位,超出部分会被舍弃)例如填写[-5,6.3]值区间(该字段为百分比字段,默认不展示 %,如 20 实际对应 20%)



ChangeRateBeginYear = 16

年初至今价格涨跌幅(精确到小数点后 3 位,超出部分会被舍弃)例如填写[-50.1,400.7]值区间(该字段为百分比字段,默认不展示 %,如 20 实际对应 20%)



Psttm = 17

基础量价属性

市销率 TTM(精确到小数点后 3 位,超出部分会被舍弃)例如填写 [100, 500] 值区间(该字段为百分比字段,默认不展示 %,如 20 实际对应 20%)



Pcfttm = 18

市现率 TTM(精确到小数点后 3 位,超出部分会被舍弃)例如填写 [100, 1000] 值区间 (该字段为百分比字段,默认不展示 %,如 20 实际对应 20%)



TotalShare = 19

总股数(精确到小数点后 0 位,超出部分会被舍弃)例如填写 [1000000000,1000000000] 值区间 (单位:股)(精确到小数点后 0 位,超出部分会被舍弃)



FloatShare = 20

流通股数(精确到小数点后 0 位,超出部分会被舍弃)例如填写 [1000000000,1000000000] 值区间 (单位:股)(精确到小数点后 0 位,超出部分会被舍弃)



FloatMarketVal = 21

流通市值(精确到小数点后 3 位,超出部分会被舍弃)例如填写 [1000000000,1000000000] 值区间 (单位:元)

Implementations

Source

impl StockField

pub fn is_valid(value: i32) -> bool

Returns true if value is a variant of StockField.

pub fn from_i32(value: i32) -> Option<StockField>

👎Deprecated: Use the TryFrom<i32> implementation instead

Converts an i32 to a StockField, or None if value is not a valid variant.

Source

impl StockField

pub fn as_str_name(&self) -> &'static str

String value of the enum field names used in the ProtoBuf definition.

The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.

pub fn from_str_name(value: &str) -> Option<Self>

Creates an enum from field names used in the ProtoBuf definition.