#[repr(i32)]pub enum DtStatus {
Unknown = 0,
Unlimited = 1,
EmCall = 2,
DtCall = 3,
}Expand description
日内交易限制情况
Variants
Unknown = 0
未知
Unlimited = 1
无限次(当前可以无限次日内交易,注意留意剩余日内交易购买力)
EmCall = 2
EM Call(当前状态不能新建仓位,需要补充资产净值至$25000以上,否则会被禁止新建仓位90天)
DtCall = 3
DT Call(当前状态有未补平的日内交易追缴金额(DTCall),需要在5个交易日内足额入金来补平 DTCall,否则会被禁止新建仓位,直到足额存入资金才会解禁)
Implementations
Sourceimpl DtStatus
impl DtStatus
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.