#[repr(i32)]pub enum TrdAccType {
Unknown = 0,
Cash = 1,
Margin = 2,
Tfsa = 3,
Rrsp = 4,
Srrsp = 5,
Derivatives = 6,
}Expand description
交易账户类型
Variants
Unknown = 0
未知类型
Cash = 1
现金账户
Margin = 2
保证金账户
Tfsa = 3
加拿大免税账户
Rrsp = 4
加拿大注册退休账户
Srrsp = 5
加拿大配偶退休账户
Derivatives = 6
日本衍生品账户
Implementations
Sourceimpl TrdAccType
impl TrdAccType
Sourceimpl TrdAccType
impl TrdAccType
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.