#[repr(i32)]pub enum TrdSubAccType {
Show 17 variants
None = 0,
JpGeneral = 1,
JpTokutei = 2,
JpNisaGeneral = 3,
JpNisaTsumitate = 4,
JpGeneralShort = 5,
JpTokuteiShort = 6,
JpHonpoGeneral = 7,
JpGaikokuGeneral = 8,
JpHonpoTokutei = 9,
JpGaikokuTokutei = 10,
JpDerivativeLong = 11,
JpDerivativeShort = 12,
JpHonpoDerivativeGeneral = 13,
JpGaikokuDerivativeGeneral = 14,
JpHonpoDerivativeTokutei = 15,
JpGaikokuDerivativeTokutei = 16,
}Expand description
JP子账户类型
Variants
None = 0
未知
JpGeneral = 1
日本-一般口座-long
JpTokutei = 2
日本-特定口座-long
JpNisaGeneral = 3
日本-一般NISA
JpNisaTsumitate = 4
日本-累计NISA
JpGeneralShort = 5
JP支持信用账户新增如下六种子账户类型
日本-一般口座-Short
JpTokuteiShort = 6
日本-特定口座-Short
JpHonpoGeneral = 7
日本-本国信用交易抵押品-一般
JpGaikokuGeneral = 8
日本-外国信用交易抵押品-一般
JpHonpoTokutei = 9
日本-本国信用交易抵押品-特定
JpGaikokuTokutei = 10
日本-外国信用交易抵押品-特定
JpDerivativeLong = 11
JP支持衍生品账户新增如下六种子账户类型
日本-衍生品-Long
JpDerivativeShort = 12
日本-衍生品-Short
JpHonpoDerivativeGeneral = 13
日本-本国衍生品证据金-一般
JpGaikokuDerivativeGeneral = 14
日本-外国衍生品证据金-一般
JpHonpoDerivativeTokutei = 15
日本-本国衍生品证据金-特定
JpGaikokuDerivativeTokutei = 16
日本-外国衍生品证据金-特定
Implementations
Sourceimpl TrdSubAccType
impl TrdSubAccType
Sourceimpl TrdSubAccType
impl TrdSubAccType
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.