pub struct GroupOrderNode {Show 31 fields
pub acc_id: u64,
pub client_order_id: String,
pub code: String,
pub sec_market: i32,
pub trd_side: i32,
pub order_type: i32,
pub qty: Option<String>,
pub amount: Option<String>,
pub price: Option<String>,
pub lot_type: u32,
pub time_in_force: Option<u32>,
pub expire_time: Option<u64>,
pub order_trade_time_type: Option<u32>,
pub enable_ba_trade: Option<u32>,
pub position_open_type: Option<u32>,
pub force_key: Option<u32>,
pub condition: Option<Condition>,
pub trigger_info: Option<TriggerInfo>,
pub children_relation: i32,
pub brother_relation: i32,
pub children: Vec<GroupOrderNode>,
pub futures_price_type: Option<u32>,
pub forex_addition: Option<ForexAddition>,
pub multi_leg_info: Option<MultiLegInfo>,
pub position_id: Option<String>,
pub combo_id: Option<String>,
pub ticket_list: Vec<String>,
pub third_party_bcan: Option<String>,
pub custom_field_json: Option<String>,
pub margin_trading_type: Option<u32>,
pub margin_period_type: Option<u32>,
}Fields
acc_id: u64client_order_id: Stringcode: Stringsec_market: i32trd_side: i32order_type: i32qty: Option<String>amount: Option<String>price: Option<String>lot_type: u32time_in_force: Option<u32>expire_time: Option<u64>order_trade_time_type: Option<u32>US/CA only; omit for Unset and every other market.
enable_ba_trade: Option<u32>HK only; omit for Unset and every other market.
position_open_type: Option<u32>force_key: Option<u32>condition: Option<Condition>trigger_info: Option<TriggerInfo>children_relation: i32brother_relation: i32children: Vec<GroupOrderNode>futures_price_type: Option<u32>Futures only. Rival=1 / Market=2; omit for specified-price Normal.
forex_addition: Option<ForexAddition>multi_leg_info: Option<MultiLegInfo>position_id: Option<String>combo_id: Option<String>ticket_list: Vec<String>third_party_bcan: Option<String>custom_field_json: Option<String>margin_trading_type: Option<u32>JP margin validation hints only. If present they must match the source-derived Negotiable=1 / Indefinite=1 values.
margin_period_type: Option<u32>Implementations
Sourceimpl GroupOrderNode
impl GroupOrderNode
Sourcepub fn amount(&self) -> &str
pub fn amount(&self) -> &str
Returns the value of amount, or the default value if amount is unset.
Sourcepub fn price(&self) -> &str
pub fn price(&self) -> &str
Returns the value of price, or the default value if price is unset.
Sourcepub fn time_in_force(&self) -> u32
pub fn time_in_force(&self) -> u32
Returns the value of time_in_force, or the default value if time_in_force is unset.
Sourcepub fn expire_time(&self) -> u64
pub fn expire_time(&self) -> u64
Returns the value of expire_time, or the default value if expire_time is unset.
Sourcepub fn order_trade_time_type(&self) -> u32
pub fn order_trade_time_type(&self) -> u32
Returns the value of order_trade_time_type, or the default value if order_trade_time_type is unset.
Sourcepub fn enable_ba_trade(&self) -> u32
pub fn enable_ba_trade(&self) -> u32
Returns the value of enable_ba_trade, or the default value if enable_ba_trade is unset.
Sourcepub fn position_open_type(&self) -> u32
pub fn position_open_type(&self) -> u32
Returns the value of position_open_type, or the default value if position_open_type is unset.
Sourcepub fn force_key(&self) -> u32
pub fn force_key(&self) -> u32
Returns the value of force_key, or the default value if force_key is unset.
Sourcepub fn children_relation(&self) -> RelationType
pub fn children_relation(&self) -> RelationType
Returns the enum value of children_relation, or the default if the field is set to an invalid enum value.
Sourcepub fn set_children_relation(&mut self, value: RelationType)
pub fn set_children_relation(&mut self, value: RelationType)
Sets children_relation to the provided enum value.
Sourcepub fn brother_relation(&self) -> RelationType
pub fn brother_relation(&self) -> RelationType
Returns the enum value of brother_relation, or the default if the field is set to an invalid enum value.
Sourcepub fn set_brother_relation(&mut self, value: RelationType)
pub fn set_brother_relation(&mut self, value: RelationType)
Sets brother_relation to the provided enum value.
Sourcepub fn futures_price_type(&self) -> u32
pub fn futures_price_type(&self) -> u32
Returns the value of futures_price_type, or the default value if futures_price_type is unset.
Sourcepub fn position_id(&self) -> &str
pub fn position_id(&self) -> &str
Returns the value of position_id, or the default value if position_id is unset.
Sourcepub fn combo_id(&self) -> &str
pub fn combo_id(&self) -> &str
Returns the value of combo_id, or the default value if combo_id is unset.
Sourcepub fn third_party_bcan(&self) -> &str
pub fn third_party_bcan(&self) -> &str
Returns the value of third_party_bcan, or the default value if third_party_bcan is unset.
Sourcepub fn custom_field_json(&self) -> &str
pub fn custom_field_json(&self) -> &str
Returns the value of custom_field_json, or the default value if custom_field_json is unset.
Sourcepub fn margin_trading_type(&self) -> u32
pub fn margin_trading_type(&self) -> u32
Returns the value of margin_trading_type, or the default value if margin_trading_type is unset.
Sourcepub fn margin_period_type(&self) -> u32
pub fn margin_period_type(&self) -> u32
Returns the value of margin_period_type, or the default value if margin_period_type is unset.